Class: Verizon::AccountConsentUpdate
- Defined in:
- lib/verizon/models/account_consent_update.rb
Overview
AccountConsentUpdate Model.
Instance Attribute Summary collapse
-
#account_name ⇒ String
The numeric name of the account, including leading zeros.
-
#all_device_consent ⇒ Integer
The consent setting to use for all the devices in the account.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(account_name = SKIP, all_device_consent = SKIP) ⇒ AccountConsentUpdate
constructor
A new instance of AccountConsentUpdate.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(account_name = SKIP, all_device_consent = SKIP) ⇒ AccountConsentUpdate
Returns a new instance of AccountConsentUpdate.
41 42 43 44 |
# File 'lib/verizon/models/account_consent_update.rb', line 41 def initialize(account_name = SKIP, = SKIP) @account_name = account_name unless account_name == SKIP @all_device_consent = unless == SKIP end |
Instance Attribute Details
#account_name ⇒ String
The numeric name of the account, including leading zeros.
14 15 16 |
# File 'lib/verizon/models/account_consent_update.rb', line 14 def account_name @account_name end |
#all_device_consent ⇒ Integer
The consent setting to use for all the devices in the account.
18 19 20 |
# File 'lib/verizon/models/account_consent_update.rb', line 18 def @all_device_consent end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/verizon/models/account_consent_update.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. account_name = hash.key?('accountName') ? hash['accountName'] : SKIP = hash.key?('allDeviceConsent') ? hash['allDeviceConsent'] : SKIP # Create object from extracted values. AccountConsentUpdate.new(account_name, ) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/verizon/models/account_consent_update.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['account_name'] = 'accountName' @_hash['all_device_consent'] = 'allDeviceConsent' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/verizon/models/account_consent_update.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/verizon/models/account_consent_update.rb', line 29 def self.optionals %w[ account_name all_device_consent ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
68 69 70 71 72 |
# File 'lib/verizon/models/account_consent_update.rb', line 68 def inspect class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name.inspect}, all_device_consent:"\ " #{@all_device_consent.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
61 62 63 64 65 |
# File 'lib/verizon/models/account_consent_update.rb', line 61 def to_s class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name}, all_device_consent:"\ " #{@all_device_consent}>" end |