Class: Verizon::AccountDeviceListResult

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/account_device_list_result.rb

Overview

Response for a request to list down account devices.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(devices = SKIP, has_more_data = SKIP) ⇒ AccountDeviceListResult

Returns a new instance of AccountDeviceListResult.



43
44
45
46
# File 'lib/verizon/models/account_device_list_result.rb', line 43

def initialize(devices = SKIP, has_more_data = SKIP)
  @devices = devices unless devices == SKIP
  @has_more_data = has_more_data unless has_more_data == SKIP
end

Instance Attribute Details

#devicesArray[ThingspaceDevice]

Up to 10,000 devices that you want to move to a different account, specified by device identifier.

Returns:



15
16
17
# File 'lib/verizon/models/account_device_list_result.rb', line 15

def devices
  @devices
end

#has_more_dataTrueClass | FalseClass

False for a status 200 response.True for a status 202 response, indicating that there is more data to be retrieved.

Returns:

  • (TrueClass | FalseClass)


20
21
22
# File 'lib/verizon/models/account_device_list_result.rb', line 20

def has_more_data
  @has_more_data
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/verizon/models/account_device_list_result.rb', line 49

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  devices = nil
  unless hash['devices'].nil?
    devices = []
    hash['devices'].each do |structure|
      devices << (ThingspaceDevice.from_hash(structure) if structure)
    end
  end

  devices = SKIP unless hash.key?('devices')
  has_more_data = hash.key?('hasMoreData') ? hash['hasMoreData'] : SKIP

  # Create object from extracted values.
  AccountDeviceListResult.new(devices,
                              has_more_data)
end

.namesObject

A mapping from model property names to API property names.



23
24
25
26
27
28
# File 'lib/verizon/models/account_device_list_result.rb', line 23

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['devices'] = 'devices'
  @_hash['has_more_data'] = 'hasMoreData'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/verizon/models/account_device_list_result.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



31
32
33
34
35
36
# File 'lib/verizon/models/account_device_list_result.rb', line 31

def self.optionals
  %w[
    devices
    has_more_data
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



77
78
79
80
# File 'lib/verizon/models/account_device_list_result.rb', line 77

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} devices: #{@devices.inspect}, has_more_data: #{@has_more_data.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



71
72
73
74
# File 'lib/verizon/models/account_device_list_result.rb', line 71

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} devices: #{@devices}, has_more_data: #{@has_more_data}>"
end