Class: Verizon::AccountGroupShareIndividual1
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::AccountGroupShareIndividual1
- Defined in:
- lib/verizon/models/account_group_share_individual1.rb
Overview
AccountGroupShareIndividual1 Model.
Instance Attribute Summary collapse
-
#account_group_share_individual ⇒ AccountGroupShareFilterCriteria
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(account_group_share_individual = SKIP) ⇒ AccountGroupShareIndividual1
constructor
A new instance of AccountGroupShareIndividual1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(account_group_share_individual = SKIP) ⇒ AccountGroupShareIndividual1
Returns a new instance of AccountGroupShareIndividual1.
35 36 37 38 39 40 |
# File 'lib/verizon/models/account_group_share_individual1.rb', line 35 def initialize(account_group_share_individual = SKIP) unless account_group_share_individual == SKIP @account_group_share_individual = account_group_share_individual end end |
Instance Attribute Details
#account_group_share_individual ⇒ AccountGroupShareFilterCriteria
TODO: Write general description for this method
14 15 16 |
# File 'lib/verizon/models/account_group_share_individual1.rb', line 14 def account_group_share_individual @account_group_share_individual end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/verizon/models/account_group_share_individual1.rb', line 43 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. if hash['accountGroupShareIndividual'] account_group_share_individual = AccountGroupShareFilterCriteria.from_hash(hash['accountGroupShareIndividual']) end # Create object from extracted values. AccountGroupShareIndividual1.new(account_group_share_individual) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/verizon/models/account_group_share_individual1.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['account_group_share_individual'] = 'accountGroupShareIndividual' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 |
# File 'lib/verizon/models/account_group_share_individual1.rb', line 31 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 27 28 |
# File 'lib/verizon/models/account_group_share_individual1.rb', line 24 def self.optionals %w[ account_group_share_individual ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
57 58 59 60 61 62 63 |
# File 'lib/verizon/models/account_group_share_individual1.rb', line 57 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
72 73 74 75 76 |
# File 'lib/verizon/models/account_group_share_individual1.rb', line 72 def inspect class_name = self.class.name.split('::').last "<#{class_name} account_group_share_individual:"\ " #{@account_group_share_individual.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
66 67 68 69 |
# File 'lib/verizon/models/account_group_share_individual1.rb', line 66 def to_s class_name = self.class.name.split('::').last "<#{class_name} account_group_share_individual: #{@account_group_share_individual}>" end |