Class: Verizon::AccountLead

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/account_lead.rb

Overview

A successful response returns an array of lead objects.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(address = SKIP, lead_id = SKIP, lead_state = SKIP) ⇒ AccountLead

Returns a new instance of AccountLead.



49
50
51
52
53
# File 'lib/verizon/models/account_lead.rb', line 49

def initialize(address = SKIP, lead_id = SKIP, lead_state = SKIP)
  @address = address unless address == SKIP
  @lead_id = lead_id unless lead_id == SKIP
  @lead_state = lead_state unless lead_state == SKIP
end

Instance Attribute Details

#addressAddress

The customer address for the line’s primary place of use, for line usage taxation.

Returns:



15
16
17
# File 'lib/verizon/models/account_lead.rb', line 15

def address
  @address
end

#lead_idString

Unique number for each lead. Use this value in the leadId parameter when activating devices to credit the activations to the lead.

Returns:

  • (String)


20
21
22
# File 'lib/verizon/models/account_lead.rb', line 20

def lead_id
  @lead_id
end

#lead_stateString

The current state of the lead, such as “Qualified” or “Closed.”

Returns:

  • (String)


24
25
26
# File 'lib/verizon/models/account_lead.rb', line 24

def lead_state
  @lead_state
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/verizon/models/account_lead.rb', line 56

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  address = Address.from_hash(hash['address']) if hash['address']
  lead_id = hash.key?('leadId') ? hash['leadId'] : SKIP
  lead_state = hash.key?('leadState') ? hash['leadState'] : SKIP

  # Create object from extracted values.
  AccountLead.new(address,
                  lead_id,
                  lead_state)
end

.namesObject

A mapping from model property names to API property names.



27
28
29
30
31
32
33
# File 'lib/verizon/models/account_lead.rb', line 27

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['address'] = 'address'
  @_hash['lead_id'] = 'leadId'
  @_hash['lead_state'] = 'leadState'
  @_hash
end

.nullablesObject

An array for nullable fields



45
46
47
# File 'lib/verizon/models/account_lead.rb', line 45

def self.nullables
  []
end

.optionalsObject

An array for optional fields



36
37
38
39
40
41
42
# File 'lib/verizon/models/account_lead.rb', line 36

def self.optionals
  %w[
    address
    lead_id
    lead_state
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



77
78
79
80
81
# File 'lib/verizon/models/account_lead.rb', line 77

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} address: #{@address.inspect}, lead_id: #{@lead_id.inspect}, lead_state:"\
  " #{@lead_state.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



71
72
73
74
# File 'lib/verizon/models/account_lead.rb', line 71

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} address: #{@address}, lead_id: #{@lead_id}, lead_state: #{@lead_state}>"
end