Class: Verizon::AccountLeadsResult
- Defined in:
- lib/verizon/models/account_leads_result.rb
Overview
Returns information for all leads associated with an account.
Instance Attribute Summary collapse
-
#has_more_data ⇒ TrueClass | FalseClass
False if no more leads.True if there is more data to be retrieved.
-
#leads ⇒ Array[AccountLead]
The leads associated with an account.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(has_more_data = SKIP, leads = SKIP) ⇒ AccountLeadsResult
constructor
A new instance of AccountLeadsResult.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(has_more_data = SKIP, leads = SKIP) ⇒ AccountLeadsResult
Returns a new instance of AccountLeadsResult.
41 42 43 44 |
# File 'lib/verizon/models/account_leads_result.rb', line 41 def initialize(has_more_data = SKIP, leads = SKIP) @has_more_data = has_more_data unless has_more_data == SKIP @leads = leads unless leads == SKIP end |
Instance Attribute Details
#has_more_data ⇒ TrueClass | FalseClass
False if no more leads.True if there is more data to be retrieved.
14 15 16 |
# File 'lib/verizon/models/account_leads_result.rb', line 14 def has_more_data @has_more_data end |
#leads ⇒ Array[AccountLead]
The leads associated with an account.
18 19 20 |
# File 'lib/verizon/models/account_leads_result.rb', line 18 def leads @leads end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/verizon/models/account_leads_result.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. has_more_data = hash.key?('hasMoreData') ? hash['hasMoreData'] : SKIP # Parameter is an array, so we need to iterate through it leads = nil unless hash['leads'].nil? leads = [] hash['leads'].each do |structure| leads << (AccountLead.from_hash(structure) if structure) end end leads = SKIP unless hash.key?('leads') # Create object from extracted values. AccountLeadsResult.new(has_more_data, leads) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/verizon/models/account_leads_result.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['has_more_data'] = 'hasMoreData' @_hash['leads'] = 'leads' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/verizon/models/account_leads_result.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/verizon/models/account_leads_result.rb', line 29 def self.optionals %w[ has_more_data leads ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
75 76 77 78 |
# File 'lib/verizon/models/account_leads_result.rb', line 75 def inspect class_name = self.class.name.split('::').last "<#{class_name} has_more_data: #{@has_more_data.inspect}, leads: #{@leads.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 |
# File 'lib/verizon/models/account_leads_result.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} has_more_data: #{@has_more_data}, leads: #{@leads}>" end |