Class: Verizon::AccountLevelObject

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/account_level_object.rb

Overview

AccountLevelObject Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(filter_criteria = SKIP, condition = SKIP, action = SKIP) ⇒ AccountLevelObject

Returns a new instance of AccountLevelObject.



47
48
49
50
51
# File 'lib/verizon/models/account_level_object.rb', line 47

def initialize(filter_criteria = SKIP, condition = SKIP, action = SKIP)
  @filter_criteria = filter_criteria unless filter_criteria == SKIP
  @condition = condition unless condition == SKIP
  @action = action unless action == SKIP
end

Instance Attribute Details

#actionAccountLevelActionEnum

The action taken when trigger conditions are met



22
23
24
# File 'lib/verizon/models/account_level_object.rb', line 22

def action
  @action
end

#conditionRateplantype2Condition

TODO: Write general description for this method



18
19
20
# File 'lib/verizon/models/account_level_object.rb', line 18

def condition
  @condition
end

#filter_criteriaAccountLevelFilter

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/verizon/models/account_level_object.rb', line 14

def filter_criteria
  @filter_criteria
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/verizon/models/account_level_object.rb', line 54

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  filter_criteria = AccountLevelFilter.from_hash(hash['filterCriteria']) if
    hash['filterCriteria']
  condition = hash.key?('condition') ? APIHelper.deserialize_union_type(
    UnionTypeLookUp.get(:AccountLevelObjectCondition), hash['condition']
  ) : SKIP
  action = hash.key?('action') ? hash['action'] : SKIP

  # Create object from extracted values.
  AccountLevelObject.new(filter_criteria,
                         condition,
                         action)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/verizon/models/account_level_object.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['filter_criteria'] = 'filterCriteria'
  @_hash['condition'] = 'condition'
  @_hash['action'] = 'action'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/verizon/models/account_level_object.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/verizon/models/account_level_object.rb', line 34

def self.optionals
  %w[
    filter_criteria
    condition
    action
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



73
74
75
76
77
78
79
# File 'lib/verizon/models/account_level_object.rb', line 73

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



89
90
91
92
93
# File 'lib/verizon/models/account_level_object.rb', line 89

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} filter_criteria: #{@filter_criteria.inspect}, condition:"\
  " #{@condition.inspect}, action: #{@action.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



82
83
84
85
86
# File 'lib/verizon/models/account_level_object.rb', line 82

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} filter_criteria: #{@filter_criteria}, condition: #{@condition}, action:"\
  " #{@action}>"
end