Class: Verizon::AccountRequestsController

Inherits:
BaseController show all
Defined in:
lib/verizon/controllers/account_requests_controller.rb

Overview

AccountRequestsController

Constant Summary

Constants inherited from BaseController

BaseController::GLOBAL_ERRORS

Instance Attribute Summary

Attributes inherited from BaseController

#config, #http_call_back

Instance Method Summary collapse

Methods inherited from BaseController

#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent

Constructor Details

This class inherits a constructor from Verizon::BaseController

Instance Method Details

#get_current_asynchronous_request_status(aname, request_id) ⇒ ApiResponse

Returns the current status of an asynchronous request that was made for a single device. response.

Parameters:

  • aname (String)

    Required parameter: Account name.

  • request_id (String)

    Required parameter: UUID from synchronous

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
# File 'lib/verizon/controllers/account_requests_controller.rb', line 15

def get_current_asynchronous_request_status(aname,
                                            request_id)
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/m2m/v1/accounts/{aname}/requests/{requestId}/status',
                                 Server::THINGSPACE)
               .template_param(new_parameter(aname, key: 'aname')
                                .should_encode(true))
               .template_param(new_parameter(request_id, key: 'requestId')
                                .should_encode(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(AsynchronousRequestResult.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'Error response.',
                             ConnectivityManagementResultException))
    .execute
end