Class: Verizon::AccountService

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/account_service.rb

Overview

Service associated with the account.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(name = SKIP, description = SKIP, states = SKIP) ⇒ AccountService

Returns a new instance of AccountService.



47
48
49
50
51
# File 'lib/verizon/models/account_service.rb', line 47

def initialize(name = SKIP, description = SKIP, states = SKIP)
  @name = name unless name == SKIP
  @description = description unless description == SKIP
  @states = states unless states == SKIP
end

Instance Attribute Details

#descriptionString

The description of the service plan.

Returns:

  • (String)


18
19
20
# File 'lib/verizon/models/account_service.rb', line 18

def description
  @description
end

#nameString

The name of the service plan.

Returns:

  • (String)


14
15
16
# File 'lib/verizon/models/account_service.rb', line 14

def name
  @name
end

#statesArray[State]

The state of the service plan.

Returns:



22
23
24
# File 'lib/verizon/models/account_service.rb', line 22

def states
  @states
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/verizon/models/account_service.rb', line 54

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  name = hash.key?('name') ? hash['name'] : SKIP
  description = hash.key?('description') ? hash['description'] : SKIP
  # Parameter is an array, so we need to iterate through it
  states = nil
  unless hash['states'].nil?
    states = []
    hash['states'].each do |structure|
      states << (State.from_hash(structure) if structure)
    end
  end

  states = SKIP unless hash.key?('states')

  # Create object from extracted values.
  AccountService.new(name,
                     description,
                     states)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/verizon/models/account_service.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['name'] = 'name'
  @_hash['description'] = 'description'
  @_hash['states'] = 'states'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/verizon/models/account_service.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/verizon/models/account_service.rb', line 34

def self.optionals
  %w[
    name
    description
    states
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



84
85
86
87
88
# File 'lib/verizon/models/account_service.rb', line 84

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name.inspect}, description: #{@description.inspect}, states:"\
  " #{@states.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



78
79
80
81
# File 'lib/verizon/models/account_service.rb', line 78

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name}, description: #{@description}, states: #{@states}>"
end