Class: Verizon::ActiveAnomalyIndicator
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::ActiveAnomalyIndicator
- Defined in:
- lib/verizon/models/active_anomaly_indicator.rb
Overview
Whether the anomaly detection is active or not.
Instance Attribute Summary collapse
-
#active ⇒ TrueClass | FalseClass
Indicates anomaly detection is active<br />True - Anomaly detection is active.<br />False - Anomaly detection is not active.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(active = SKIP) ⇒ ActiveAnomalyIndicator
constructor
A new instance of ActiveAnomalyIndicator.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(active = SKIP) ⇒ ActiveAnomalyIndicator
Returns a new instance of ActiveAnomalyIndicator.
36 37 38 |
# File 'lib/verizon/models/active_anomaly_indicator.rb', line 36 def initialize(active = SKIP) @active = active unless active == SKIP end |
Instance Attribute Details
#active ⇒ TrueClass | FalseClass
Indicates anomaly detection is active<br />True - Anomaly detection is active.<br />False - Anomaly detection is not active.
15 16 17 |
# File 'lib/verizon/models/active_anomaly_indicator.rb', line 15 def active @active end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
41 42 43 44 45 46 47 48 49 |
# File 'lib/verizon/models/active_anomaly_indicator.rb', line 41 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. active = hash.key?('active') ? hash['active'] : SKIP # Create object from extracted values. ActiveAnomalyIndicator.new(active) end |
.names ⇒ Object
A mapping from model property names to API property names.
18 19 20 21 22 |
# File 'lib/verizon/models/active_anomaly_indicator.rb', line 18 def self.names @_hash = {} if @_hash.nil? @_hash['active'] = 'active' @_hash end |
.nullables ⇒ Object
An array for nullable fields
32 33 34 |
# File 'lib/verizon/models/active_anomaly_indicator.rb', line 32 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
25 26 27 28 29 |
# File 'lib/verizon/models/active_anomaly_indicator.rb', line 25 def self.optionals %w[ active ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
53 54 55 56 57 58 59 |
# File 'lib/verizon/models/active_anomaly_indicator.rb', line 53 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
68 69 70 71 |
# File 'lib/verizon/models/active_anomaly_indicator.rb', line 68 def inspect class_name = self.class.name.split('::').last "<#{class_name} active: #{@active.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
62 63 64 65 |
# File 'lib/verizon/models/active_anomaly_indicator.rb', line 62 def to_s class_name = self.class.name.split('::').last "<#{class_name} active: #{@active}>" end |