Class: Verizon::ActiveTriggerIndicator

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/active_trigger_indicator.rb

Overview

Whether the trigger is active or not.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(active = SKIP) ⇒ ActiveTriggerIndicator

Returns a new instance of ActiveTriggerIndicator.



36
37
38
# File 'lib/verizon/models/active_trigger_indicator.rb', line 36

def initialize(active = SKIP)
  @active = active unless active == SKIP
end

Instance Attribute Details

#activeTrueClass | FalseClass

Indicates if the trigger is active<br />True - trigger is active<br />False - trigger is not active.

Returns:

  • (TrueClass | FalseClass)


15
16
17
# File 'lib/verizon/models/active_trigger_indicator.rb', line 15

def active
  @active
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



41
42
43
44
45
46
47
48
49
# File 'lib/verizon/models/active_trigger_indicator.rb', line 41

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  active = hash.key?('active') ? hash['active'] : SKIP

  # Create object from extracted values.
  ActiveTriggerIndicator.new(active)
end

.namesObject

A mapping from model property names to API property names.



18
19
20
21
22
# File 'lib/verizon/models/active_trigger_indicator.rb', line 18

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['active'] = 'active'
  @_hash
end

.nullablesObject

An array for nullable fields



32
33
34
# File 'lib/verizon/models/active_trigger_indicator.rb', line 32

def self.nullables
  []
end

.optionalsObject

An array for optional fields



25
26
27
28
29
# File 'lib/verizon/models/active_trigger_indicator.rb', line 25

def self.optionals
  %w[
    active
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



53
54
55
56
57
58
59
# File 'lib/verizon/models/active_trigger_indicator.rb', line 53

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



68
69
70
71
# File 'lib/verizon/models/active_trigger_indicator.rb', line 68

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} active: #{@active.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



62
63
64
65
# File 'lib/verizon/models/active_trigger_indicator.rb', line 62

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} active: #{@active}>"
end