Class: Verizon::AnomalyTriggersV2Controller

Inherits:
BaseController show all
Defined in:
lib/verizon/controllers/anomaly_triggers_v2_controller.rb

Overview

AnomalyTriggersV2Controller

Constant Summary

Constants inherited from BaseController

BaseController::GLOBAL_ERRORS

Instance Attribute Summary

Attributes inherited from BaseController

#config, #http_call_back

Instance Method Summary collapse

Methods inherited from BaseController

#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent

Constructor Details

This class inherits a constructor from Verizon::BaseController

Instance Method Details

#create_anomaly_detection_trigger_v2(body) ⇒ ApiResponse

Creates the trigger to identify an anomaly. ActiveTriggerIndicator]] body Required parameter: Request to create an anomaly trigger.

Parameters:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
# File 'lib/verizon/controllers/anomaly_triggers_v2_controller.rb', line 14

def create_anomaly_detection_trigger_v2(body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/m2m/v2/triggers',
                                 Server::THINGSPACE)
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body)
                            .validator(proc do |value|
                              UnionTypeLookUp.get(:CreateTriggerRequestOptions2)
                                             .validate(value)
                            end))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(AnomalyDetectionTrigger.method(:from_hash))
                .is_api_response(true)
                .local_error('default',
                             'An error occurred.',
                             IntelligenceResultException))
    .execute
end

#list_anomaly_detection_trigger_settings_v2(trigger_id) ⇒ ApiResponse

Retrieves the values for a specific trigger ID. specific trigger.

Parameters:

  • trigger_id (String)

    Required parameter: The trigger ID of a

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/verizon/controllers/anomaly_triggers_v2_controller.rb', line 70

def list_anomaly_detection_trigger_settings_v2(trigger_id)
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/m2m/v2/triggers/{triggerId}',
                                 Server::THINGSPACE)
               .template_param(new_parameter(trigger_id, key: 'triggerId')
                                .should_encode(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(AnomalyTriggerResult.method(:from_hash))
                .is_api_response(true)
                .local_error('default',
                             'An error occurred.',
                             IntelligenceResultException))
    .execute
end

#update_anomaly_detection_trigger_v2(body) ⇒ ApiResponse

Updates an existing trigger using the account name. parameter: Request to update existing trigger.

Parameters:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/verizon/controllers/anomaly_triggers_v2_controller.rb', line 42

def update_anomaly_detection_trigger_v2(body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::PUT,
                                 '/m2m/v2/triggers',
                                 Server::THINGSPACE)
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body)
                            .validator(proc do |value|
                              UnionTypeLookUp.get(:UpdateTriggerRequestOptions2)
                                             .validate(value)
                            end))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(IntelligenceSuccessResult.method(:from_hash))
                .is_api_response(true)
                .local_error('default',
                             'An error occurred.',
                             IntelligenceResultException))
    .execute
end