Class: Verizon::AssociateLabelRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/associate_label_request.rb

Overview

AssociateLabelRequest Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(account_name = nil, labels = nil) ⇒ AssociateLabelRequest

Returns a new instance of AssociateLabelRequest.



39
40
41
42
# File 'lib/verizon/models/associate_label_request.rb', line 39

def initialize( = nil, labels = nil)
  @account_name = 
  @labels = labels
end

Instance Attribute Details

#account_nameString

The name of a billing account. An account name is usually numeric, and must include any leading zeros.

Returns:

  • (String)


15
16
17
# File 'lib/verizon/models/associate_label_request.rb', line 15

def 
  @account_name
end

#labelsAccountLabels

Maximum of 2,000 objects are allowed in the array.

Returns:



19
20
21
# File 'lib/verizon/models/associate_label_request.rb', line 19

def labels
  @labels
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



45
46
47
48
49
50
51
52
53
54
55
# File 'lib/verizon/models/associate_label_request.rb', line 45

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
   = hash.key?('accountName') ? hash['accountName'] : nil
  labels = AccountLabels.from_hash(hash['labels']) if hash['labels']

  # Create object from extracted values.
  AssociateLabelRequest.new(,
                            labels)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/verizon/models/associate_label_request.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['account_name'] = 'accountName'
  @_hash['labels'] = 'labels'
  @_hash
end

.nullablesObject

An array for nullable fields



35
36
37
# File 'lib/verizon/models/associate_label_request.rb', line 35

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
# File 'lib/verizon/models/associate_label_request.rb', line 30

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



64
65
66
67
# File 'lib/verizon/models/associate_label_request.rb', line 64

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} account_name: #{@account_name.inspect}, labels: #{@labels.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



58
59
60
61
# File 'lib/verizon/models/associate_label_request.rb', line 58

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} account_name: #{@account_name}, labels: #{@labels}>"
end