Class: Verizon::AsynchronousRequestResultforplanner
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::AsynchronousRequestResultforplanner
- Defined in:
- lib/verizon/models/asynchronous_request_resultforplanner.rb
Overview
A successful request returns the request ID (UUID) and the current status.
Instance Attribute Summary collapse
-
#request_id ⇒ String
The unique ID of a request.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(request_id = SKIP) ⇒ AsynchronousRequestResultforplanner
constructor
A new instance of AsynchronousRequestResultforplanner.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(request_id = SKIP) ⇒ AsynchronousRequestResultforplanner
Returns a new instance of AsynchronousRequestResultforplanner.
37 38 39 |
# File 'lib/verizon/models/asynchronous_request_resultforplanner.rb', line 37 def initialize(request_id = SKIP) @request_id = request_id unless request_id == SKIP end |
Instance Attribute Details
#request_id ⇒ String
The unique ID of a request. This is a UUID value.
14 15 16 |
# File 'lib/verizon/models/asynchronous_request_resultforplanner.rb', line 14 def request_id @request_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
42 43 44 45 46 47 48 49 50 |
# File 'lib/verizon/models/asynchronous_request_resultforplanner.rb', line 42 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. request_id = hash.key?('requestId') ? hash['requestId'] : SKIP # Create object from extracted values. AsynchronousRequestResultforplanner.new(request_id) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/verizon/models/asynchronous_request_resultforplanner.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['request_id'] = 'requestId' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 34 35 |
# File 'lib/verizon/models/asynchronous_request_resultforplanner.rb', line 31 def self.nullables %w[ request_id ] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 27 28 |
# File 'lib/verizon/models/asynchronous_request_resultforplanner.rb', line 24 def self.optionals %w[ request_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
59 60 61 62 |
# File 'lib/verizon/models/asynchronous_request_resultforplanner.rb', line 59 def inspect class_name = self.class.name.split('::').last "<#{class_name} request_id: #{@request_id.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
53 54 55 56 |
# File 'lib/verizon/models/asynchronous_request_resultforplanner.rb', line 53 def to_s class_name = self.class.name.split('::').last "<#{class_name} request_id: #{@request_id}>" end |