Class: Verizon::BillingCycle
- Defined in:
- lib/verizon/models/billing_cycle.rb
Overview
BillingCycle Model.
Instance Attribute Summary collapse
-
#month ⇒ String
TODO: Write general description for this method.
-
#year ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(year = SKIP, month = SKIP) ⇒ BillingCycle
constructor
A new instance of BillingCycle.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(year = SKIP, month = SKIP) ⇒ BillingCycle
Returns a new instance of BillingCycle.
41 42 43 44 |
# File 'lib/verizon/models/billing_cycle.rb', line 41 def initialize(year = SKIP, month = SKIP) @year = year unless year == SKIP @month = month unless month == SKIP end |
Instance Attribute Details
#month ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/verizon/models/billing_cycle.rb', line 18 def month @month end |
#year ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/verizon/models/billing_cycle.rb', line 14 def year @year end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/verizon/models/billing_cycle.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. year = hash.key?('year') ? hash['year'] : SKIP month = hash.key?('month') ? hash['month'] : SKIP # Create object from extracted values. BillingCycle.new(year, month) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/verizon/models/billing_cycle.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['year'] = 'year' @_hash['month'] = 'month' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/verizon/models/billing_cycle.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/verizon/models/billing_cycle.rb', line 29 def self.optionals %w[ year month ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 |
# File 'lib/verizon/models/billing_cycle.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} year: #{@year.inspect}, month: #{@month.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/verizon/models/billing_cycle.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} year: #{@year}, month: #{@month}>" end |