Class: Verizon::CallbackActionResult
- Defined in:
- lib/verizon/models/callback_action_result.rb
Overview
Response to a callback action.
Instance Attribute Summary collapse
-
#account_name ⇒ String
The name of the billing account.
-
#service_name ⇒ String
The name of the callback service that was registered/deregistered.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(account_name = SKIP, service_name = SKIP) ⇒ CallbackActionResult
constructor
A new instance of CallbackActionResult.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(account_name = SKIP, service_name = SKIP) ⇒ CallbackActionResult
Returns a new instance of CallbackActionResult.
41 42 43 44 |
# File 'lib/verizon/models/callback_action_result.rb', line 41 def initialize(account_name = SKIP, service_name = SKIP) @account_name = account_name unless account_name == SKIP @service_name = service_name unless service_name == SKIP end |
Instance Attribute Details
#account_name ⇒ String
The name of the billing account.
14 15 16 |
# File 'lib/verizon/models/callback_action_result.rb', line 14 def account_name @account_name end |
#service_name ⇒ String
The name of the callback service that was registered/deregistered.
18 19 20 |
# File 'lib/verizon/models/callback_action_result.rb', line 18 def service_name @service_name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/verizon/models/callback_action_result.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. account_name = hash.key?('accountName') ? hash['accountName'] : SKIP service_name = hash.key?('serviceName') ? hash['serviceName'] : SKIP # Create object from extracted values. CallbackActionResult.new(account_name, service_name) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/verizon/models/callback_action_result.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['account_name'] = 'accountName' @_hash['service_name'] = 'serviceName' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/verizon/models/callback_action_result.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/verizon/models/callback_action_result.rb', line 29 def self.optionals %w[ account_name service_name ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 70 |
# File 'lib/verizon/models/callback_action_result.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name.inspect}, service_name:"\ " #{@service_name.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/verizon/models/callback_action_result.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name}, service_name: #{@service_name}>" end |