Class: Verizon::CallbackCreated

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/callback_created.rb

Overview

CallbackCreated Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(account_name = nil, name = nil, url = SKIP) ⇒ CallbackCreated

Returns a new instance of CallbackCreated.



47
48
49
50
51
# File 'lib/verizon/models/callback_created.rb', line 47

def initialize( = nil, name = nil, url = SKIP)
  @account_name = 
  @name = name
  @url = url unless url == SKIP
end

Instance Attribute Details

#account_nameString

The numeric name of the account and must include leading zeroes.

Returns:

  • (String)


14
15
16
# File 'lib/verizon/models/callback_created.rb', line 14

def 
  @account_name
end

#nameString

The name of the callback service, which identifies the type and format of messages that will be sent to the registered URL.

Returns:

  • (String)


19
20
21
# File 'lib/verizon/models/callback_created.rb', line 19

def name
  @name
end

#urlString

The address of the callback listening service where the ThingSpace Platform will send callback messages for the service type.

Returns:

  • (String)


24
25
26
# File 'lib/verizon/models/callback_created.rb', line 24

def url
  @url
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/verizon/models/callback_created.rb', line 54

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
   = hash.key?('accountName') ? hash['accountName'] : nil
  name = hash.key?('name') ? hash['name'] : nil
  url = hash.key?('url') ? hash['url'] : SKIP

  # Create object from extracted values.
  CallbackCreated.new(,
                      name,
                      url)
end

.namesObject

A mapping from model property names to API property names.



27
28
29
30
31
32
33
# File 'lib/verizon/models/callback_created.rb', line 27

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['account_name'] = 'accountName'
  @_hash['name'] = 'name'
  @_hash['url'] = 'url'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/verizon/models/callback_created.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



36
37
38
39
40
# File 'lib/verizon/models/callback_created.rb', line 36

def self.optionals
  %w[
    url
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



75
76
77
78
79
# File 'lib/verizon/models/callback_created.rb', line 75

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} account_name: #{@account_name.inspect}, name: #{@name.inspect}, url:"\
  " #{@url.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



69
70
71
72
# File 'lib/verizon/models/callback_created.rb', line 69

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} account_name: #{@account_name}, name: #{@name}, url: #{@url}>"
end