Class: Verizon::Carriercode1

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/carriercode1.rb

Overview

Carriercode1 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(carrier_code = SKIP, percentage = SKIP) ⇒ Carriercode1

Returns a new instance of Carriercode1.



41
42
43
44
# File 'lib/verizon/models/carriercode1.rb', line 41

def initialize(carrier_code = SKIP, percentage = SKIP)
  @carrier_code = carrier_code unless carrier_code == SKIP
  @percentage = percentage unless percentage == SKIP
end

Instance Attribute Details

#carrier_codeString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/verizon/models/carriercode1.rb', line 14

def carrier_code
  @carrier_code
end

#percentageAllowanceThreshold

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/verizon/models/carriercode1.rb', line 18

def percentage
  @percentage
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



47
48
49
50
51
52
53
54
55
56
57
# File 'lib/verizon/models/carriercode1.rb', line 47

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  carrier_code = hash.key?('carrierCode') ? hash['carrierCode'] : SKIP
  percentage = AllowanceThreshold.from_hash(hash['percentage']) if hash['percentage']

  # Create object from extracted values.
  Carriercode1.new(carrier_code,
                   percentage)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/verizon/models/carriercode1.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['carrier_code'] = 'carrierCode'
  @_hash['percentage'] = 'percentage'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/verizon/models/carriercode1.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/verizon/models/carriercode1.rb', line 29

def self.optionals
  %w[
    carrier_code
    percentage
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (Carriercode1 | Hash)

    value against the validation is performed.



61
62
63
64
65
66
67
# File 'lib/verizon/models/carriercode1.rb', line 61

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



76
77
78
79
80
# File 'lib/verizon/models/carriercode1.rb', line 76

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} carrier_code: #{@carrier_code.inspect}, percentage:"\
  " #{@percentage.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



70
71
72
73
# File 'lib/verizon/models/carriercode1.rb', line 70

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} carrier_code: #{@carrier_code}, percentage: #{@percentage}>"
end