Class: Verizon::ChangeConfigurationRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::ChangeConfigurationRequest
- Defined in:
- lib/verizon/models/change_configuration_request.rb
Overview
The request body identifies the device and the values to set.
Instance Attribute Summary collapse
-
#accountidentifier ⇒ AccountIdentifier
The ID of the authenticating billing account, in the format ‘“billingaccountid”:“1234567890-12345”`.
-
#configuration ⇒ Configuration
List of the field names and values to set.
-
#resourceidentifier ⇒ ResourceIdentifier
The ID of the target to delete, in the format “dd1682d3-2d80-cefc-f3ee-25154800beff”.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(accountidentifier = SKIP, resourceidentifier = SKIP, configuration = SKIP) ⇒ ChangeConfigurationRequest
constructor
A new instance of ChangeConfigurationRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(accountidentifier = SKIP, resourceidentifier = SKIP, configuration = SKIP) ⇒ ChangeConfigurationRequest
Returns a new instance of ChangeConfigurationRequest.
49 50 51 52 53 54 |
# File 'lib/verizon/models/change_configuration_request.rb', line 49 def initialize(accountidentifier = SKIP, resourceidentifier = SKIP, configuration = SKIP) @accountidentifier = accountidentifier unless accountidentifier == SKIP @resourceidentifier = resourceidentifier unless resourceidentifier == SKIP @configuration = configuration unless configuration == SKIP end |
Instance Attribute Details
#accountidentifier ⇒ AccountIdentifier
The ID of the authenticating billing account, in the format ‘“billingaccountid”:“1234567890-12345”`.
15 16 17 |
# File 'lib/verizon/models/change_configuration_request.rb', line 15 def accountidentifier @accountidentifier end |
#configuration ⇒ Configuration
List of the field names and values to set.
24 25 26 |
# File 'lib/verizon/models/change_configuration_request.rb', line 24 def configuration @configuration end |
#resourceidentifier ⇒ ResourceIdentifier
The ID of the target to delete, in the format “dd1682d3-2d80-cefc-f3ee-25154800beff”.
20 21 22 |
# File 'lib/verizon/models/change_configuration_request.rb', line 20 def resourceidentifier @resourceidentifier end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/verizon/models/change_configuration_request.rb', line 57 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. accountidentifier = AccountIdentifier.from_hash(hash['accountidentifier']) if hash['accountidentifier'] resourceidentifier = ResourceIdentifier.from_hash(hash['resourceidentifier']) if hash['resourceidentifier'] configuration = Configuration.from_hash(hash['configuration']) if hash['configuration'] # Create object from extracted values. ChangeConfigurationRequest.new(accountidentifier, resourceidentifier, configuration) end |
.names ⇒ Object
A mapping from model property names to API property names.
27 28 29 30 31 32 33 |
# File 'lib/verizon/models/change_configuration_request.rb', line 27 def self.names @_hash = {} if @_hash.nil? @_hash['accountidentifier'] = 'accountidentifier' @_hash['resourceidentifier'] = 'resourceidentifier' @_hash['configuration'] = 'configuration' @_hash end |
.nullables ⇒ Object
An array for nullable fields
45 46 47 |
# File 'lib/verizon/models/change_configuration_request.rb', line 45 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
36 37 38 39 40 41 42 |
# File 'lib/verizon/models/change_configuration_request.rb', line 36 def self.optionals %w[ accountidentifier resourceidentifier configuration ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
81 82 83 84 85 |
# File 'lib/verizon/models/change_configuration_request.rb', line 81 def inspect class_name = self.class.name.split('::').last "<#{class_name} accountidentifier: #{@accountidentifier.inspect}, resourceidentifier:"\ " #{@resourceidentifier.inspect}, configuration: #{@configuration.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
74 75 76 77 78 |
# File 'lib/verizon/models/change_configuration_request.rb', line 74 def to_s class_name = self.class.name.split('::').last "<#{class_name} accountidentifier: #{@accountidentifier}, resourceidentifier:"\ " #{@resourceidentifier}, configuration: #{@configuration}>" end |