Class: Verizon::ConditionObjectCall
- Defined in:
- lib/verizon/models/condition_object_call.rb
Overview
ConditionObjectCall Model.
Instance Attribute Summary collapse
-
#allowance_threshold ⇒ AllowanceThreshold
The interval to monitor for the threshold.
-
#comparitor ⇒ ComparitorEnum
The boolean of the comparison.
-
#condition_type ⇒ ConditionTypeEnum
The condition type being monitored.
-
#cycle_type ⇒ RulesCycleTypeEnum
The interval to monitor for the threshold.
-
#threshold ⇒ Integer
The threshold value the trigger monitors for.
-
#threshold_unit ⇒ ThresholdUnitEnum
The units of the threshold.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(condition_type = SKIP, comparitor = SKIP, threshold = SKIP, threshold_unit = SKIP, cycle_type = SKIP, allowance_threshold = SKIP) ⇒ ConditionObjectCall
constructor
A new instance of ConditionObjectCall.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(condition_type = SKIP, comparitor = SKIP, threshold = SKIP, threshold_unit = SKIP, cycle_type = SKIP, allowance_threshold = SKIP) ⇒ ConditionObjectCall
Returns a new instance of ConditionObjectCall.
69 70 71 72 73 74 75 76 77 78 |
# File 'lib/verizon/models/condition_object_call.rb', line 69 def initialize(condition_type = SKIP, comparitor = SKIP, threshold = SKIP, threshold_unit = SKIP, cycle_type = SKIP, allowance_threshold = SKIP) @condition_type = condition_type unless condition_type == SKIP @comparitor = comparitor unless comparitor == SKIP @threshold = threshold unless threshold == SKIP @threshold_unit = threshold_unit unless threshold_unit == SKIP @cycle_type = cycle_type unless cycle_type == SKIP @allowance_threshold = allowance_threshold unless allowance_threshold == SKIP end |
Instance Attribute Details
#allowance_threshold ⇒ AllowanceThreshold
The interval to monitor for the threshold. This can be Daily, Weekly or Monthly
38 39 40 |
# File 'lib/verizon/models/condition_object_call.rb', line 38 def allowance_threshold @allowance_threshold end |
#comparitor ⇒ ComparitorEnum
The boolean of the comparison. ‘gt` is Greater Than, `lt` is Less Than and `eq` is Equal To
19 20 21 |
# File 'lib/verizon/models/condition_object_call.rb', line 19 def comparitor @comparitor end |
#condition_type ⇒ ConditionTypeEnum
The condition type being monitored
14 15 16 |
# File 'lib/verizon/models/condition_object_call.rb', line 14 def condition_type @condition_type end |
#cycle_type ⇒ RulesCycleTypeEnum
The interval to monitor for the threshold. This can be Daily, Weekly or Monthly
33 34 35 |
# File 'lib/verizon/models/condition_object_call.rb', line 33 def cycle_type @cycle_type end |
#threshold ⇒ Integer
The threshold value the trigger monitors for
23 24 25 |
# File 'lib/verizon/models/condition_object_call.rb', line 23 def threshold @threshold end |
#threshold_unit ⇒ ThresholdUnitEnum
The units of the threshold. This can be KB, Kilobits, MB, Megabits, or GB, Gigabits
28 29 30 |
# File 'lib/verizon/models/condition_object_call.rb', line 28 def threshold_unit @threshold_unit end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/verizon/models/condition_object_call.rb', line 81 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. condition_type = hash.key?('conditionType') ? hash['conditionType'] : SKIP comparitor = hash.key?('comparitor') ? hash['comparitor'] : SKIP threshold = hash.key?('threshold') ? hash['threshold'] : SKIP threshold_unit = hash.key?('thresholdUnit') ? hash['thresholdUnit'] : SKIP cycle_type = hash.key?('cycleType') ? hash['cycleType'] : SKIP allowance_threshold = AllowanceThreshold.from_hash(hash['allowanceThreshold']) if hash['allowanceThreshold'] # Create object from extracted values. ConditionObjectCall.new(condition_type, comparitor, threshold, threshold_unit, cycle_type, allowance_threshold) end |
.names ⇒ Object
A mapping from model property names to API property names.
41 42 43 44 45 46 47 48 49 50 |
# File 'lib/verizon/models/condition_object_call.rb', line 41 def self.names @_hash = {} if @_hash.nil? @_hash['condition_type'] = 'conditionType' @_hash['comparitor'] = 'comparitor' @_hash['threshold'] = 'threshold' @_hash['threshold_unit'] = 'thresholdUnit' @_hash['cycle_type'] = 'cycleType' @_hash['allowance_threshold'] = 'allowanceThreshold' @_hash end |
.nullables ⇒ Object
An array for nullable fields
65 66 67 |
# File 'lib/verizon/models/condition_object_call.rb', line 65 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
53 54 55 56 57 58 59 60 61 62 |
# File 'lib/verizon/models/condition_object_call.rb', line 53 def self.optionals %w[ condition_type comparitor threshold threshold_unit cycle_type allowance_threshold ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
104 105 106 107 108 109 110 |
# File 'lib/verizon/models/condition_object_call.rb', line 104 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
121 122 123 124 125 126 127 |
# File 'lib/verizon/models/condition_object_call.rb', line 121 def inspect class_name = self.class.name.split('::').last "<#{class_name} condition_type: #{@condition_type.inspect}, comparitor:"\ " #{@comparitor.inspect}, threshold: #{@threshold.inspect}, threshold_unit:"\ " #{@threshold_unit.inspect}, cycle_type: #{@cycle_type.inspect}, allowance_threshold:"\ " #{@allowance_threshold.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
113 114 115 116 117 118 |
# File 'lib/verizon/models/condition_object_call.rb', line 113 def to_s class_name = self.class.name.split('::').last "<#{class_name} condition_type: #{@condition_type}, comparitor: #{@comparitor}, threshold:"\ " #{@threshold}, threshold_unit: #{@threshold_unit}, cycle_type: #{@cycle_type},"\ " allowance_threshold: #{@allowance_threshold}>" end |