Class: Verizon::ConsentDeleteRequest
- Defined in:
- lib/verizon/models/consent_delete_request.rb
Overview
ConsentDeleteRequest Model.
Instance Attribute Summary collapse
-
#account_name ⇒ String
Account identifier.
-
#device_list ⇒ Array[String]
Device ID list.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(account_name = SKIP, device_list = SKIP) ⇒ ConsentDeleteRequest
constructor
A new instance of ConsentDeleteRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(account_name = SKIP, device_list = SKIP) ⇒ ConsentDeleteRequest
Returns a new instance of ConsentDeleteRequest.
41 42 43 44 |
# File 'lib/verizon/models/consent_delete_request.rb', line 41 def initialize(account_name = SKIP, device_list = SKIP) @account_name = account_name unless account_name == SKIP @device_list = device_list unless device_list == SKIP end |
Instance Attribute Details
#account_name ⇒ String
Account identifier.
14 15 16 |
# File 'lib/verizon/models/consent_delete_request.rb', line 14 def account_name @account_name end |
#device_list ⇒ Array[String]
Device ID list.
18 19 20 |
# File 'lib/verizon/models/consent_delete_request.rb', line 18 def device_list @device_list end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/verizon/models/consent_delete_request.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. account_name = hash.key?('accountName') ? hash['accountName'] : SKIP device_list = hash.key?('deviceList') ? hash['deviceList'] : SKIP # Create object from extracted values. ConsentDeleteRequest.new(account_name, device_list) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/verizon/models/consent_delete_request.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['account_name'] = 'accountName' @_hash['device_list'] = 'deviceList' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/verizon/models/consent_delete_request.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/verizon/models/consent_delete_request.rb', line 29 def self.optionals %w[ account_name device_list ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 70 |
# File 'lib/verizon/models/consent_delete_request.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name.inspect}, device_list:"\ " #{@device_list.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/verizon/models/consent_delete_request.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name}, device_list: #{@device_list}>" end |