Class: Verizon::Content1
- Defined in:
- lib/verizon/models/content1.rb
Overview
Content1 Model.
Instance Attribute Summary collapse
-
#work_zone ⇒ Array[Object]
List of work zone signs and directions.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(work_zone = nil) ⇒ Content1
constructor
A new instance of Content1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(work_zone = nil) ⇒ Content1
Returns a new instance of Content1.
33 34 35 |
# File 'lib/verizon/models/content1.rb', line 33 def initialize(work_zone = nil) @work_zone = work_zone end |
Instance Attribute Details
#work_zone ⇒ Array[Object]
List of work zone signs and directions.
14 15 16 |
# File 'lib/verizon/models/content1.rb', line 14 def work_zone @work_zone end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
38 39 40 41 42 43 44 45 46 47 48 |
# File 'lib/verizon/models/content1.rb', line 38 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. work_zone = hash.key?('workZone') ? APIHelper.deserialize_union_type( UnionTypeLookUp.get(:TextPhraseOrITIS2), hash['workZone'] ) : nil # Create object from extracted values. Content1.new(work_zone) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/verizon/models/content1.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['work_zone'] = 'workZone' @_hash end |
.nullables ⇒ Object
An array for nullable fields
29 30 31 |
# File 'lib/verizon/models/content1.rb', line 29 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 |
# File 'lib/verizon/models/content1.rb', line 24 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/verizon/models/content1.rb', line 52 def self.validate(value) if value.instance_of? self return UnionTypeLookUp.get(:TextPhraseOrITIS2) .validate(value.work_zone) end return false unless value.instance_of? Hash UnionTypeLookUp.get(:TextPhraseOrITIS2) .validate(value['workZone']) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
71 72 73 74 |
# File 'lib/verizon/models/content1.rb', line 71 def inspect class_name = self.class.name.split('::').last "<#{class_name} work_zone: #{@work_zone.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
65 66 67 68 |
# File 'lib/verizon/models/content1.rb', line 65 def to_s class_name = self.class.name.split('::').last "<#{class_name} work_zone: #{@work_zone}>" end |