Class: Verizon::Content3

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/content3.rb

Overview

Content3 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(speed_limit = nil) ⇒ Content3

Returns a new instance of Content3.



33
34
35
# File 'lib/verizon/models/content3.rb', line 33

def initialize(speed_limit = nil)
  @speed_limit = speed_limit
end

Instance Attribute Details

#speed_limitArray[Object]

List of speed limits and cautions.

Returns:

  • (Array[Object])


14
15
16
# File 'lib/verizon/models/content3.rb', line 14

def speed_limit
  @speed_limit
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



38
39
40
41
42
43
44
45
46
47
48
# File 'lib/verizon/models/content3.rb', line 38

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  speed_limit = hash.key?('speedLimit') ? APIHelper.deserialize_union_type(
    UnionTypeLookUp.get(:TextPhraseOrITIS2), hash['speedLimit']
  ) : nil

  # Create object from extracted values.
  Content3.new(speed_limit)
end

.namesObject

A mapping from model property names to API property names.



17
18
19
20
21
# File 'lib/verizon/models/content3.rb', line 17

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['speed_limit'] = 'speedLimit'
  @_hash
end

.nullablesObject

An array for nullable fields



29
30
31
# File 'lib/verizon/models/content3.rb', line 29

def self.nullables
  []
end

.optionalsObject

An array for optional fields



24
25
26
# File 'lib/verizon/models/content3.rb', line 24

def self.optionals
  []
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (Content3 | Hash)

    value against the validation is performed.



52
53
54
55
56
57
58
59
60
61
62
# File 'lib/verizon/models/content3.rb', line 52

def self.validate(value)
  if value.instance_of? self
    return UnionTypeLookUp.get(:TextPhraseOrITIS2)
                          .validate(value.speed_limit)
  end

  return false unless value.instance_of? Hash

  UnionTypeLookUp.get(:TextPhraseOrITIS2)
                 .validate(value['speedLimit'])
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



71
72
73
74
# File 'lib/verizon/models/content3.rb', line 71

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} speed_limit: #{@speed_limit.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



65
66
67
68
# File 'lib/verizon/models/content3.rb', line 65

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} speed_limit: #{@speed_limit}>"
end