Class: Verizon::CreateTargetRequestFields
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::CreateTargetRequestFields
- Defined in:
- lib/verizon/models/create_target_request_fields.rb
Overview
CreateTargetRequestFields Model.
Instance Attribute Summary collapse
-
#devicetypes ⇒ Array[String]
List of device types.
-
#httpheaders ⇒ FieldsHttpHeaders
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(httpheaders = SKIP, devicetypes = SKIP) ⇒ CreateTargetRequestFields
constructor
A new instance of CreateTargetRequestFields.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(httpheaders = SKIP, devicetypes = SKIP) ⇒ CreateTargetRequestFields
Returns a new instance of CreateTargetRequestFields.
41 42 43 44 |
# File 'lib/verizon/models/create_target_request_fields.rb', line 41 def initialize(httpheaders = SKIP, devicetypes = SKIP) @httpheaders = httpheaders unless httpheaders == SKIP @devicetypes = devicetypes unless devicetypes == SKIP end |
Instance Attribute Details
#devicetypes ⇒ Array[String]
List of device types.
18 19 20 |
# File 'lib/verizon/models/create_target_request_fields.rb', line 18 def devicetypes @devicetypes end |
#httpheaders ⇒ FieldsHttpHeaders
TODO: Write general description for this method
14 15 16 |
# File 'lib/verizon/models/create_target_request_fields.rb', line 14 def httpheaders @httpheaders end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/verizon/models/create_target_request_fields.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. httpheaders = FieldsHttpHeaders.from_hash(hash['httpheaders']) if hash['httpheaders'] devicetypes = hash.key?('devicetypes') ? hash['devicetypes'] : SKIP # Create object from extracted values. CreateTargetRequestFields.new(httpheaders, devicetypes) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/verizon/models/create_target_request_fields.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['httpheaders'] = 'httpheaders' @_hash['devicetypes'] = 'devicetypes' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/verizon/models/create_target_request_fields.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/verizon/models/create_target_request_fields.rb', line 29 def self.optionals %w[ httpheaders devicetypes ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 70 |
# File 'lib/verizon/models/create_target_request_fields.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} httpheaders: #{@httpheaders.inspect}, devicetypes:"\ " #{@devicetypes.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/verizon/models/create_target_request_fields.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} httpheaders: #{@httpheaders}, devicetypes: #{@devicetypes}>" end |