Class: Verizon::CredentialsRequest
- Defined in:
- lib/verizon/models/credentials_request.rb
Overview
CredentialsRequest Model.
Instance Attribute Summary collapse
-
#account_number ⇒ String
Billing Account Number.
-
#ecpd ⇒ String
Enterprise Customer Profile ID.
-
#items ⇒ Array[DeviceCredentialRequestItem]
List of devices (1-50 items).
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(ecpd = nil, account_number = nil, items = nil) ⇒ CredentialsRequest
constructor
A new instance of CredentialsRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(ecpd = nil, account_number = nil, items = nil) ⇒ CredentialsRequest
Returns a new instance of CredentialsRequest.
43 44 45 46 47 |
# File 'lib/verizon/models/credentials_request.rb', line 43 def initialize(ecpd = nil, account_number = nil, items = nil) @ecpd = ecpd @account_number = account_number @items = items end |
Instance Attribute Details
#account_number ⇒ String
Billing Account Number
18 19 20 |
# File 'lib/verizon/models/credentials_request.rb', line 18 def account_number @account_number end |
#ecpd ⇒ String
Enterprise Customer Profile ID
14 15 16 |
# File 'lib/verizon/models/credentials_request.rb', line 14 def ecpd @ecpd end |
#items ⇒ Array[DeviceCredentialRequestItem]
List of devices (1-50 items)
22 23 24 |
# File 'lib/verizon/models/credentials_request.rb', line 22 def items @items end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/verizon/models/credentials_request.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. ecpd = hash.key?('ECPD') ? hash['ECPD'] : nil account_number = hash.key?('accountNumber') ? hash['accountNumber'] : nil # Parameter is an array, so we need to iterate through it items = nil unless hash['items'].nil? items = [] hash['items'].each do |structure| items << (DeviceCredentialRequestItem.from_hash(structure) if structure) end end items = nil unless hash.key?('items') # Create object from extracted values. CredentialsRequest.new(ecpd, account_number, items) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/verizon/models/credentials_request.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['ecpd'] = 'ECPD' @_hash['account_number'] = 'accountNumber' @_hash['items'] = 'items' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/verizon/models/credentials_request.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 |
# File 'lib/verizon/models/credentials_request.rb', line 34 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
80 81 82 83 84 |
# File 'lib/verizon/models/credentials_request.rb', line 80 def inspect class_name = self.class.name.split('::').last "<#{class_name} ecpd: #{@ecpd.inspect}, account_number: #{@account_number.inspect}, items:"\ " #{@items.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
74 75 76 77 |
# File 'lib/verizon/models/credentials_request.rb', line 74 def to_s class_name = self.class.name.split('::').last "<#{class_name} ecpd: #{@ecpd}, account_number: #{@account_number}, items: #{@items}>" end |