Class: Verizon::CustomFields
- Defined in:
- lib/verizon/models/custom_fields.rb
Overview
Custom data that can be included using key-value pairs.
Instance Attribute Summary collapse
-
#key ⇒ String
The key for an extended attribute.
-
#value ⇒ String
The value of an extended attribute.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(key = nil, value = nil) ⇒ CustomFields
constructor
A new instance of CustomFields.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(key = nil, value = nil) ⇒ CustomFields
Returns a new instance of CustomFields.
38 39 40 41 |
# File 'lib/verizon/models/custom_fields.rb', line 38 def initialize(key = nil, value = nil) @key = key @value = value end |
Instance Attribute Details
#key ⇒ String
The key for an extended attribute.
14 15 16 |
# File 'lib/verizon/models/custom_fields.rb', line 14 def key @key end |
#value ⇒ String
The value of an extended attribute.
18 19 20 |
# File 'lib/verizon/models/custom_fields.rb', line 18 def value @value end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/verizon/models/custom_fields.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. key = hash.key?('key') ? hash['key'] : nil value = hash.key?('value') ? hash['value'] : nil # Create object from extracted values. CustomFields.new(key, value) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/verizon/models/custom_fields.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['key'] = 'key' @_hash['value'] = 'value' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/verizon/models/custom_fields.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/verizon/models/custom_fields.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
63 64 65 66 |
# File 'lib/verizon/models/custom_fields.rb', line 63 def inspect class_name = self.class.name.split('::').last "<#{class_name} key: #{@key.inspect}, value: #{@value.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
57 58 59 60 |
# File 'lib/verizon/models/custom_fields.rb', line 57 def to_s class_name = self.class.name.split('::').last "<#{class_name} key: #{@key}, value: #{@value}>" end |