Class: Verizon::DataPercentage75TriggerAttribute

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/data_percentage75_trigger_attribute.rb

Overview

Trigger attribute for when data percentage is over 75% used.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(key = SKIP, value = SKIP) ⇒ DataPercentage75TriggerAttribute

Returns a new instance of DataPercentage75TriggerAttribute.



42
43
44
45
# File 'lib/verizon/models/data_percentage75_trigger_attribute.rb', line 42

def initialize(key = SKIP, value = SKIP)
  @key = key unless key == SKIP
  @value = value unless value == SKIP
end

Instance Attribute Details

#keyString

Key data percentage 75.

Returns:

  • (String)


14
15
16
# File 'lib/verizon/models/data_percentage75_trigger_attribute.rb', line 14

def key
  @key
end

#valueTrueClass | FalseClass

DataPercentage75<br />True - Trigger on Data percentage is over 75% used<br />False - Do not trigger when over 75% used.

Returns:

  • (TrueClass | FalseClass)


19
20
21
# File 'lib/verizon/models/data_percentage75_trigger_attribute.rb', line 19

def value
  @value
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



48
49
50
51
52
53
54
55
56
57
58
# File 'lib/verizon/models/data_percentage75_trigger_attribute.rb', line 48

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  key = hash.key?('key') ? hash['key'] : SKIP
  value = hash.key?('value') ? hash['value'] : SKIP

  # Create object from extracted values.
  DataPercentage75TriggerAttribute.new(key,
                                       value)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/verizon/models/data_percentage75_trigger_attribute.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['key'] = 'key'
  @_hash['value'] = 'value'
  @_hash
end

.nullablesObject

An array for nullable fields



38
39
40
# File 'lib/verizon/models/data_percentage75_trigger_attribute.rb', line 38

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
33
34
35
# File 'lib/verizon/models/data_percentage75_trigger_attribute.rb', line 30

def self.optionals
  %w[
    key
    value
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



62
63
64
65
66
67
68
# File 'lib/verizon/models/data_percentage75_trigger_attribute.rb', line 62

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



77
78
79
80
# File 'lib/verizon/models/data_percentage75_trigger_attribute.rb', line 77

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} key: #{@key.inspect}, value: #{@value.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



71
72
73
74
# File 'lib/verizon/models/data_percentage75_trigger_attribute.rb', line 71

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} key: #{@key}, value: #{@value}>"
end