Class: Verizon::DataTrigger4
- Defined in:
- lib/verizon/models/data_trigger4.rb
Overview
DataTrigger4 Model.
Instance Attribute Summary collapse
-
#account_level ⇒ AccountLevelObject
TODO: Write general description for this method.
-
#action ⇒ Actionobject
The interval to monitor for the threshold.
-
#allowance_threshold ⇒ AllowanceThreshold
The interval to monitor for the threshold.
-
#comparitor ⇒ ComparitorEnum
The boolean of the comparison.
-
#condition_type ⇒ ConditionTypeEnum
The condition type being monitored.
-
#cycle_type ⇒ RulesCycleTypeEnum
The interval to monitor for the threshold.
-
#device_group ⇒ DeviceGroupFilterCriteria
TODO: Write general description for this method.
-
#threshold ⇒ Integer
The threshold value the trigger monitors for.
-
#threshold_unit ⇒ ThresholdUnitEnum
The units of the threshold.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(account_level = SKIP, device_group = SKIP, condition_type = SKIP, comparitor = SKIP, threshold = SKIP, threshold_unit = SKIP, cycle_type = SKIP, allowance_threshold = SKIP, action = SKIP) ⇒ DataTrigger4
constructor
A new instance of DataTrigger4.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(account_level = SKIP, device_group = SKIP, condition_type = SKIP, comparitor = SKIP, threshold = SKIP, threshold_unit = SKIP, cycle_type = SKIP, allowance_threshold = SKIP, action = SKIP) ⇒ DataTrigger4
Returns a new instance of DataTrigger4.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/verizon/models/data_trigger4.rb', line 88 def initialize(account_level = SKIP, device_group = SKIP, condition_type = SKIP, comparitor = SKIP, threshold = SKIP, threshold_unit = SKIP, cycle_type = SKIP, allowance_threshold = SKIP, action = SKIP) @account_level = account_level unless account_level == SKIP @device_group = device_group unless device_group == SKIP @condition_type = condition_type unless condition_type == SKIP @comparitor = comparitor unless comparitor == SKIP @threshold = threshold unless threshold == SKIP @threshold_unit = threshold_unit unless threshold_unit == SKIP @cycle_type = cycle_type unless cycle_type == SKIP @allowance_threshold = allowance_threshold unless allowance_threshold == SKIP @action = action unless action == SKIP end |
Instance Attribute Details
#account_level ⇒ AccountLevelObject
TODO: Write general description for this method
14 15 16 |
# File 'lib/verizon/models/data_trigger4.rb', line 14 def account_level @account_level end |
#action ⇒ Actionobject
The interval to monitor for the threshold. This can be Daily, Weekly or Monthly
51 52 53 |
# File 'lib/verizon/models/data_trigger4.rb', line 51 def action @action end |
#allowance_threshold ⇒ AllowanceThreshold
The interval to monitor for the threshold. This can be Daily, Weekly or Monthly
46 47 48 |
# File 'lib/verizon/models/data_trigger4.rb', line 46 def allowance_threshold @allowance_threshold end |
#comparitor ⇒ ComparitorEnum
The boolean of the comparison. ‘gt` is Greater Than, `lt` is Less Than and `eq` is Equal To
27 28 29 |
# File 'lib/verizon/models/data_trigger4.rb', line 27 def comparitor @comparitor end |
#condition_type ⇒ ConditionTypeEnum
The condition type being monitored
22 23 24 |
# File 'lib/verizon/models/data_trigger4.rb', line 22 def condition_type @condition_type end |
#cycle_type ⇒ RulesCycleTypeEnum
The interval to monitor for the threshold. This can be Daily, Weekly or Monthly
41 42 43 |
# File 'lib/verizon/models/data_trigger4.rb', line 41 def cycle_type @cycle_type end |
#device_group ⇒ DeviceGroupFilterCriteria
TODO: Write general description for this method
18 19 20 |
# File 'lib/verizon/models/data_trigger4.rb', line 18 def device_group @device_group end |
#threshold ⇒ Integer
The threshold value the trigger monitors for
31 32 33 |
# File 'lib/verizon/models/data_trigger4.rb', line 31 def threshold @threshold end |
#threshold_unit ⇒ ThresholdUnitEnum
The units of the threshold. This can be KB, Kilobits, MB, Megabits, or GB, Gigabits
36 37 38 |
# File 'lib/verizon/models/data_trigger4.rb', line 36 def threshold_unit @threshold_unit end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/verizon/models/data_trigger4.rb', line 104 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. account_level = AccountLevelObject.from_hash(hash['accountLevel']) if hash['accountLevel'] device_group = DeviceGroupFilterCriteria.from_hash(hash['deviceGroup']) if hash['deviceGroup'] condition_type = hash.key?('conditionType') ? hash['conditionType'] : SKIP comparitor = hash.key?('comparitor') ? hash['comparitor'] : SKIP threshold = hash.key?('threshold') ? hash['threshold'] : SKIP threshold_unit = hash.key?('thresholdUnit') ? hash['thresholdUnit'] : SKIP cycle_type = hash.key?('cycleType') ? hash['cycleType'] : SKIP allowance_threshold = AllowanceThreshold.from_hash(hash['allowanceThreshold']) if hash['allowanceThreshold'] action = Actionobject.from_hash(hash['action']) if hash['action'] # Create object from extracted values. DataTrigger4.new(account_level, device_group, condition_type, comparitor, threshold, threshold_unit, cycle_type, allowance_threshold, action) end |
.names ⇒ Object
A mapping from model property names to API property names.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/verizon/models/data_trigger4.rb', line 54 def self.names @_hash = {} if @_hash.nil? @_hash['account_level'] = 'accountLevel' @_hash['device_group'] = 'deviceGroup' @_hash['condition_type'] = 'conditionType' @_hash['comparitor'] = 'comparitor' @_hash['threshold'] = 'threshold' @_hash['threshold_unit'] = 'thresholdUnit' @_hash['cycle_type'] = 'cycleType' @_hash['allowance_threshold'] = 'allowanceThreshold' @_hash['action'] = 'action' @_hash end |
.nullables ⇒ Object
An array for nullable fields
84 85 86 |
# File 'lib/verizon/models/data_trigger4.rb', line 84 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/verizon/models/data_trigger4.rb', line 69 def self.optionals %w[ account_level device_group condition_type comparitor threshold threshold_unit cycle_type allowance_threshold action ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
134 135 136 137 138 139 140 |
# File 'lib/verizon/models/data_trigger4.rb', line 134 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
152 153 154 155 156 157 158 159 |
# File 'lib/verizon/models/data_trigger4.rb', line 152 def inspect class_name = self.class.name.split('::').last "<#{class_name} account_level: #{@account_level.inspect}, device_group:"\ " #{@device_group.inspect}, condition_type: #{@condition_type.inspect}, comparitor:"\ " #{@comparitor.inspect}, threshold: #{@threshold.inspect}, threshold_unit:"\ " #{@threshold_unit.inspect}, cycle_type: #{@cycle_type.inspect}, allowance_threshold:"\ " #{@allowance_threshold.inspect}, action: #{@action.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
143 144 145 146 147 148 149 |
# File 'lib/verizon/models/data_trigger4.rb', line 143 def to_s class_name = self.class.name.split('::').last "<#{class_name} account_level: #{@account_level}, device_group: #{@device_group},"\ " condition_type: #{@condition_type}, comparitor: #{@comparitor}, threshold: #{@threshold},"\ " threshold_unit: #{@threshold_unit}, cycle_type: #{@cycle_type}, allowance_threshold:"\ " #{@allowance_threshold}, action: #{@action}>" end |