Class: Verizon::DateFilter
- Defined in:
- lib/verizon/models/date_filter.rb
Overview
Filter out the dates.
Instance Attribute Summary collapse
-
#earliest ⇒ String
Only include devices that were added after this date and time.
-
#latest ⇒ String
Only include devices that were added before this date and time.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(earliest = nil, latest = nil) ⇒ DateFilter
constructor
A new instance of DateFilter.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(earliest = nil, latest = nil) ⇒ DateFilter
Returns a new instance of DateFilter.
38 39 40 41 |
# File 'lib/verizon/models/date_filter.rb', line 38 def initialize(earliest = nil, latest = nil) @earliest = earliest @latest = latest end |
Instance Attribute Details
#earliest ⇒ String
Only include devices that were added after this date and time.
14 15 16 |
# File 'lib/verizon/models/date_filter.rb', line 14 def earliest @earliest end |
#latest ⇒ String
Only include devices that were added before this date and time.
18 19 20 |
# File 'lib/verizon/models/date_filter.rb', line 18 def latest @latest end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/verizon/models/date_filter.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. earliest = hash.key?('earliest') ? hash['earliest'] : nil latest = hash.key?('latest') ? hash['latest'] : nil # Create object from extracted values. DateFilter.new(earliest, latest) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/verizon/models/date_filter.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['earliest'] = 'earliest' @_hash['latest'] = 'latest' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/verizon/models/date_filter.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/verizon/models/date_filter.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
63 64 65 66 |
# File 'lib/verizon/models/date_filter.rb', line 63 def inspect class_name = self.class.name.split('::').last "<#{class_name} earliest: #{@earliest.inspect}, latest: #{@latest.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
57 58 59 60 |
# File 'lib/verizon/models/date_filter.rb', line 57 def to_s class_name = self.class.name.split('::').last "<#{class_name} earliest: #{@earliest}, latest: #{@latest}>" end |