Class: Verizon::DescriptionOfRoadSurfaceCinders
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::DescriptionOfRoadSurfaceCinders
- Defined in:
- lib/verizon/models/description_of_road_surface_cinders.rb
Overview
DescriptionOfRoadSurfaceCinders Model.
Instance Attribute Summary collapse
-
#cinders ⇒ Cinders
Indicates the surface of the roadway is cinders.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(cinders = nil) ⇒ DescriptionOfRoadSurfaceCinders
constructor
A new instance of DescriptionOfRoadSurfaceCinders.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(cinders = nil) ⇒ DescriptionOfRoadSurfaceCinders
Returns a new instance of DescriptionOfRoadSurfaceCinders.
33 34 35 |
# File 'lib/verizon/models/description_of_road_surface_cinders.rb', line 33 def initialize(cinders = nil) @cinders = cinders end |
Instance Attribute Details
#cinders ⇒ Cinders
Indicates the surface of the roadway is cinders.
14 15 16 |
# File 'lib/verizon/models/description_of_road_surface_cinders.rb', line 14 def cinders @cinders end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
38 39 40 41 42 43 44 45 46 |
# File 'lib/verizon/models/description_of_road_surface_cinders.rb', line 38 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. cinders = Cinders.from_hash(hash['cinders']) if hash['cinders'] # Create object from extracted values. DescriptionOfRoadSurfaceCinders.new(cinders) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/verizon/models/description_of_road_surface_cinders.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['cinders'] = 'cinders' @_hash end |
.nullables ⇒ Object
An array for nullable fields
29 30 31 |
# File 'lib/verizon/models/description_of_road_surface_cinders.rb', line 29 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 |
# File 'lib/verizon/models/description_of_road_surface_cinders.rb', line 24 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/verizon/models/description_of_road_surface_cinders.rb', line 50 def self.validate(value) if value.instance_of? self return APIHelper.valid_type?(value.cinders, ->(val) { Cinders.validate(val) }, is_model_hash: true) end return false unless value.instance_of? Hash APIHelper.valid_type?(value['cinders'], ->(val) { Cinders.validate(val) }, is_model_hash: true) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
71 72 73 74 |
# File 'lib/verizon/models/description_of_road_surface_cinders.rb', line 71 def inspect class_name = self.class.name.split('::').last "<#{class_name} cinders: #{@cinders.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
65 66 67 68 |
# File 'lib/verizon/models/description_of_road_surface_cinders.rb', line 65 def to_s class_name = self.class.name.split('::').last "<#{class_name} cinders: #{@cinders}>" end |