Class: Verizon::DeviceActionsController

Inherits:
BaseController show all
Defined in:
lib/verizon/controllers/device_actions_controller.rb

Overview

DeviceActionsController

Constant Summary

Constants inherited from BaseController

BaseController::GLOBAL_ERRORS

Instance Attribute Summary

Attributes inherited from BaseController

#config, #http_call_back

Instance Method Summary collapse

Methods inherited from BaseController

#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent

Constructor Details

This class inherits a constructor from Verizon::BaseController

Instance Method Details

#account_information(account_name) ⇒ ApiResponse

Retrieve all of the service plans, features and carriers associated with the account specified. here

Parameters:

  • account_name (String)

    Required parameter: TODO: type description

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/verizon/controllers/device_actions_controller.rb', line 86

def ()
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/v1/accounts/{accountName}',
                                 Server::THINGSPACE)
               .template_param(new_parameter(, key: 'accountName')
                                .should_encode(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(AccountDetails.method(:from_hash))
                .is_api_response(true)
                .local_error('default',
                             'Error response',
                             GIORestErrorResponseException))
    .execute
end

#aggregate_usage(body) ⇒ ApiResponse

Retrieve the aggregate usage for a device or a number of devices. here

Parameters:

  • body (AggregateUsage)

    Required parameter: TODO: type description

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
# File 'lib/verizon/controllers/device_actions_controller.rb', line 13

def aggregate_usage(body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/v1/devices/usage/actions/list/aggregate',
                                 Server::THINGSPACE)
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(GIORequestResponse.method(:from_hash))
                .is_api_response(true)
                .local_error('default',
                             'Error response',
                             GIORestErrorResponseException))
    .execute
end

#daily_usage(body) ⇒ ApiResponse

Retrieve the daily usage for a device, for a specified period of time, segmented by day

Parameters:

  • body (DailyUsage)

    Required parameter: TODO: type description here

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/verizon/controllers/device_actions_controller.rb', line 37

def daily_usage(body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/v1/devices/usage/actions/list',
                                 Server::THINGSPACE)
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(DailyUsageResponse.method(:from_hash))
                .is_api_response(true)
                .local_error('default',
                             'Error response',
                             GIORestErrorResponseException))
    .execute
end

#get_asynchronous_request_status(account_name, request_id) ⇒ ApiResponse

Get the status of an asynchronous request made with the Device Actions. here here

Parameters:

  • account_name (String)

    Required parameter: TODO: type description

  • request_id (String)

    Required parameter: TODO: type description

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/verizon/controllers/device_actions_controller.rb', line 160

def get_asynchronous_request_status(,
                                    request_id)
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/m2m/v2/accounts/{accountName}/requests/{requestID}/status',
                                 Server::THINGSPACE)
               .template_param(new_parameter(, key: 'accountName')
                                .should_encode(true))
               .template_param(new_parameter(request_id, key: 'requestID')
                                .should_encode(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(StatusResponse.method(:from_hash))
                .is_api_response(true)
                .local_error('default',
                             'Error response',
                             GIORestErrorResponseException))
    .execute
end

#retrieve_device_provisioning_history(body) ⇒ ApiResponse

Retrieve the provisioning history of a specific device or devices. History

Parameters:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/verizon/controllers/device_actions_controller.rb', line 134

def retrieve_device_provisioning_history(body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/m2m/v2/devices/history/actions/list',
                                 Server::THINGSPACE)
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(GIORequestResponse.method(:from_hash))
                .is_api_response(true)
                .local_error('default',
                             'Error response',
                             GIORestErrorResponseException))
    .execute
end

#retrieve_the_global_device_list(body) ⇒ ApiResponse

Allows the profile to fetch the complete device list. This works with Verizon US and Global profiles. Profile Query

Parameters:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/verizon/controllers/device_actions_controller.rb', line 110

def retrieve_the_global_device_list(body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/m2m/v2/devices/actions/list',
                                 Server::THINGSPACE)
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(GIORequestResponse.method(:from_hash))
                .is_api_response(true)
                .local_error('default',
                             'Error response',
                             GIORestErrorResponseException))
    .execute
end

#service_plan_list(account_name) ⇒ ApiResponse

Retrieve all of the service plans, features and carriers associated with the account specified. here

Parameters:

  • account_name (String)

    Required parameter: TODO: type description

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/verizon/controllers/device_actions_controller.rb', line 62

def service_plan_list()
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/v1/plans/{accountName}',
                                 Server::THINGSPACE)
               .template_param(new_parameter(, key: 'accountName')
                                .should_encode(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(AccountDetails.method(:from_hash))
                .is_api_response(true)
                .local_error('default',
                             'Error response',
                             GIORestErrorResponseException))
    .execute
end