Class: Verizon::DeviceIdforplanner
- Defined in:
- lib/verizon/models/device_idforplanner.rb
Overview
DeviceIdforplanner Model.
Instance Attribute Summary collapse
-
#id ⇒ String
TODO: Write general description for this method.
-
#kind ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(kind = SKIP, id = SKIP) ⇒ DeviceIdforplanner
constructor
A new instance of DeviceIdforplanner.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(kind = SKIP, id = SKIP) ⇒ DeviceIdforplanner
Returns a new instance of DeviceIdforplanner.
44 45 46 47 |
# File 'lib/verizon/models/device_idforplanner.rb', line 44 def initialize(kind = SKIP, id = SKIP) @kind = kind unless kind == SKIP @id = id unless id == SKIP end |
Instance Attribute Details
#id ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/verizon/models/device_idforplanner.rb', line 18 def id @id end |
#kind ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/verizon/models/device_idforplanner.rb', line 14 def kind @kind end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/verizon/models/device_idforplanner.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. kind = hash.key?('kind') ? hash['kind'] : SKIP id = hash.key?('id') ? hash['id'] : SKIP # Create object from extracted values. DeviceIdforplanner.new(kind, id) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/verizon/models/device_idforplanner.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['kind'] = 'kind' @_hash['id'] = 'id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 40 41 42 |
# File 'lib/verizon/models/device_idforplanner.rb', line 37 def self.nullables %w[ kind id ] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/verizon/models/device_idforplanner.rb', line 29 def self.optionals %w[ kind id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
69 70 71 72 |
# File 'lib/verizon/models/device_idforplanner.rb', line 69 def inspect class_name = self.class.name.split('::').last "<#{class_name} kind: #{@kind.inspect}, id: #{@id.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
63 64 65 66 |
# File 'lib/verizon/models/device_idforplanner.rb', line 63 def to_s class_name = self.class.name.split('::').last "<#{class_name} kind: #{@kind}, id: #{@id}>" end |