Class: Verizon::DeviceLabels
- Defined in:
- lib/verizon/models/device_labels.rb
Overview
A label for a single device.
Instance Attribute Summary collapse
-
#name ⇒ String
The label you want to associate with the device.
-
#value ⇒ String
The value of label.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(name = nil, value = nil) ⇒ DeviceLabels
constructor
A new instance of DeviceLabels.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(name = nil, value = nil) ⇒ DeviceLabels
Returns a new instance of DeviceLabels.
38 39 40 41 |
# File 'lib/verizon/models/device_labels.rb', line 38 def initialize(name = nil, value = nil) @name = name @value = value end |
Instance Attribute Details
#name ⇒ String
The label you want to associate with the device.
14 15 16 |
# File 'lib/verizon/models/device_labels.rb', line 14 def name @name end |
#value ⇒ String
The value of label
18 19 20 |
# File 'lib/verizon/models/device_labels.rb', line 18 def value @value end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/verizon/models/device_labels.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. name = hash.key?('name') ? hash['name'] : nil value = hash.key?('value') ? hash['value'] : nil # Create object from extracted values. DeviceLabels.new(name, value) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/verizon/models/device_labels.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['name'] = 'name' @_hash['value'] = 'value' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/verizon/models/device_labels.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/verizon/models/device_labels.rb', line 29 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/verizon/models/device_labels.rb', line 58 def self.validate(value) if value.instance_of? self return ( APIHelper.valid_type?(value.name, ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value.value, ->(val) { val.instance_of? String }) ) end return false unless value.instance_of? Hash ( APIHelper.valid_type?(value['name'], ->(val) { val.instance_of? String }) and APIHelper.valid_type?(value['value'], ->(val) { val.instance_of? String }) ) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
85 86 87 88 |
# File 'lib/verizon/models/device_labels.rb', line 85 def inspect class_name = self.class.name.split('::').last "<#{class_name} name: #{@name.inspect}, value: #{@value.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
79 80 81 82 |
# File 'lib/verizon/models/device_labels.rb', line 79 def to_s class_name = self.class.name.split('::').last "<#{class_name} name: #{@name}, value: #{@value}>" end |