Class: Verizon::DeviceListIP

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/device_list_ip.rb

Overview

DeviceListIP Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(device_ids = nil, ipaddress = nil) ⇒ DeviceListIP

Returns a new instance of DeviceListIP.



38
39
40
41
# File 'lib/verizon/models/device_list_ip.rb', line 38

def initialize(device_ids = nil, ipaddress = nil)
  @device_ids = device_ids
  @ipaddress = ipaddress
end

Instance Attribute Details

#device_idsArray[PWNDeviceId]

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/verizon/models/device_list_ip.rb', line 14

def device_ids
  @device_ids
end

#ipaddressString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/verizon/models/device_list_ip.rb', line 18

def ipaddress
  @ipaddress
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/verizon/models/device_list_ip.rb', line 44

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  device_ids = nil
  unless hash['deviceIds'].nil?
    device_ids = []
    hash['deviceIds'].each do |structure|
      device_ids << (PWNDeviceId.from_hash(structure) if structure)
    end
  end

  device_ids = nil unless hash.key?('deviceIds')
  ipaddress = hash.key?('ipAddress') ? hash['ipAddress'] : nil

  # Create object from extracted values.
  DeviceListIP.new(device_ids,
                   ipaddress)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/verizon/models/device_list_ip.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['device_ids'] = 'deviceIds'
  @_hash['ipaddress'] = 'ipAddress'
  @_hash
end

.nullablesObject

An array for nullable fields



34
35
36
# File 'lib/verizon/models/device_list_ip.rb', line 34

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
# File 'lib/verizon/models/device_list_ip.rb', line 29

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



72
73
74
75
# File 'lib/verizon/models/device_list_ip.rb', line 72

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} device_ids: #{@device_ids.inspect}, ipaddress: #{@ipaddress.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



66
67
68
69
# File 'lib/verizon/models/device_list_ip.rb', line 66

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} device_ids: #{@device_ids}, ipaddress: #{@ipaddress}>"
end