Class: Verizon::DeviceManagementResult
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::DeviceManagementResult
- Defined in:
- lib/verizon/models/device_management_result.rb
Overview
Response to activate service for one or more devices so that they can send and receive data.
Instance Attribute Summary collapse
-
#request_id ⇒ String
A unique string that associates the request with the results that are sent via a callback service.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(request_id = SKIP) ⇒ DeviceManagementResult
constructor
A new instance of DeviceManagementResult.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(request_id = SKIP) ⇒ DeviceManagementResult
Returns a new instance of DeviceManagementResult.
37 38 39 |
# File 'lib/verizon/models/device_management_result.rb', line 37 def initialize(request_id = SKIP) @request_id = request_id unless request_id == SKIP end |
Instance Attribute Details
#request_id ⇒ String
A unique string that associates the request with the results that are sent via a callback service.
16 17 18 |
# File 'lib/verizon/models/device_management_result.rb', line 16 def request_id @request_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
42 43 44 45 46 47 48 49 50 |
# File 'lib/verizon/models/device_management_result.rb', line 42 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. request_id = hash.key?('requestId') ? hash['requestId'] : SKIP # Create object from extracted values. DeviceManagementResult.new(request_id) end |
.names ⇒ Object
A mapping from model property names to API property names.
19 20 21 22 23 |
# File 'lib/verizon/models/device_management_result.rb', line 19 def self.names @_hash = {} if @_hash.nil? @_hash['request_id'] = 'requestId' @_hash end |
.nullables ⇒ Object
An array for nullable fields
33 34 35 |
# File 'lib/verizon/models/device_management_result.rb', line 33 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
26 27 28 29 30 |
# File 'lib/verizon/models/device_management_result.rb', line 26 def self.optionals %w[ request_id ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
59 60 61 62 |
# File 'lib/verizon/models/device_management_result.rb', line 59 def inspect class_name = self.class.name.split('::').last "<#{class_name} request_id: #{@request_id.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
53 54 55 56 |
# File 'lib/verizon/models/device_management_result.rb', line 53 def to_s class_name = self.class.name.split('::').last "<#{class_name} request_id: #{@request_id}>" end |