Class: Verizon::DeviceServiceRequest
- Defined in:
- lib/verizon/models/device_service_request.rb
Overview
Device information.
Instance Attribute Summary collapse
-
#bullseye_enable ⇒ HplBullseyeEnable
A flag that shows if Hyper Precise is enabled (true) or disabled (false).
-
#imei ⇒ String
The International Mobile Equipment Identifier of the device.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(imei = nil, bullseye_enable = nil) ⇒ DeviceServiceRequest
constructor
A new instance of DeviceServiceRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(imei = nil, bullseye_enable = nil) ⇒ DeviceServiceRequest
Returns a new instance of DeviceServiceRequest.
38 39 40 41 |
# File 'lib/verizon/models/device_service_request.rb', line 38 def initialize(imei = nil, bullseye_enable = nil) @imei = imei @bullseye_enable = bullseye_enable end |
Instance Attribute Details
#bullseye_enable ⇒ HplBullseyeEnable
A flag that shows if Hyper Precise is enabled (true) or disabled (false).
18 19 20 |
# File 'lib/verizon/models/device_service_request.rb', line 18 def bullseye_enable @bullseye_enable end |
#imei ⇒ String
The International Mobile Equipment Identifier of the device.
14 15 16 |
# File 'lib/verizon/models/device_service_request.rb', line 14 def imei @imei end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/verizon/models/device_service_request.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. imei = hash.key?('imei') ? hash['imei'] : nil bullseye_enable = HplBullseyeEnable.from_hash(hash['BullseyeEnable']) if hash['BullseyeEnable'] # Create object from extracted values. DeviceServiceRequest.new(imei, bullseye_enable) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/verizon/models/device_service_request.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['imei'] = 'imei' @_hash['bullseye_enable'] = 'BullseyeEnable' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/verizon/models/device_service_request.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/verizon/models/device_service_request.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
64 65 66 67 |
# File 'lib/verizon/models/device_service_request.rb', line 64 def inspect class_name = self.class.name.split('::').last "<#{class_name} imei: #{@imei.inspect}, bullseye_enable: #{@bullseye_enable.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
58 59 60 61 |
# File 'lib/verizon/models/device_service_request.rb', line 58 def to_s class_name = self.class.name.split('::').last "<#{class_name} imei: #{@imei}, bullseye_enable: #{@bullseye_enable}>" end |