Class: Verizon::DeviceStatusItemforplanner

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/device_status_itemforplanner.rb

Overview

DeviceStatusItemforplanner Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(device_ids = SKIP, status = SKIP, reason = SKIP) ⇒ DeviceStatusItemforplanner

Returns a new instance of DeviceStatusItemforplanner.



51
52
53
54
55
# File 'lib/verizon/models/device_status_itemforplanner.rb', line 51

def initialize(device_ids = SKIP, status = SKIP, reason = SKIP)
  @device_ids = device_ids unless device_ids == SKIP
  @status = status unless status == SKIP
  @reason = reason unless reason == SKIP
end

Instance Attribute Details

#device_idsArray[DeviceIdforplanner]

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/verizon/models/device_status_itemforplanner.rb', line 14

def device_ids
  @device_ids
end

#reasonString

TODO: Write general description for this method

Returns:

  • (String)


22
23
24
# File 'lib/verizon/models/device_status_itemforplanner.rb', line 22

def reason
  @reason
end

#statusString

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/verizon/models/device_status_itemforplanner.rb', line 18

def status
  @status
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/verizon/models/device_status_itemforplanner.rb', line 58

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  device_ids = nil
  unless hash['deviceIds'].nil?
    device_ids = []
    hash['deviceIds'].each do |structure|
      device_ids << (DeviceIdforplanner.from_hash(structure) if structure)
    end
  end

  device_ids = SKIP unless hash.key?('deviceIds')
  status = hash.key?('status') ? hash['status'] : SKIP
  reason = hash.key?('reason') ? hash['reason'] : SKIP

  # Create object from extracted values.
  DeviceStatusItemforplanner.new(device_ids,
                                 status,
                                 reason)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/verizon/models/device_status_itemforplanner.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['device_ids'] = 'deviceIds'
  @_hash['status'] = 'status'
  @_hash['reason'] = 'reason'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
46
47
48
49
# File 'lib/verizon/models/device_status_itemforplanner.rb', line 43

def self.nullables
  %w[
    device_ids
    status
    reason
  ]
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/verizon/models/device_status_itemforplanner.rb', line 34

def self.optionals
  %w[
    device_ids
    status
    reason
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



88
89
90
91
92
# File 'lib/verizon/models/device_status_itemforplanner.rb', line 88

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} device_ids: #{@device_ids.inspect}, status: #{@status.inspect}, reason:"\
  " #{@reason.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



82
83
84
85
# File 'lib/verizon/models/device_status_itemforplanner.rb', line 82

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} device_ids: #{@device_ids}, status: #{@status}, reason: #{@reason}>"
end