Class: Verizon::DiagnosticsHistoryController

Inherits:
BaseController show all
Defined in:
lib/verizon/controllers/diagnostics_history_controller.rb

Overview

DiagnosticsHistoryController

Constant Summary

Constants inherited from BaseController

BaseController::GLOBAL_ERRORS

Instance Attribute Summary

Attributes inherited from BaseController

#config, #http_call_back

Instance Method Summary collapse

Methods inherited from BaseController

#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent

Constructor Details

This class inherits a constructor from Verizon::BaseController

Instance Method Details

#get_diagnostics_history(body) ⇒ ApiResponse

This endpoint allows the user to get the history data. information.

Parameters:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
# File 'lib/verizon/controllers/diagnostics_history_controller.rb', line 13

def get_diagnostics_history(body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/history/actions/$search',
                                 Server::DEVICE_DIAGNOSTICS)
               .header_param(new_parameter('*/*', key: 'Content-Type'))
               .body_param(new_parameter(body))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(History.method(:from_hash))
                .is_api_response(true)
                .is_response_array(true)
                .local_error('default',
                             'Error response.',
                             DeviceDiagnosticsResultException))
    .execute
end