Class: Verizon::DmV1DevicesActionsSetRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::DmV1DevicesActionsSetRequest
- Defined in:
- lib/verizon/models/dm_v1_devices_actions_set_request.rb
Overview
DmV1DevicesActionsSetRequest Model.
Instance Attribute Summary collapse
-
#accountname ⇒ String
The numeric account name, which must include leading zeros.
-
#configuration ⇒ DtoDeviceActionSetConfiguration1
The numeric account name, which must include leading zeros.
-
#resourceidentifier ⇒ DtoDeviceResourceIdentifier1
Device identifiers, one or more are required.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(accountname = SKIP, configuration = SKIP, resourceidentifier = SKIP) ⇒ DmV1DevicesActionsSetRequest
constructor
A new instance of DmV1DevicesActionsSetRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(accountname = SKIP, configuration = SKIP, resourceidentifier = SKIP) ⇒ DmV1DevicesActionsSetRequest
Returns a new instance of DmV1DevicesActionsSetRequest.
47 48 49 50 51 52 |
# File 'lib/verizon/models/dm_v1_devices_actions_set_request.rb', line 47 def initialize(accountname = SKIP, configuration = SKIP, resourceidentifier = SKIP) @accountname = accountname unless accountname == SKIP @configuration = configuration unless configuration == SKIP @resourceidentifier = resourceidentifier unless resourceidentifier == SKIP end |
Instance Attribute Details
#accountname ⇒ String
The numeric account name, which must include leading zeros
14 15 16 |
# File 'lib/verizon/models/dm_v1_devices_actions_set_request.rb', line 14 def accountname @accountname end |
#configuration ⇒ DtoDeviceActionSetConfiguration1
The numeric account name, which must include leading zeros
18 19 20 |
# File 'lib/verizon/models/dm_v1_devices_actions_set_request.rb', line 18 def configuration @configuration end |
#resourceidentifier ⇒ DtoDeviceResourceIdentifier1
Device identifiers, one or more are required
22 23 24 |
# File 'lib/verizon/models/dm_v1_devices_actions_set_request.rb', line 22 def resourceidentifier @resourceidentifier end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/verizon/models/dm_v1_devices_actions_set_request.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. accountname = hash.key?('accountname') ? hash['accountname'] : SKIP configuration = DtoDeviceActionSetConfiguration1.from_hash(hash['configuration']) if hash['configuration'] resourceidentifier = DtoDeviceResourceIdentifier1.from_hash(hash['resourceidentifier']) if hash['resourceidentifier'] # Create object from extracted values. DmV1DevicesActionsSetRequest.new(accountname, configuration, resourceidentifier) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/verizon/models/dm_v1_devices_actions_set_request.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['accountname'] = 'accountname' @_hash['configuration'] = 'configuration' @_hash['resourceidentifier'] = 'resourceidentifier' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/verizon/models/dm_v1_devices_actions_set_request.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/verizon/models/dm_v1_devices_actions_set_request.rb', line 34 def self.optionals %w[ accountname configuration resourceidentifier ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
79 80 81 82 83 |
# File 'lib/verizon/models/dm_v1_devices_actions_set_request.rb', line 79 def inspect class_name = self.class.name.split('::').last "<#{class_name} accountname: #{@accountname.inspect}, configuration:"\ " #{@configuration.inspect}, resourceidentifier: #{@resourceidentifier.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
72 73 74 75 76 |
# File 'lib/verizon/models/dm_v1_devices_actions_set_request.rb', line 72 def to_s class_name = self.class.name.split('::').last "<#{class_name} accountname: #{@accountname}, configuration: #{@configuration},"\ " resourceidentifier: #{@resourceidentifier}>" end |