Class: Verizon::DownloadTimeWindow
- Defined in:
- lib/verizon/models/download_time_window.rb
Overview
DownloadTimeWindow Model.
Instance Attribute Summary collapse
-
#end_time ⇒ String
Device IMEI list.
-
#start_time ⇒ String
Device IMEI list.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(start_time = SKIP, end_time = SKIP) ⇒ DownloadTimeWindow
constructor
A new instance of DownloadTimeWindow.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(start_time = SKIP, end_time = SKIP) ⇒ DownloadTimeWindow
Returns a new instance of DownloadTimeWindow.
41 42 43 44 |
# File 'lib/verizon/models/download_time_window.rb', line 41 def initialize(start_time = SKIP, end_time = SKIP) @start_time = start_time unless start_time == SKIP @end_time = end_time unless end_time == SKIP end |
Instance Attribute Details
#end_time ⇒ String
Device IMEI list.
18 19 20 |
# File 'lib/verizon/models/download_time_window.rb', line 18 def end_time @end_time end |
#start_time ⇒ String
Device IMEI list.
14 15 16 |
# File 'lib/verizon/models/download_time_window.rb', line 14 def start_time @start_time end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/verizon/models/download_time_window.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. start_time = hash.key?('startTime') ? hash['startTime'] : SKIP end_time = hash.key?('endTime') ? hash['endTime'] : SKIP # Create object from extracted values. DownloadTimeWindow.new(start_time, end_time) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/verizon/models/download_time_window.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['start_time'] = 'startTime' @_hash['end_time'] = 'endTime' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/verizon/models/download_time_window.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/verizon/models/download_time_window.rb', line 29 def self.optionals %w[ start_time end_time ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 |
# File 'lib/verizon/models/download_time_window.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} start_time: #{@start_time.inspect}, end_time: #{@end_time.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/verizon/models/download_time_window.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} start_time: #{@start_time}, end_time: #{@end_time}>" end |