Class: Verizon::DtoAddUsersToNotificationGroupRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/dto_add_users_to_notification_group_request.rb

Overview

DtoAddUsersToNotificationGroupRequest Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(accountname = SKIP, id = SKIP, userids = SKIP) ⇒ DtoAddUsersToNotificationGroupRequest

Returns a new instance of DtoAddUsersToNotificationGroupRequest.



47
48
49
50
51
# File 'lib/verizon/models/dto_add_users_to_notification_group_request.rb', line 47

def initialize(accountname = SKIP, id = SKIP, userids = SKIP)
  @accountname = accountname unless accountname == SKIP
  @id = id unless id == SKIP
  @userids = userids unless userids == SKIP
end

Instance Attribute Details

#accountnameString

The numeric account name, which must include leading zeros

Returns:

  • (String)


14
15
16
# File 'lib/verizon/models/dto_add_users_to_notification_group_request.rb', line 14

def accountname
  @accountname
end

#idString

UUID of the user record, assigned at creation

Returns:

  • (String)


18
19
20
# File 'lib/verizon/models/dto_add_users_to_notification_group_request.rb', line 18

def id
  @id
end

#useridsArray[String]

UUID of the user record, assigned at creation

Returns:

  • (Array[String])


22
23
24
# File 'lib/verizon/models/dto_add_users_to_notification_group_request.rb', line 22

def userids
  @userids
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/verizon/models/dto_add_users_to_notification_group_request.rb', line 54

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  accountname = hash.key?('accountname') ? hash['accountname'] : SKIP
  id = hash.key?('id') ? hash['id'] : SKIP
  userids = hash.key?('userids') ? hash['userids'] : SKIP

  # Create object from extracted values.
  DtoAddUsersToNotificationGroupRequest.new(accountname,
                                            id,
                                            userids)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/verizon/models/dto_add_users_to_notification_group_request.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['accountname'] = 'accountname'
  @_hash['id'] = 'id'
  @_hash['userids'] = 'userids'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/verizon/models/dto_add_users_to_notification_group_request.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/verizon/models/dto_add_users_to_notification_group_request.rb', line 34

def self.optionals
  %w[
    accountname
    id
    userids
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



75
76
77
78
79
# File 'lib/verizon/models/dto_add_users_to_notification_group_request.rb', line 75

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} accountname: #{@accountname.inspect}, id: #{@id.inspect}, userids:"\
  " #{@userids.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



69
70
71
72
# File 'lib/verizon/models/dto_add_users_to_notification_group_request.rb', line 69

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} accountname: #{@accountname}, id: #{@id}, userids: #{@userids}>"
end