Class: Verizon::DtoDeviceActionSetConfiguration
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::DtoDeviceActionSetConfiguration
- Defined in:
- lib/verizon/models/dto_device_action_set_configuration.rb
Overview
DtoDeviceActionSetConfiguration Model.
Instance Attribute Summary collapse
-
#device_config ⇒ DtoDeviceConfig
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(device_config = SKIP) ⇒ DtoDeviceActionSetConfiguration
constructor
A new instance of DtoDeviceActionSetConfiguration.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(device_config = SKIP) ⇒ DtoDeviceActionSetConfiguration
Returns a new instance of DtoDeviceActionSetConfiguration.
35 36 37 |
# File 'lib/verizon/models/dto_device_action_set_configuration.rb', line 35 def initialize(device_config = SKIP) @device_config = device_config unless device_config == SKIP end |
Instance Attribute Details
#device_config ⇒ DtoDeviceConfig
TODO: Write general description for this method
14 15 16 |
# File 'lib/verizon/models/dto_device_action_set_configuration.rb', line 14 def device_config @device_config end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
40 41 42 43 44 45 46 47 48 |
# File 'lib/verizon/models/dto_device_action_set_configuration.rb', line 40 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. device_config = DtoDeviceConfig.from_hash(hash['deviceConfig']) if hash['deviceConfig'] # Create object from extracted values. DtoDeviceActionSetConfiguration.new(device_config) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/verizon/models/dto_device_action_set_configuration.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['device_config'] = 'deviceConfig' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 |
# File 'lib/verizon/models/dto_device_action_set_configuration.rb', line 31 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 27 28 |
# File 'lib/verizon/models/dto_device_action_set_configuration.rb', line 24 def self.optionals %w[ device_config ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
52 53 54 55 56 57 58 |
# File 'lib/verizon/models/dto_device_action_set_configuration.rb', line 52 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
67 68 69 70 |
# File 'lib/verizon/models/dto_device_action_set_configuration.rb', line 67 def inspect class_name = self.class.name.split('::').last "<#{class_name} device_config: #{@device_config.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
61 62 63 64 |
# File 'lib/verizon/models/dto_device_action_set_configuration.rb', line 61 def to_s class_name = self.class.name.split('::').last "<#{class_name} device_config: #{@device_config}>" end |