Class: Verizon::DtoDeviceActionSetConfiguration1
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::DtoDeviceActionSetConfiguration1
- Defined in:
- lib/verizon/models/dto_device_action_set_configuration1.rb
Overview
DtoDeviceActionSetConfiguration1 Model.
Instance Attribute Summary collapse
-
#device_config ⇒ DtoDeviceConfig
TODO: Write general description for this method.
-
#rbs_high_precision_tilt_config ⇒ RbsHighPrecisionTiltConfig
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(device_config = SKIP, rbs_high_precision_tilt_config = SKIP) ⇒ DtoDeviceActionSetConfiguration1
constructor
A new instance of DtoDeviceActionSetConfiguration1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(device_config = SKIP, rbs_high_precision_tilt_config = SKIP) ⇒ DtoDeviceActionSetConfiguration1
Returns a new instance of DtoDeviceActionSetConfiguration1.
41 42 43 44 45 46 47 |
# File 'lib/verizon/models/dto_device_action_set_configuration1.rb', line 41 def initialize(device_config = SKIP, rbs_high_precision_tilt_config = SKIP) @device_config = device_config unless device_config == SKIP unless rbs_high_precision_tilt_config == SKIP @rbs_high_precision_tilt_config = rbs_high_precision_tilt_config end end |
Instance Attribute Details
#device_config ⇒ DtoDeviceConfig
TODO: Write general description for this method
14 15 16 |
# File 'lib/verizon/models/dto_device_action_set_configuration1.rb', line 14 def device_config @device_config end |
#rbs_high_precision_tilt_config ⇒ RbsHighPrecisionTiltConfig
TODO: Write general description for this method
18 19 20 |
# File 'lib/verizon/models/dto_device_action_set_configuration1.rb', line 18 def rbs_high_precision_tilt_config @rbs_high_precision_tilt_config end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/verizon/models/dto_device_action_set_configuration1.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. device_config = DtoDeviceConfig.from_hash(hash['deviceConfig']) if hash['deviceConfig'] if hash['RbsHighPrecisionTiltConfig'] rbs_high_precision_tilt_config = RbsHighPrecisionTiltConfig.from_hash(hash['RbsHighPrecisionTiltConfig']) end # Create object from extracted values. DtoDeviceActionSetConfiguration1.new(device_config, rbs_high_precision_tilt_config) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/verizon/models/dto_device_action_set_configuration1.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['device_config'] = 'deviceConfig' @_hash['rbs_high_precision_tilt_config'] = 'RbsHighPrecisionTiltConfig' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/verizon/models/dto_device_action_set_configuration1.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/verizon/models/dto_device_action_set_configuration1.rb', line 29 def self.optionals %w[ device_config rbs_high_precision_tilt_config ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
72 73 74 75 76 |
# File 'lib/verizon/models/dto_device_action_set_configuration1.rb', line 72 def inspect class_name = self.class.name.split('::').last "<#{class_name} device_config: #{@device_config.inspect}, rbs_high_precision_tilt_config:"\ " #{@rbs_high_precision_tilt_config.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
65 66 67 68 69 |
# File 'lib/verizon/models/dto_device_action_set_configuration1.rb', line 65 def to_s class_name = self.class.name.split('::').last "<#{class_name} device_config: #{@device_config}, rbs_high_precision_tilt_config:"\ " #{@rbs_high_precision_tilt_config}>" end |