Class: Verizon::DtoLastReportedTimeResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::DtoLastReportedTimeResponse
- Defined in:
- lib/verizon/models/dto_last_reported_time_response.rb
Overview
DtoLastReportedTimeResponse Model.
Instance Attribute Summary collapse
-
#event ⇒ ResourceEvent
TODO: Write general description for this method.
-
#timestamp ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(event = SKIP, timestamp = SKIP) ⇒ DtoLastReportedTimeResponse
constructor
A new instance of DtoLastReportedTimeResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(event = SKIP, timestamp = SKIP) ⇒ DtoLastReportedTimeResponse
Returns a new instance of DtoLastReportedTimeResponse.
41 42 43 44 |
# File 'lib/verizon/models/dto_last_reported_time_response.rb', line 41 def initialize(event = SKIP, = SKIP) @event = event unless event == SKIP @timestamp = unless == SKIP end |
Instance Attribute Details
#event ⇒ ResourceEvent
TODO: Write general description for this method
14 15 16 |
# File 'lib/verizon/models/dto_last_reported_time_response.rb', line 14 def event @event end |
#timestamp ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/verizon/models/dto_last_reported_time_response.rb', line 18 def @timestamp end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/verizon/models/dto_last_reported_time_response.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. event = ResourceEvent.from_hash(hash['event']) if hash['event'] = hash.key?('timestamp') ? hash['timestamp'] : SKIP # Create object from extracted values. DtoLastReportedTimeResponse.new(event, ) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/verizon/models/dto_last_reported_time_response.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['event'] = 'event' @_hash['timestamp'] = 'timestamp' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/verizon/models/dto_last_reported_time_response.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/verizon/models/dto_last_reported_time_response.rb', line 29 def self.optionals %w[ event timestamp ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 |
# File 'lib/verizon/models/dto_last_reported_time_response.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} event: #{@event.inspect}, timestamp: #{@timestamp.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/verizon/models/dto_last_reported_time_response.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} event: #{@event}, timestamp: #{@timestamp}>" end |