Class: Verizon::Feature
- Defined in:
- lib/verizon/models/feature.rb
Overview
Feature Model.
Instance Attribute Summary collapse
-
#features ⇒ String
The calling and data features available for the account.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(features = SKIP) ⇒ Feature
constructor
A new instance of Feature.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(features = SKIP) ⇒ Feature
Returns a new instance of Feature.
37 38 39 |
# File 'lib/verizon/models/feature.rb', line 37 def initialize(features = SKIP) @features = features unless features == SKIP end |
Instance Attribute Details
#features ⇒ String
The calling and data features available for the account. Note: for Global IoT Orchestrator, the features ‘eUICC Verizon as Lead` and `Global eSim Billing` will always be present.
16 17 18 |
# File 'lib/verizon/models/feature.rb', line 16 def features @features end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
42 43 44 45 46 47 48 49 50 |
# File 'lib/verizon/models/feature.rb', line 42 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. features = hash.key?('features') ? hash['features'] : SKIP # Create object from extracted values. Feature.new(features) end |
.names ⇒ Object
A mapping from model property names to API property names.
19 20 21 22 23 |
# File 'lib/verizon/models/feature.rb', line 19 def self.names @_hash = {} if @_hash.nil? @_hash['features'] = 'features' @_hash end |
.nullables ⇒ Object
An array for nullable fields
33 34 35 |
# File 'lib/verizon/models/feature.rb', line 33 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
26 27 28 29 30 |
# File 'lib/verizon/models/feature.rb', line 26 def self.optionals %w[ features ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
59 60 61 62 |
# File 'lib/verizon/models/feature.rb', line 59 def inspect class_name = self.class.name.split('::').last "<#{class_name} features: #{@features.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
53 54 55 56 |
# File 'lib/verizon/models/feature.rb', line 53 def to_s class_name = self.class.name.split('::').last "<#{class_name} features: #{@features}>" end |