Class: Verizon::FilterCriteria1
- Defined in:
- lib/verizon/models/filter_criteria1.rb
Overview
FilterCriteria1 Model.
Instance Attribute Summary collapse
-
#account_name_list ⇒ Array[String]
An array of account names.
-
#carrier_service_plan_code ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(carrier_service_plan_code = SKIP, account_name_list = SKIP) ⇒ FilterCriteria1
constructor
A new instance of FilterCriteria1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(carrier_service_plan_code = SKIP, account_name_list = SKIP) ⇒ FilterCriteria1
Returns a new instance of FilterCriteria1.
41 42 43 44 45 46 47 |
# File 'lib/verizon/models/filter_criteria1.rb', line 41 def initialize(carrier_service_plan_code = SKIP, account_name_list = SKIP) unless carrier_service_plan_code == SKIP @carrier_service_plan_code = carrier_service_plan_code end @account_name_list = account_name_list unless account_name_list == SKIP end |
Instance Attribute Details
#account_name_list ⇒ Array[String]
An array of account names
18 19 20 |
# File 'lib/verizon/models/filter_criteria1.rb', line 18 def account_name_list @account_name_list end |
#carrier_service_plan_code ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/verizon/models/filter_criteria1.rb', line 14 def carrier_service_plan_code @carrier_service_plan_code end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/verizon/models/filter_criteria1.rb', line 50 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. carrier_service_plan_code = hash.key?('carrierServicePlanCode') ? hash['carrierServicePlanCode'] : SKIP account_name_list = hash.key?('accountNameList') ? hash['accountNameList'] : SKIP # Create object from extracted values. FilterCriteria1.new(carrier_service_plan_code, account_name_list) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/verizon/models/filter_criteria1.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['carrier_service_plan_code'] = 'carrierServicePlanCode' @_hash['account_name_list'] = 'accountNameList' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/verizon/models/filter_criteria1.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/verizon/models/filter_criteria1.rb', line 29 def self.optionals %w[ carrier_service_plan_code account_name_list ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
66 67 68 69 70 71 72 |
# File 'lib/verizon/models/filter_criteria1.rb', line 66 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
82 83 84 85 86 |
# File 'lib/verizon/models/filter_criteria1.rb', line 82 def inspect class_name = self.class.name.split('::').last "<#{class_name} carrier_service_plan_code: #{@carrier_service_plan_code.inspect},"\ " account_name_list: #{@account_name_list.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
75 76 77 78 79 |
# File 'lib/verizon/models/filter_criteria1.rb', line 75 def to_s class_name = self.class.name.split('::').last "<#{class_name} carrier_service_plan_code: #{@carrier_service_plan_code},"\ " account_name_list: #{@account_name_list}>" end |