Class: Verizon::FindDeviceByPropertyResponseList
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::FindDeviceByPropertyResponseList
- Defined in:
- lib/verizon/models/find_device_by_property_response_list.rb
Overview
A success response includes an array of all matching devices. Each device includes the full device resource definition.
Instance Attribute Summary collapse
-
#device_property ⇒ Array[FindDeviceByPropertyResponse]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(device_property = SKIP) ⇒ FindDeviceByPropertyResponseList
constructor
A new instance of FindDeviceByPropertyResponseList.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(device_property = SKIP) ⇒ FindDeviceByPropertyResponseList
Returns a new instance of FindDeviceByPropertyResponseList.
36 37 38 |
# File 'lib/verizon/models/find_device_by_property_response_list.rb', line 36 def initialize(device_property = SKIP) @device_property = device_property unless device_property == SKIP end |
Instance Attribute Details
#device_property ⇒ Array[FindDeviceByPropertyResponse]
TODO: Write general description for this method
15 16 17 |
# File 'lib/verizon/models/find_device_by_property_response_list.rb', line 15 def device_property @device_property end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/verizon/models/find_device_by_property_response_list.rb', line 41 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it device_property = nil unless hash['DeviceProperty'].nil? device_property = [] hash['DeviceProperty'].each do |structure| device_property << (FindDeviceByPropertyResponse.from_hash(structure) if structure) end end device_property = SKIP unless hash.key?('DeviceProperty') # Create object from extracted values. FindDeviceByPropertyResponseList.new(device_property) end |
.names ⇒ Object
A mapping from model property names to API property names.
18 19 20 21 22 |
# File 'lib/verizon/models/find_device_by_property_response_list.rb', line 18 def self.names @_hash = {} if @_hash.nil? @_hash['device_property'] = 'DeviceProperty' @_hash end |
.nullables ⇒ Object
An array for nullable fields
32 33 34 |
# File 'lib/verizon/models/find_device_by_property_response_list.rb', line 32 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
25 26 27 28 29 |
# File 'lib/verizon/models/find_device_by_property_response_list.rb', line 25 def self.optionals %w[ device_property ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
67 68 69 70 |
# File 'lib/verizon/models/find_device_by_property_response_list.rb', line 67 def inspect class_name = self.class.name.split('::').last "<#{class_name} device_property: #{@device_property.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
61 62 63 64 |
# File 'lib/verizon/models/find_device_by_property_response_list.rb', line 61 def to_s class_name = self.class.name.split('::').last "<#{class_name} device_property: #{@device_property}>" end |