Class: Verizon::GIOSmsMessage

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/gio_sms_message.rb

Overview

GIOSmsMessage Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(device_ids = SKIP, message = SKIP, timestamp = SKIP) ⇒ GIOSmsMessage

Returns a new instance of GIOSmsMessage.



48
49
50
51
52
# File 'lib/verizon/models/gio_sms_message.rb', line 48

def initialize(device_ids = SKIP, message = SKIP, timestamp = SKIP)
  @device_ids = device_ids unless device_ids == SKIP
  @message = message unless message == SKIP
  @timestamp = timestamp unless timestamp == SKIP
end

Instance Attribute Details

#device_idsArray[GIODeviceId]

TODO: Write general description for this method

Returns:



15
16
17
# File 'lib/verizon/models/gio_sms_message.rb', line 15

def device_ids
  @device_ids
end

#messageString

TODO: Write general description for this method

Returns:

  • (String)


19
20
21
# File 'lib/verizon/models/gio_sms_message.rb', line 19

def message
  @message
end

#timestampDateTime

TODO: Write general description for this method

Returns:

  • (DateTime)


23
24
25
# File 'lib/verizon/models/gio_sms_message.rb', line 23

def timestamp
  @timestamp
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/verizon/models/gio_sms_message.rb', line 55

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  device_ids = nil
  unless hash['deviceIds'].nil?
    device_ids = []
    hash['deviceIds'].each do |structure|
      device_ids << (GIODeviceId.from_hash(structure) if structure)
    end
  end

  device_ids = SKIP unless hash.key?('deviceIds')
  message = hash.key?('message') ? hash['message'] : SKIP
  timestamp = if hash.key?('timestamp')
                (DateTimeHelper.from_rfc3339(hash['timestamp']) if hash['timestamp'])
              else
                SKIP
              end

  # Create object from extracted values.
  GIOSmsMessage.new(device_ids,
                    message,
                    timestamp)
end

.namesObject

A mapping from model property names to API property names.



26
27
28
29
30
31
32
# File 'lib/verizon/models/gio_sms_message.rb', line 26

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['device_ids'] = 'deviceIds'
  @_hash['message'] = 'message'
  @_hash['timestamp'] = 'timestamp'
  @_hash
end

.nullablesObject

An array for nullable fields



44
45
46
# File 'lib/verizon/models/gio_sms_message.rb', line 44

def self.nullables
  []
end

.optionalsObject

An array for optional fields



35
36
37
38
39
40
41
# File 'lib/verizon/models/gio_sms_message.rb', line 35

def self.optionals
  %w[
    device_ids
    message
    timestamp
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (GIOSmsMessage | Hash)

    value against the validation is performed.



88
89
90
91
92
93
94
# File 'lib/verizon/models/gio_sms_message.rb', line 88

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



104
105
106
107
108
# File 'lib/verizon/models/gio_sms_message.rb', line 104

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} device_ids: #{@device_ids.inspect}, message: #{@message.inspect},"\
  " timestamp: #{@timestamp.inspect}>"
end

#to_custom_timestampObject



82
83
84
# File 'lib/verizon/models/gio_sms_message.rb', line 82

def to_custom_timestamp
  DateTimeHelper.to_rfc3339(timestamp)
end

#to_sObject

Provides a human-readable string representation of the object.



97
98
99
100
101
# File 'lib/verizon/models/gio_sms_message.rb', line 97

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} device_ids: #{@device_ids}, message: #{@message}, timestamp:"\
  " #{@timestamp}>"
end