Class: Verizon::GenerateResponseItem
- Defined in:
- lib/verizon/models/generate_response_item.rb
Overview
GenerateResponseItem Model.
Instance Attribute Summary collapse
-
#credential ⇒ GenerateResponseItemCredential
TODO: Write general description for this method.
-
#imei ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(imei = SKIP, credential = SKIP) ⇒ GenerateResponseItem
constructor
A new instance of GenerateResponseItem.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(imei = SKIP, credential = SKIP) ⇒ GenerateResponseItem
Returns a new instance of GenerateResponseItem.
41 42 43 44 |
# File 'lib/verizon/models/generate_response_item.rb', line 41 def initialize(imei = SKIP, credential = SKIP) @imei = imei unless imei == SKIP @credential = credential unless credential == SKIP end |
Instance Attribute Details
#credential ⇒ GenerateResponseItemCredential
TODO: Write general description for this method
18 19 20 |
# File 'lib/verizon/models/generate_response_item.rb', line 18 def credential @credential end |
#imei ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/verizon/models/generate_response_item.rb', line 14 def imei @imei end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/verizon/models/generate_response_item.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. imei = hash.key?('imei') ? hash['imei'] : SKIP credential = GenerateResponseItemCredential.from_hash(hash['credential']) if hash['credential'] # Create object from extracted values. GenerateResponseItem.new(imei, credential) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/verizon/models/generate_response_item.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['imei'] = 'imei' @_hash['credential'] = 'credential' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/verizon/models/generate_response_item.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/verizon/models/generate_response_item.rb', line 29 def self.optionals %w[ imei credential ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
67 68 69 70 |
# File 'lib/verizon/models/generate_response_item.rb', line 67 def inspect class_name = self.class.name.split('::').last "<#{class_name} imei: #{@imei.inspect}, credential: #{@credential.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
61 62 63 64 |
# File 'lib/verizon/models/generate_response_item.rb', line 61 def to_s class_name = self.class.name.split('::').last "<#{class_name} imei: #{@imei}, credential: #{@credential}>" end |