Class: Verizon::HPLDeviceManagementController

Inherits:
BaseController show all
Defined in:
lib/verizon/controllers/hpl_device_management_controller.rb

Overview

HPLDeviceManagementController

Constant Summary

Constants inherited from BaseController

BaseController::GLOBAL_ERRORS

Instance Attribute Summary

Attributes inherited from BaseController

#config, #http_call_back

Instance Method Summary collapse

Methods inherited from BaseController

#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent

Constructor Details

This class inherits a constructor from Verizon::BaseController

Instance Method Details

#add_devices_hyper_precise(body) ⇒ ApiResponse

Use this API if you want to manage some device settings before you are ready to activate service for the devices. the account.

Parameters:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
# File 'lib/verizon/controllers/hpl_device_management_controller.rb', line 14

def add_devices_hyper_precise(body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/devices/actions/add',
                                 Server::HYPER_PRECISE_LOCATION)
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(HplAddDevicesRequest.method(:from_hash))
                .is_api_response(true)
                .is_response_array(true)
                .local_error('400',
                             'Bad Request.',
                             HyperPreciseLocationResultException)
                .local_error('401',
                             'Unauthorized',
                             HyperPreciseLocationResultException)
                .local_error('403',
                             'Forbidden',
                             HyperPreciseLocationResultException)
                .local_error('404',
                             'Not Found / Does not exist',
                             HyperPreciseLocationResultException)
                .local_error('405',
                             'Method Not Allowed',
                             HyperPreciseLocationResultException)
                .local_error('406',
                             'Format / Request Unacceptable',
                             HyperPreciseLocationResultException)
                .local_error('429',
                             'Too many requests',
                             HyperPreciseLocationResultException)
                .local_error('500',
                             'Internal Server Error',
                             HyperPreciseLocationResultException)
                .local_error('default',
                             'Error response',
                             HyperPreciseLocationResultException))
    .execute
end