Class: Verizon::HistorySearchLimitTime
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::HistorySearchLimitTime
- Defined in:
- lib/verizon/models/history_search_limit_time.rb
Overview
The time period for which a request should retrieve data, beginning with the limitTime.startOn and proceeding with the limitTime.duration.
Instance Attribute Summary collapse
-
#duration ⇒ NumericalData
Describes value and unit of time.
-
#start_on ⇒ DateTime
The starting date-time for this request.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(start_on = SKIP, duration = SKIP) ⇒ HistorySearchLimitTime
constructor
A new instance of HistorySearchLimitTime.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
- #to_custom_start_on ⇒ Object
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(start_on = SKIP, duration = SKIP) ⇒ HistorySearchLimitTime
Returns a new instance of HistorySearchLimitTime.
43 44 45 46 |
# File 'lib/verizon/models/history_search_limit_time.rb', line 43 def initialize(start_on = SKIP, duration = SKIP) @start_on = start_on unless start_on == SKIP @duration = duration unless duration == SKIP end |
Instance Attribute Details
#duration ⇒ NumericalData
Describes value and unit of time.
20 21 22 |
# File 'lib/verizon/models/history_search_limit_time.rb', line 20 def duration @duration end |
#start_on ⇒ DateTime
The starting date-time for this request.
16 17 18 |
# File 'lib/verizon/models/history_search_limit_time.rb', line 16 def start_on @start_on end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/verizon/models/history_search_limit_time.rb', line 49 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. start_on = if hash.key?('startOn') (DateTimeHelper.from_rfc3339(hash['startOn']) if hash['startOn']) else SKIP end duration = NumericalData.from_hash(hash['duration']) if hash['duration'] # Create object from extracted values. HistorySearchLimitTime.new(start_on, duration) end |
.names ⇒ Object
A mapping from model property names to API property names.
23 24 25 26 27 28 |
# File 'lib/verizon/models/history_search_limit_time.rb', line 23 def self.names @_hash = {} if @_hash.nil? @_hash['start_on'] = 'startOn' @_hash['duration'] = 'duration' @_hash end |
.nullables ⇒ Object
An array for nullable fields
39 40 41 |
# File 'lib/verizon/models/history_search_limit_time.rb', line 39 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
31 32 33 34 35 36 |
# File 'lib/verizon/models/history_search_limit_time.rb', line 31 def self.optionals %w[ start_on duration ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
76 77 78 79 |
# File 'lib/verizon/models/history_search_limit_time.rb', line 76 def inspect class_name = self.class.name.split('::').last "<#{class_name} start_on: #{@start_on.inspect}, duration: #{@duration.inspect}>" end |
#to_custom_start_on ⇒ Object
65 66 67 |
# File 'lib/verizon/models/history_search_limit_time.rb', line 65 def to_custom_start_on DateTimeHelper.to_rfc3339(start_on) end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
70 71 72 73 |
# File 'lib/verizon/models/history_search_limit_time.rb', line 70 def to_s class_name = self.class.name.split('::').last "<#{class_name} start_on: #{@start_on}, duration: #{@duration}>" end |