Class: Verizon::HyperPreciseLocationFault
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::HyperPreciseLocationFault
- Defined in:
- lib/verizon/models/hyper_precise_location_fault.rb
Overview
Fault occurred while responding.
Instance Attribute Summary collapse
-
#code ⇒ String
Hyper precise location fault code.
-
#description ⇒ String
Hyper precise location fault description.
-
#message ⇒ String
Hyper precise location fault message.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(code = SKIP, message = SKIP, description = SKIP) ⇒ HyperPreciseLocationFault
constructor
A new instance of HyperPreciseLocationFault.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(code = SKIP, message = SKIP, description = SKIP) ⇒ HyperPreciseLocationFault
Returns a new instance of HyperPreciseLocationFault.
47 48 49 50 51 |
# File 'lib/verizon/models/hyper_precise_location_fault.rb', line 47 def initialize(code = SKIP, = SKIP, description = SKIP) @code = code unless code == SKIP @message = unless == SKIP @description = description unless description == SKIP end |
Instance Attribute Details
#code ⇒ String
Hyper precise location fault code.
14 15 16 |
# File 'lib/verizon/models/hyper_precise_location_fault.rb', line 14 def code @code end |
#description ⇒ String
Hyper precise location fault description.
22 23 24 |
# File 'lib/verizon/models/hyper_precise_location_fault.rb', line 22 def description @description end |
#message ⇒ String
Hyper precise location fault message.
18 19 20 |
# File 'lib/verizon/models/hyper_precise_location_fault.rb', line 18 def @message end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/verizon/models/hyper_precise_location_fault.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. code = hash.key?('code') ? hash['code'] : SKIP = hash.key?('message') ? hash['message'] : SKIP description = hash.key?('description') ? hash['description'] : SKIP # Create object from extracted values. HyperPreciseLocationFault.new(code, , description) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/verizon/models/hyper_precise_location_fault.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['code'] = 'code' @_hash['message'] = 'message' @_hash['description'] = 'description' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/verizon/models/hyper_precise_location_fault.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/verizon/models/hyper_precise_location_fault.rb', line 34 def self.optionals %w[ code message description ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
75 76 77 78 79 |
# File 'lib/verizon/models/hyper_precise_location_fault.rb', line 75 def inspect class_name = self.class.name.split('::').last "<#{class_name} code: #{@code.inspect}, message: #{@message.inspect}, description:"\ " #{@description.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 |
# File 'lib/verizon/models/hyper_precise_location_fault.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} code: #{@code}, message: #{@message}, description: #{@description}>" end |