Class: Verizon::IPPoolforplanner
- Defined in:
- lib/verizon/models/ip_poolforplanner.rb
Overview
IPPoolforplanner Model.
Instance Attribute Summary collapse
-
#is_default_pool ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#pool_name ⇒ String
TODO: Write general description for this method.
-
#pool_type ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(is_default_pool = SKIP, pool_name = SKIP, pool_type = SKIP) ⇒ IPPoolforplanner
constructor
A new instance of IPPoolforplanner.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(is_default_pool = SKIP, pool_name = SKIP, pool_type = SKIP) ⇒ IPPoolforplanner
Returns a new instance of IPPoolforplanner.
47 48 49 50 51 |
# File 'lib/verizon/models/ip_poolforplanner.rb', line 47 def initialize(is_default_pool = SKIP, pool_name = SKIP, pool_type = SKIP) @is_default_pool = is_default_pool unless is_default_pool == SKIP @pool_name = pool_name unless pool_name == SKIP @pool_type = pool_type unless pool_type == SKIP end |
Instance Attribute Details
#is_default_pool ⇒ TrueClass | FalseClass
TODO: Write general description for this method
14 15 16 |
# File 'lib/verizon/models/ip_poolforplanner.rb', line 14 def is_default_pool @is_default_pool end |
#pool_name ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/verizon/models/ip_poolforplanner.rb', line 18 def pool_name @pool_name end |
#pool_type ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/verizon/models/ip_poolforplanner.rb', line 22 def pool_type @pool_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/verizon/models/ip_poolforplanner.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. is_default_pool = hash.key?('isDefaultPool') ? hash['isDefaultPool'] : SKIP pool_name = hash.key?('poolName') ? hash['poolName'] : SKIP pool_type = hash.key?('poolType') ? hash['poolType'] : SKIP # Create object from extracted values. IPPoolforplanner.new(is_default_pool, pool_name, pool_type) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/verizon/models/ip_poolforplanner.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['is_default_pool'] = 'isDefaultPool' @_hash['pool_name'] = 'poolName' @_hash['pool_type'] = 'poolType' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/verizon/models/ip_poolforplanner.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/verizon/models/ip_poolforplanner.rb', line 34 def self.optionals %w[ is_default_pool pool_name pool_type ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
77 78 79 80 81 |
# File 'lib/verizon/models/ip_poolforplanner.rb', line 77 def inspect class_name = self.class.name.split('::').last "<#{class_name} is_default_pool: #{@is_default_pool.inspect}, pool_name:"\ " #{@pool_name.inspect}, pool_type: #{@pool_type.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
70 71 72 73 74 |
# File 'lib/verizon/models/ip_poolforplanner.rb', line 70 def to_s class_name = self.class.name.split('::').last "<#{class_name} is_default_pool: #{@is_default_pool}, pool_name: #{@pool_name}, pool_type:"\ " #{@pool_type}>" end |