Class: Verizon::Id

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/id.rb

Overview

Id Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(id = SKIP, kind = SKIP) ⇒ Id

Returns a new instance of Id.



43
44
45
46
# File 'lib/verizon/models/id.rb', line 43

def initialize(id = SKIP, kind = SKIP)
  @id = id unless id == SKIP
  @kind = kind unless kind == SKIP
end

Instance Attribute Details

#idString

The value of the device identifier.

Returns:

  • (String)


14
15
16
# File 'lib/verizon/models/id.rb', line 14

def id
  @id
end

#kindString

The type of the device identifier. Valid types of identifiers are:ESN (decimal),EID,ICCID (up to 20 digits),IMEI (up to 16 digits),MDN,MEID (hexadecimal),MSISDN.

Returns:

  • (String)


20
21
22
# File 'lib/verizon/models/id.rb', line 20

def kind
  @kind
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



49
50
51
52
53
54
55
56
57
58
59
# File 'lib/verizon/models/id.rb', line 49

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  id = hash.key?('id') ? hash['id'] : SKIP
  kind = hash.key?('kind') ? hash['kind'] : SKIP

  # Create object from extracted values.
  Id.new(id,
         kind)
end

.namesObject

A mapping from model property names to API property names.



23
24
25
26
27
28
# File 'lib/verizon/models/id.rb', line 23

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['id'] = 'id'
  @_hash['kind'] = 'kind'
  @_hash
end

.nullablesObject

An array for nullable fields



39
40
41
# File 'lib/verizon/models/id.rb', line 39

def self.nullables
  []
end

.optionalsObject

An array for optional fields



31
32
33
34
35
36
# File 'lib/verizon/models/id.rb', line 31

def self.optionals
  %w[
    id
    kind
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (Id | Hash)

    value against the validation is performed.



63
64
65
66
67
68
69
# File 'lib/verizon/models/id.rb', line 63

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



78
79
80
81
# File 'lib/verizon/models/id.rb', line 78

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id.inspect}, kind: #{@kind.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



72
73
74
75
# File 'lib/verizon/models/id.rb', line 72

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id}, kind: #{@kind}>"
end