Class: Verizon::IntelligenceServiceController

Inherits:
BaseController show all
Defined in:
lib/verizon/controllers/intelligence_service_controller.rb

Overview

IntelligenceServiceController

Constant Summary

Constants inherited from BaseController

BaseController::GLOBAL_ERRORS

Instance Attribute Summary

Attributes inherited from BaseController

#config, #http_call_back

Instance Method Summary collapse

Methods inherited from BaseController

#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent

Constructor Details

This class inherits a constructor from Verizon::BaseController

Instance Method Details

#set_connection_planner(body: nil) ⇒ ApiResponse

Retrieves available device windows for Connection Planner. type description here

Parameters:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
# File 'lib/verizon/controllers/intelligence_service_controller.rb', line 13

def set_connection_planner(body: nil)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/v1/intelligence/device/connection-planner',
                                 Server::THINGSPACE)
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(AsynchronousRequestResultforplanner.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'Bad request',
                             RestErrorResponseforplannerException)
                .local_error('401',
                             'Unauthorized',
                             AuthRestErrorResponseforplannerException)
                .local_error('403',
                             'Forbidden',
                             RestErrorResponseforplannerException)
                .local_error('404',
                             'Not Found / Does not exist',
                             RestErrorResponseforplannerException)
                .local_error('406',
                             'Format / Request Unacceptable',
                             RestErrorResponseforplannerException)
                .local_error('429',
                             'Too many requests',
                             RestErrorResponseforplannerException)
                .local_error('default',
                             'Error response',
                             RestErrorResponseforplannerException))
    .execute
end

#status_connection_planner(body: nil) ⇒ ApiResponse

Retrieves the device status for the Connection Planner service. type description here

Parameters:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/verizon/controllers/intelligence_service_controller.rb', line 55

def status_connection_planner(body: nil)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/v1/intelligence/device/connection-planner/status',
                                 Server::THINGSPACE)
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(GetDeviceStatusesResponseforplanner.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'Bad request',
                             RestErrorResponseforplannerException)
                .local_error('401',
                             'Unauthorized',
                             AuthRestErrorResponseforplannerException)
                .local_error('403',
                             'Forbidden',
                             RestErrorResponseforplannerException)
                .local_error('404',
                             'Not Found / Does not exist',
                             RestErrorResponseforplannerException)
                .local_error('406',
                             'Format / Request Unacceptable',
                             RestErrorResponseforplannerException)
                .local_error('429',
                             'Too many requests',
                             RestErrorResponseforplannerException)
                .local_error('default',
                             'Error response',
                             RestErrorResponseforplannerException))
    .execute
end