Class: Verizon::M5gBiCarrierInformation

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/m_5g_bi_carrier_information.rb

Overview

M5gBiCarrierInformation Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(carrier_name = SKIP) ⇒ M5gBiCarrierInformation

Returns a new instance of M5gBiCarrierInformation.



35
36
37
# File 'lib/verizon/models/m_5g_bi_carrier_information.rb', line 35

def initialize(carrier_name = SKIP)
  @carrier_name = carrier_name unless carrier_name == SKIP
end

Instance Attribute Details

#carrier_nameString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/verizon/models/m_5g_bi_carrier_information.rb', line 14

def carrier_name
  @carrier_name
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



40
41
42
43
44
45
46
47
48
# File 'lib/verizon/models/m_5g_bi_carrier_information.rb', line 40

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  carrier_name = hash.key?('carrierName') ? hash['carrierName'] : SKIP

  # Create object from extracted values.
  M5gBiCarrierInformation.new(carrier_name)
end

.namesObject

A mapping from model property names to API property names.



17
18
19
20
21
# File 'lib/verizon/models/m_5g_bi_carrier_information.rb', line 17

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['carrier_name'] = 'carrierName'
  @_hash
end

.nullablesObject

An array for nullable fields



31
32
33
# File 'lib/verizon/models/m_5g_bi_carrier_information.rb', line 31

def self.nullables
  []
end

.optionalsObject

An array for optional fields



24
25
26
27
28
# File 'lib/verizon/models/m_5g_bi_carrier_information.rb', line 24

def self.optionals
  %w[
    carrier_name
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



52
53
54
55
56
57
58
# File 'lib/verizon/models/m_5g_bi_carrier_information.rb', line 52

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



67
68
69
70
# File 'lib/verizon/models/m_5g_bi_carrier_information.rb', line 67

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} carrier_name: #{@carrier_name.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



61
62
63
64
# File 'lib/verizon/models/m_5g_bi_carrier_information.rb', line 61

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} carrier_name: #{@carrier_name}>"
end