Class: Verizon::M5gBiaddressAndcustomerinfo

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/m_5g_biaddress_andcustomerinfo.rb

Overview

M5gBiaddressAndcustomerinfo Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(primary_placeofuse = SKIP) ⇒ M5gBiaddressAndcustomerinfo

Returns a new instance of M5gBiaddressAndcustomerinfo.



35
36
37
# File 'lib/verizon/models/m_5g_biaddress_andcustomerinfo.rb', line 35

def initialize(primary_placeofuse = SKIP)
  @primary_placeofuse = primary_placeofuse unless primary_placeofuse == SKIP
end

Instance Attribute Details

#primary_placeofuseM5gBiprimaryPlaceofuse

TODO: Write general description for this method



14
15
16
# File 'lib/verizon/models/m_5g_biaddress_andcustomerinfo.rb', line 14

def primary_placeofuse
  @primary_placeofuse
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



40
41
42
43
44
45
46
47
48
49
# File 'lib/verizon/models/m_5g_biaddress_andcustomerinfo.rb', line 40

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  primary_placeofuse = M5gBiprimaryPlaceofuse.from_hash(hash['primaryPlaceofuse']) if
    hash['primaryPlaceofuse']

  # Create object from extracted values.
  M5gBiaddressAndcustomerinfo.new(primary_placeofuse)
end

.namesObject

A mapping from model property names to API property names.



17
18
19
20
21
# File 'lib/verizon/models/m_5g_biaddress_andcustomerinfo.rb', line 17

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['primary_placeofuse'] = 'primaryPlaceofuse'
  @_hash
end

.nullablesObject

An array for nullable fields



31
32
33
# File 'lib/verizon/models/m_5g_biaddress_andcustomerinfo.rb', line 31

def self.nullables
  []
end

.optionalsObject

An array for optional fields



24
25
26
27
28
# File 'lib/verizon/models/m_5g_biaddress_andcustomerinfo.rb', line 24

def self.optionals
  %w[
    primary_placeofuse
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



53
54
55
56
57
58
59
# File 'lib/verizon/models/m_5g_biaddress_andcustomerinfo.rb', line 53

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



68
69
70
71
# File 'lib/verizon/models/m_5g_biaddress_andcustomerinfo.rb', line 68

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} primary_placeofuse: #{@primary_placeofuse.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



62
63
64
65
# File 'lib/verizon/models/m_5g_biaddress_andcustomerinfo.rb', line 62

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} primary_placeofuse: #{@primary_placeofuse}>"
end