Class: Verizon::M5gBideviceDetailsresponse

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/m_5g_bidevice_detailsresponse.rb

Overview

M5gBideviceDetailsresponse Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(has_more_data = SKIP, devices = SKIP) ⇒ M5gBideviceDetailsresponse

Returns a new instance of M5gBideviceDetailsresponse.



41
42
43
44
# File 'lib/verizon/models/m_5g_bidevice_detailsresponse.rb', line 41

def initialize(has_more_data = SKIP, devices = SKIP)
  @has_more_data = has_more_data unless has_more_data == SKIP
  @devices = devices unless devices == SKIP
end

Instance Attribute Details

#devicesArray[M5gBiaccountNameobject]

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/verizon/models/m_5g_bidevice_detailsresponse.rb', line 18

def devices
  @devices
end

#has_more_dataTrueClass | FalseClass

TODO: Write general description for this method

Returns:

  • (TrueClass | FalseClass)


14
15
16
# File 'lib/verizon/models/m_5g_bidevice_detailsresponse.rb', line 14

def has_more_data
  @has_more_data
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



47
48
49
50
51
52
53
54
55
56
57
58
59
# File 'lib/verizon/models/m_5g_bidevice_detailsresponse.rb', line 47

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  has_more_data = hash.key?('hasMoreData') ? hash['hasMoreData'] : SKIP
  devices = hash.key?('devices') ? APIHelper.deserialize_union_type(
    UnionTypeLookUp.get(:M5gBideviceDetailsresponseDevices), hash['devices']
  ) : SKIP

  # Create object from extracted values.
  M5gBideviceDetailsresponse.new(has_more_data,
                                 devices)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/verizon/models/m_5g_bidevice_detailsresponse.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['has_more_data'] = 'hasMoreData'
  @_hash['devices'] = 'devices'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/verizon/models/m_5g_bidevice_detailsresponse.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/verizon/models/m_5g_bidevice_detailsresponse.rb', line 29

def self.optionals
  %w[
    has_more_data
    devices
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



63
64
65
66
67
68
69
# File 'lib/verizon/models/m_5g_bidevice_detailsresponse.rb', line 63

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



78
79
80
81
# File 'lib/verizon/models/m_5g_bidevice_detailsresponse.rb', line 78

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} has_more_data: #{@has_more_data.inspect}, devices: #{@devices.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



72
73
74
75
# File 'lib/verizon/models/m_5g_bidevice_detailsresponse.rb', line 72

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} has_more_data: #{@has_more_data}, devices: #{@devices}>"
end