Class: Verizon::M5gBideviceIdarray
- Defined in:
- lib/verizon/models/m_5g_bidevice_idarray.rb
Overview
M5gBideviceIdarray Model.
Instance Attribute Summary collapse
-
#device_id ⇒ Array[M5gBideviceId1]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(device_id = SKIP) ⇒ M5gBideviceIdarray
constructor
A new instance of M5gBideviceIdarray.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(device_id = SKIP) ⇒ M5gBideviceIdarray
Returns a new instance of M5gBideviceIdarray.
35 36 37 |
# File 'lib/verizon/models/m_5g_bidevice_idarray.rb', line 35 def initialize(device_id = SKIP) @device_id = device_id unless device_id == SKIP end |
Instance Attribute Details
#device_id ⇒ Array[M5gBideviceId1]
TODO: Write general description for this method
14 15 16 |
# File 'lib/verizon/models/m_5g_bidevice_idarray.rb', line 14 def device_id @device_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/verizon/models/m_5g_bidevice_idarray.rb', line 40 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. device_id = hash.key?('deviceId') ? APIHelper.deserialize_union_type( UnionTypeLookUp.get(:M5gBideviceIdarrayDeviceId), hash['deviceId'] ) : SKIP # Create object from extracted values. M5gBideviceIdarray.new(device_id) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/verizon/models/m_5g_bidevice_idarray.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['device_id'] = 'deviceId' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 |
# File 'lib/verizon/models/m_5g_bidevice_idarray.rb', line 31 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 27 28 |
# File 'lib/verizon/models/m_5g_bidevice_idarray.rb', line 24 def self.optionals %w[ device_id ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
54 55 56 57 58 59 60 |
# File 'lib/verizon/models/m_5g_bidevice_idarray.rb', line 54 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
69 70 71 72 |
# File 'lib/verizon/models/m_5g_bidevice_idarray.rb', line 69 def inspect class_name = self.class.name.split('::').last "<#{class_name} device_id: #{@device_id.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
63 64 65 66 |
# File 'lib/verizon/models/m_5g_bidevice_idarray.rb', line 63 def to_s class_name = self.class.name.split('::').last "<#{class_name} device_id: #{@device_id}>" end |