Class: Verizon::M5gBideviceIdarray2
- Defined in:
- lib/verizon/models/m_5g_bidevice_idarray2.rb
Overview
M5gBideviceIdarray2 Model.
Instance Attribute Summary collapse
-
#device_id ⇒ Array[M5gBideviceId1]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(device_id = SKIP) ⇒ M5gBideviceIdarray2
constructor
A new instance of M5gBideviceIdarray2.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(device_id = SKIP) ⇒ M5gBideviceIdarray2
Returns a new instance of M5gBideviceIdarray2.
35 36 37 |
# File 'lib/verizon/models/m_5g_bidevice_idarray2.rb', line 35 def initialize(device_id = SKIP) @device_id = device_id unless device_id == SKIP end |
Instance Attribute Details
#device_id ⇒ Array[M5gBideviceId1]
TODO: Write general description for this method
14 15 16 |
# File 'lib/verizon/models/m_5g_bidevice_idarray2.rb', line 14 def device_id @device_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/verizon/models/m_5g_bidevice_idarray2.rb', line 40 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it device_id = nil unless hash['deviceId'].nil? device_id = [] hash['deviceId'].each do |structure| device_id << (M5gBideviceId1.from_hash(structure) if structure) end end device_id = SKIP unless hash.key?('deviceId') # Create object from extracted values. M5gBideviceIdarray2.new(device_id) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/verizon/models/m_5g_bidevice_idarray2.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['device_id'] = 'deviceId' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 |
# File 'lib/verizon/models/m_5g_bidevice_idarray2.rb', line 31 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 27 28 |
# File 'lib/verizon/models/m_5g_bidevice_idarray2.rb', line 24 def self.optionals %w[ device_id ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
61 62 63 64 65 66 67 |
# File 'lib/verizon/models/m_5g_bidevice_idarray2.rb', line 61 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
76 77 78 79 |
# File 'lib/verizon/models/m_5g_bidevice_idarray2.rb', line 76 def inspect class_name = self.class.name.split('::').last "<#{class_name} device_id: #{@device_id.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
70 71 72 73 |
# File 'lib/verizon/models/m_5g_bidevice_idarray2.rb', line 70 def to_s class_name = self.class.name.split('::').last "<#{class_name} device_id: #{@device_id}>" end |