Class: Verizon::M5gBiprimaryPlaceofuse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::M5gBiprimaryPlaceofuse
- Defined in:
- lib/verizon/models/m_5g_biprimary_placeofuse.rb
Overview
M5gBiprimaryPlaceofuse Model.
Instance Attribute Summary collapse
-
#address ⇒ M5gBiAddress
TODO: Write general description for this method.
-
#customer_name ⇒ M5gBiCustomerName
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(address = SKIP, customer_name = SKIP) ⇒ M5gBiprimaryPlaceofuse
constructor
A new instance of M5gBiprimaryPlaceofuse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(address = SKIP, customer_name = SKIP) ⇒ M5gBiprimaryPlaceofuse
Returns a new instance of M5gBiprimaryPlaceofuse.
41 42 43 44 |
# File 'lib/verizon/models/m_5g_biprimary_placeofuse.rb', line 41 def initialize(address = SKIP, customer_name = SKIP) @address = address unless address == SKIP @customer_name = customer_name unless customer_name == SKIP end |
Instance Attribute Details
#address ⇒ M5gBiAddress
TODO: Write general description for this method
14 15 16 |
# File 'lib/verizon/models/m_5g_biprimary_placeofuse.rb', line 14 def address @address end |
#customer_name ⇒ M5gBiCustomerName
TODO: Write general description for this method
18 19 20 |
# File 'lib/verizon/models/m_5g_biprimary_placeofuse.rb', line 18 def customer_name @customer_name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/verizon/models/m_5g_biprimary_placeofuse.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. address = M5gBiAddress.from_hash(hash['address']) if hash['address'] customer_name = M5gBiCustomerName.from_hash(hash['customerName']) if hash['customerName'] # Create object from extracted values. M5gBiprimaryPlaceofuse.new(address, customer_name) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/verizon/models/m_5g_biprimary_placeofuse.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['address'] = 'address' @_hash['customer_name'] = 'customerName' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/verizon/models/m_5g_biprimary_placeofuse.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/verizon/models/m_5g_biprimary_placeofuse.rb', line 29 def self.optionals %w[ address customer_name ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
61 62 63 64 65 66 67 |
# File 'lib/verizon/models/m_5g_biprimary_placeofuse.rb', line 61 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
76 77 78 79 |
# File 'lib/verizon/models/m_5g_biprimary_placeofuse.rb', line 76 def inspect class_name = self.class.name.split('::').last "<#{class_name} address: #{@address.inspect}, customer_name: #{@customer_name.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
70 71 72 73 |
# File 'lib/verizon/models/m_5g_biprimary_placeofuse.rb', line 70 def to_s class_name = self.class.name.split('::').last "<#{class_name} address: #{@address}, customer_name: #{@customer_name}>" end |