Class: Verizon::ManagedAccountsAddRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::ManagedAccountsAddRequest
- Defined in:
- lib/verizon/models/managed_accounts_add_request.rb
Overview
ManagedAccountsAddRequest Model.
Instance Attribute Summary collapse
-
#account_name ⇒ String
Account identifier.
-
#managed_acc_list ⇒ Array[String]
managed account list.
-
#service_name ⇒ ServiceNameEnum
Service name.
-
#type ⇒ String
SKU name.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(account_name = nil, service_name = ServiceNameEnum::LOCATION, type = nil, managed_acc_list = nil) ⇒ ManagedAccountsAddRequest
constructor
A new instance of ManagedAccountsAddRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(account_name = nil, service_name = ServiceNameEnum::LOCATION, type = nil, managed_acc_list = nil) ⇒ ManagedAccountsAddRequest
Returns a new instance of ManagedAccountsAddRequest.
48 49 50 51 52 53 54 |
# File 'lib/verizon/models/managed_accounts_add_request.rb', line 48 def initialize(account_name = nil, service_name = ServiceNameEnum::LOCATION, type = nil, managed_acc_list = nil) @account_name = account_name @service_name = service_name @type = type @managed_acc_list = managed_acc_list end |
Instance Attribute Details
#account_name ⇒ String
Account identifier
14 15 16 |
# File 'lib/verizon/models/managed_accounts_add_request.rb', line 14 def account_name @account_name end |
#managed_acc_list ⇒ Array[String]
managed account list
26 27 28 |
# File 'lib/verizon/models/managed_accounts_add_request.rb', line 26 def managed_acc_list @managed_acc_list end |
#service_name ⇒ ServiceNameEnum
Service name
18 19 20 |
# File 'lib/verizon/models/managed_accounts_add_request.rb', line 18 def service_name @service_name end |
#type ⇒ String
SKU name
22 23 24 |
# File 'lib/verizon/models/managed_accounts_add_request.rb', line 22 def type @type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/verizon/models/managed_accounts_add_request.rb', line 57 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. account_name = hash.key?('accountName') ? hash['accountName'] : nil service_name = hash['serviceName'] ||= ServiceNameEnum::LOCATION type = hash.key?('type') ? hash['type'] : nil managed_acc_list = hash.key?('managedAccList') ? hash['managedAccList'] : nil # Create object from extracted values. ManagedAccountsAddRequest.new(account_name, service_name, type, managed_acc_list) end |
.names ⇒ Object
A mapping from model property names to API property names.
29 30 31 32 33 34 35 36 |
# File 'lib/verizon/models/managed_accounts_add_request.rb', line 29 def self.names @_hash = {} if @_hash.nil? @_hash['account_name'] = 'accountName' @_hash['service_name'] = 'serviceName' @_hash['type'] = 'type' @_hash['managed_acc_list'] = 'managedAccList' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/verizon/models/managed_accounts_add_request.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
39 40 41 |
# File 'lib/verizon/models/managed_accounts_add_request.rb', line 39 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
82 83 84 85 86 87 |
# File 'lib/verizon/models/managed_accounts_add_request.rb', line 82 def inspect class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name.inspect}, service_name:"\ " #{@service_name.inspect}, type: #{@type.inspect}, managed_acc_list:"\ " #{@managed_acc_list.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
75 76 77 78 79 |
# File 'lib/verizon/models/managed_accounts_add_request.rb', line 75 def to_s class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name}, service_name: #{@service_name}, type:"\ " #{@type}, managed_acc_list: #{@managed_acc_list}>" end |