Class: Verizon::Message3

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/message3.rb

Overview

Message3 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(is_private = nil, road_user_type = nil, trigger_conditions = nil, etsi_alert = nil, limits = SKIP, distribution_type = SKIP, distribution_schedule = SKIP) ⇒ Message3

Returns a new instance of Message3.



75
76
77
78
79
80
81
82
83
84
85
# File 'lib/verizon/models/message3.rb', line 75

def initialize(is_private = nil, road_user_type = nil,
               trigger_conditions = nil, etsi_alert = nil, limits = SKIP,
               distribution_type = SKIP, distribution_schedule = SKIP)
  @is_private = is_private
  @road_user_type = road_user_type
  @trigger_conditions = trigger_conditions
  @limits = limits unless limits == SKIP
  @distribution_type = distribution_type unless distribution_type == SKIP
  @distribution_schedule = distribution_schedule unless distribution_schedule == SKIP
  @etsi_alert = etsi_alert
end

Instance Attribute Details

#distribution_scheduleDistributionSchedule

The distribution schedule parameters for broadcast messages.



42
43
44
# File 'lib/verizon/models/message3.rb', line 42

def distribution_schedule
  @distribution_schedule
end

#distribution_typeArray[DistributionTypesEnum]

Type of the distribution.

Returns:



38
39
40
# File 'lib/verizon/models/message3.rb', line 38

def distribution_type
  @distribution_type
end

#etsi_alertEtsiAlert

The distribution schedule parameters for broadcast messages.

Returns:



46
47
48
# File 'lib/verizon/models/message3.rb', line 46

def etsi_alert
  @etsi_alert
end

#is_privateTrueClass | FalseClass

Defines whether the message is private or public. Private messages are published under the Vendor ID defined in the configuration and only visible to devices of selected vendors. Public messages are published under the Public vendor and are visible to all the users.

Returns:

  • (TrueClass | FalseClass)


18
19
20
# File 'lib/verizon/models/message3.rb', line 18

def is_private
  @is_private
end

#limitsArray[Object]

List of limitations. These limitations can be used for making the trigger condition more precise by defining speed and motion direction requirements to be met before the messages are sent out.

Returns:

  • (Array[Object])


34
35
36
# File 'lib/verizon/models/message3.rb', line 34

def limits
  @limits
end

#road_user_typeArray[RoadUserTypesEnum]

Type of the Road User.

Returns:



22
23
24
# File 'lib/verizon/models/message3.rb', line 22

def road_user_type
  @road_user_type
end

#trigger_conditionsArray[TriggerConditionEnum]

Trigger conditions that define on which road user action the message will be sent. If multiple Trigger Conditions are defined any of them will trigger the message.

Returns:



28
29
30
# File 'lib/verizon/models/message3.rb', line 28

def trigger_conditions
  @trigger_conditions
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/verizon/models/message3.rb', line 88

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  is_private = hash.key?('isPrivate') ? hash['isPrivate'] : nil
  road_user_type = hash.key?('roadUserType') ? hash['roadUserType'] : nil
  trigger_conditions =
    hash.key?('triggerConditions') ? hash['triggerConditions'] : nil
  etsi_alert = EtsiAlert.from_hash(hash['etsiAlert']) if hash['etsiAlert']
  limits = hash.key?('limits') ? APIHelper.deserialize_union_type(
    UnionTypeLookUp.get(:Limits), hash['limits']
  ) : SKIP
  distribution_type =
    hash.key?('distributionType') ? hash['distributionType'] : SKIP
  distribution_schedule = DistributionSchedule.from_hash(hash['distributionSchedule']) if
    hash['distributionSchedule']

  # Create object from extracted values.
  Message3.new(is_private,
               road_user_type,
               trigger_conditions,
               etsi_alert,
               limits,
               distribution_type,
               distribution_schedule)
end

.namesObject

A mapping from model property names to API property names.



49
50
51
52
53
54
55
56
57
58
59
# File 'lib/verizon/models/message3.rb', line 49

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['is_private'] = 'isPrivate'
  @_hash['road_user_type'] = 'roadUserType'
  @_hash['trigger_conditions'] = 'triggerConditions'
  @_hash['limits'] = 'limits'
  @_hash['distribution_type'] = 'distributionType'
  @_hash['distribution_schedule'] = 'distributionSchedule'
  @_hash['etsi_alert'] = 'etsiAlert'
  @_hash
end

.nullablesObject

An array for nullable fields



71
72
73
# File 'lib/verizon/models/message3.rb', line 71

def self.nullables
  []
end

.optionalsObject

An array for optional fields



62
63
64
65
66
67
68
# File 'lib/verizon/models/message3.rb', line 62

def self.optionals
  %w[
    limits
    distribution_type
    distribution_schedule
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (Message3 | Hash)

    value against the validation is performed.



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'lib/verizon/models/message3.rb', line 117

def self.validate(value)
  if value.instance_of? self
    return (
      APIHelper.valid_type?(value.is_private,
                            ->(val) { val.instance_of? TrueClass or val.instance_of? FalseClass }) and
        APIHelper.valid_type?(value.road_user_type,
                              ->(val) { RoadUserTypesEnum.validate(val) }) and
        APIHelper.valid_type?(value.trigger_conditions,
                              ->(val) { TriggerConditionEnum.validate(val) }) and
        APIHelper.valid_type?(value.etsi_alert,
                              ->(val) { EtsiAlert.validate(val) },
                              is_model_hash: true)
    )
  end

  return false unless value.instance_of? Hash

  (
    APIHelper.valid_type?(value['isPrivate'],
                          ->(val) { val.instance_of? TrueClass or val.instance_of? FalseClass }) and
      APIHelper.valid_type?(value['roadUserType'],
                            ->(val) { RoadUserTypesEnum.validate(val) }) and
      APIHelper.valid_type?(value['triggerConditions'],
                            ->(val) { TriggerConditionEnum.validate(val) }) and
      APIHelper.valid_type?(value['etsiAlert'],
                            ->(val) { EtsiAlert.validate(val) },
                            is_model_hash: true)
  )
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



157
158
159
160
161
162
163
164
# File 'lib/verizon/models/message3.rb', line 157

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} is_private: #{@is_private.inspect}, road_user_type:"\
  " #{@road_user_type.inspect}, trigger_conditions: #{@trigger_conditions.inspect}, limits:"\
  " #{@limits.inspect}, distribution_type: #{@distribution_type.inspect},"\
  " distribution_schedule: #{@distribution_schedule.inspect}, etsi_alert:"\
  " #{@etsi_alert.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



148
149
150
151
152
153
154
# File 'lib/verizon/models/message3.rb', line 148

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} is_private: #{@is_private}, road_user_type: #{@road_user_type},"\
  " trigger_conditions: #{@trigger_conditions}, limits: #{@limits}, distribution_type:"\
  " #{@distribution_type}, distribution_schedule: #{@distribution_schedule}, etsi_alert:"\
  " #{@etsi_alert}>"
end