Class: Verizon::MultiPolygon

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/multi_polygon.rb

Overview

A MultiPolygon is a type of geometry that represents a collection of Polygon geometries.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(type = nil, coordinates = nil) ⇒ MultiPolygon

Returns a new instance of MultiPolygon.



39
40
41
42
# File 'lib/verizon/models/multi_polygon.rb', line 39

def initialize(type = nil, coordinates = nil)
  @type = type
  @coordinates = coordinates
end

Instance Attribute Details

#coordinatesArray[Float]

TODO: Write general description for this method

Returns:

  • (Array[Float])


19
20
21
# File 'lib/verizon/models/multi_polygon.rb', line 19

def coordinates
  @coordinates
end

#typeType5Enum

TODO: Write general description for this method

Returns:



15
16
17
# File 'lib/verizon/models/multi_polygon.rb', line 15

def type
  @type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



45
46
47
48
49
50
51
52
53
54
55
# File 'lib/verizon/models/multi_polygon.rb', line 45

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  type = hash.key?('type') ? hash['type'] : nil
  coordinates = hash.key?('coordinates') ? hash['coordinates'] : nil

  # Create object from extracted values.
  MultiPolygon.new(type,
                   coordinates)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/verizon/models/multi_polygon.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['type'] = 'type'
  @_hash['coordinates'] = 'coordinates'
  @_hash
end

.nullablesObject

An array for nullable fields



35
36
37
# File 'lib/verizon/models/multi_polygon.rb', line 35

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
# File 'lib/verizon/models/multi_polygon.rb', line 30

def self.optionals
  []
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (MultiPolygon | Hash)

    value against the validation is performed.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/verizon/models/multi_polygon.rb', line 59

def self.validate(value)
  if value.instance_of? self
    return (
      APIHelper.valid_type?(value.type,
                            ->(val) { Type5Enum.validate(val) }) and
        APIHelper.valid_type?(value.coordinates,
                              ->(val) { val.instance_of? Float })
    )
  end

  return false unless value.instance_of? Hash

  (
    APIHelper.valid_type?(value['type'],
                          ->(val) { Type5Enum.validate(val) }) and
      APIHelper.valid_type?(value['coordinates'],
                            ->(val) { val.instance_of? Float })
  )
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



86
87
88
89
# File 'lib/verizon/models/multi_polygon.rb', line 86

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} type: #{@type.inspect}, coordinates: #{@coordinates.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



80
81
82
83
# File 'lib/verizon/models/multi_polygon.rb', line 80

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} type: #{@type}, coordinates: #{@coordinates}>"
end