Class: Verizon::Notify
- Defined in:
- lib/verizon/models/notify.rb
Overview
Notify Model.
Instance Attribute Summary collapse
-
#alert_type ⇒ String
TODO: Write general description for this method.
-
#threshold ⇒ Array[Carriercode1]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(alert_type = SKIP, threshold = SKIP) ⇒ Notify
constructor
A new instance of Notify.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(alert_type = SKIP, threshold = SKIP) ⇒ Notify
Returns a new instance of Notify.
41 42 43 44 |
# File 'lib/verizon/models/notify.rb', line 41 def initialize(alert_type = SKIP, threshold = SKIP) @alert_type = alert_type unless alert_type == SKIP @threshold = threshold unless threshold == SKIP end |
Instance Attribute Details
#alert_type ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/verizon/models/notify.rb', line 14 def alert_type @alert_type end |
#threshold ⇒ Array[Carriercode1]
TODO: Write general description for this method
18 19 20 |
# File 'lib/verizon/models/notify.rb', line 18 def threshold @threshold end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/verizon/models/notify.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. alert_type = hash.key?('alertType') ? hash['alertType'] : SKIP threshold = hash.key?('threshold') ? APIHelper.deserialize_union_type( UnionTypeLookUp.get(:NotifyThreshold), hash['threshold'] ) : SKIP # Create object from extracted values. Notify.new(alert_type, threshold) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/verizon/models/notify.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['alert_type'] = 'alertType' @_hash['threshold'] = 'threshold' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/verizon/models/notify.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/verizon/models/notify.rb', line 29 def self.optionals %w[ alert_type threshold ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
63 64 65 66 67 68 69 |
# File 'lib/verizon/models/notify.rb', line 63 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
78 79 80 81 |
# File 'lib/verizon/models/notify.rb', line 78 def inspect class_name = self.class.name.split('::').last "<#{class_name} alert_type: #{@alert_type.inspect}, threshold: #{@threshold.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
72 73 74 75 |
# File 'lib/verizon/models/notify.rb', line 72 def to_s class_name = self.class.name.split('::').last "<#{class_name} alert_type: #{@alert_type}, threshold: #{@threshold}>" end |