Class: Verizon::Offboarding
- Defined in:
- lib/verizon/models/offboarding.rb
Overview
Offboarding Model.
Instance Attribute Summary collapse
-
#sensoridentifier ⇒ String
the IEEE EUI64 address space used to identify a device.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(sensoridentifier = SKIP) ⇒ Offboarding
constructor
A new instance of Offboarding.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(sensoridentifier = SKIP) ⇒ Offboarding
Returns a new instance of Offboarding.
36 37 38 |
# File 'lib/verizon/models/offboarding.rb', line 36 def initialize(sensoridentifier = SKIP) @sensoridentifier = sensoridentifier unless sensoridentifier == SKIP end |
Instance Attribute Details
#sensoridentifier ⇒ String
the IEEE EUI64 address space used to identify a device. It is supplied by the device manufacturer
15 16 17 |
# File 'lib/verizon/models/offboarding.rb', line 15 def sensoridentifier @sensoridentifier end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
41 42 43 44 45 46 47 48 49 50 |
# File 'lib/verizon/models/offboarding.rb', line 41 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. sensoridentifier = hash.key?('sensoridentifier') ? hash['sensoridentifier'] : SKIP # Create object from extracted values. Offboarding.new(sensoridentifier) end |
.names ⇒ Object
A mapping from model property names to API property names.
18 19 20 21 22 |
# File 'lib/verizon/models/offboarding.rb', line 18 def self.names @_hash = {} if @_hash.nil? @_hash['sensoridentifier'] = 'sensoridentifier' @_hash end |
.nullables ⇒ Object
An array for nullable fields
32 33 34 |
# File 'lib/verizon/models/offboarding.rb', line 32 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
25 26 27 28 29 |
# File 'lib/verizon/models/offboarding.rb', line 25 def self.optionals %w[ sensoridentifier ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
59 60 61 62 |
# File 'lib/verizon/models/offboarding.rb', line 59 def inspect class_name = self.class.name.split('::').last "<#{class_name} sensoridentifier: #{@sensoridentifier.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
53 54 55 56 |
# File 'lib/verizon/models/offboarding.rb', line 53 def to_s class_name = self.class.name.split('::').last "<#{class_name} sensoridentifier: #{@sensoridentifier}>" end |