Class: Verizon::PWNProfile
- Defined in:
- lib/verizon/models/pwn_profile.rb
Overview
PWNProfile Model.
Instance Attribute Summary collapse
-
#profile_id ⇒ String
TODO: Write general description for this method.
-
#profile_name ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(profile_id = SKIP, profile_name = SKIP) ⇒ PWNProfile
constructor
A new instance of PWNProfile.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(profile_id = SKIP, profile_name = SKIP) ⇒ PWNProfile
Returns a new instance of PWNProfile.
41 42 43 44 |
# File 'lib/verizon/models/pwn_profile.rb', line 41 def initialize(profile_id = SKIP, profile_name = SKIP) @profile_id = profile_id unless profile_id == SKIP @profile_name = profile_name unless profile_name == SKIP end |
Instance Attribute Details
#profile_id ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/verizon/models/pwn_profile.rb', line 14 def profile_id @profile_id end |
#profile_name ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/verizon/models/pwn_profile.rb', line 18 def profile_name @profile_name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/verizon/models/pwn_profile.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. profile_id = hash.key?('profileId') ? hash['profileId'] : SKIP profile_name = hash.key?('profileName') ? hash['profileName'] : SKIP # Create object from extracted values. PWNProfile.new(profile_id, profile_name) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/verizon/models/pwn_profile.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['profile_id'] = 'profileId' @_hash['profile_name'] = 'profileName' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/verizon/models/pwn_profile.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/verizon/models/pwn_profile.rb', line 29 def self.optionals %w[ profile_id profile_name ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 70 |
# File 'lib/verizon/models/pwn_profile.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} profile_id: #{@profile_id.inspect}, profile_name:"\ " #{@profile_name.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/verizon/models/pwn_profile.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} profile_id: #{@profile_id}, profile_name: #{@profile_name}>" end |