Class: Verizon::PayAsYouGoFilterCriteria1

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/pay_as_you_go_filter_criteria1.rb

Overview

PayAsYouGoFilterCriteria1 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(carrier_service_plan_code = SKIP, account_name_list = SKIP) ⇒ PayAsYouGoFilterCriteria1

Returns a new instance of PayAsYouGoFilterCriteria1.



41
42
43
44
45
46
47
# File 'lib/verizon/models/pay_as_you_go_filter_criteria1.rb', line 41

def initialize(carrier_service_plan_code = SKIP,  = SKIP)
  unless carrier_service_plan_code == SKIP
    @carrier_service_plan_code =
      carrier_service_plan_code
  end
  @account_name_list =  unless  == SKIP
end

Instance Attribute Details

#account_name_listArray[String]

An array of account names

Returns:

  • (Array[String])


18
19
20
# File 'lib/verizon/models/pay_as_you_go_filter_criteria1.rb', line 18

def 
  @account_name_list
end

#carrier_service_plan_codeString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/verizon/models/pay_as_you_go_filter_criteria1.rb', line 14

def carrier_service_plan_code
  @carrier_service_plan_code
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/verizon/models/pay_as_you_go_filter_criteria1.rb', line 50

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  carrier_service_plan_code =
    hash.key?('carrierServicePlanCode') ? hash['carrierServicePlanCode'] : SKIP
   =
    hash.key?('accountNameList') ? hash['accountNameList'] : SKIP

  # Create object from extracted values.
  PayAsYouGoFilterCriteria1.new(carrier_service_plan_code,
                                )
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/verizon/models/pay_as_you_go_filter_criteria1.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['carrier_service_plan_code'] = 'carrierServicePlanCode'
  @_hash['account_name_list'] = 'accountNameList'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/verizon/models/pay_as_you_go_filter_criteria1.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
32
33
34
# File 'lib/verizon/models/pay_as_you_go_filter_criteria1.rb', line 29

def self.optionals
  %w[
    carrier_service_plan_code
    account_name_list
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



66
67
68
69
70
71
72
# File 'lib/verizon/models/pay_as_you_go_filter_criteria1.rb', line 66

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



82
83
84
85
86
# File 'lib/verizon/models/pay_as_you_go_filter_criteria1.rb', line 82

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} carrier_service_plan_code: #{@carrier_service_plan_code.inspect},"\
  " account_name_list: #{@account_name_list.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



75
76
77
78
79
# File 'lib/verizon/models/pay_as_you_go_filter_criteria1.rb', line 75

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} carrier_service_plan_code: #{@carrier_service_plan_code},"\
  " account_name_list: #{@account_name_list}>"
end