Class: Verizon::PayAsYouGoPricePlanTrigger

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/pay_as_you_go_price_plan_trigger.rb

Overview

PayAsYouGoPricePlanTrigger Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(pay_as_you_go = SKIP, condition = SKIP, action = SKIP) ⇒ PayAsYouGoPricePlanTrigger

Returns a new instance of PayAsYouGoPricePlanTrigger.



47
48
49
50
51
# File 'lib/verizon/models/pay_as_you_go_price_plan_trigger.rb', line 47

def initialize(pay_as_you_go = SKIP, condition = SKIP, action = SKIP)
  @pay_as_you_go = pay_as_you_go unless pay_as_you_go == SKIP
  @condition = condition unless condition == SKIP
  @action = action unless action == SKIP
end

Instance Attribute Details

#actionActionobject

TODO: Write general description for this method

Returns:



22
23
24
# File 'lib/verizon/models/pay_as_you_go_price_plan_trigger.rb', line 22

def action
  @action
end

#conditionRateplantype2Condition

TODO: Write general description for this method



18
19
20
# File 'lib/verizon/models/pay_as_you_go_price_plan_trigger.rb', line 18

def condition
  @condition
end

#pay_as_you_goPayAsYouGoFilterCriteria

TODO: Write general description for this method



14
15
16
# File 'lib/verizon/models/pay_as_you_go_price_plan_trigger.rb', line 14

def pay_as_you_go
  @pay_as_you_go
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/verizon/models/pay_as_you_go_price_plan_trigger.rb', line 54

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  pay_as_you_go = PayAsYouGoFilterCriteria.from_hash(hash['payAsYouGo']) if hash['payAsYouGo']
  condition = hash.key?('condition') ? APIHelper.deserialize_union_type(
    UnionTypeLookUp.get(:PayAsYouGoPricePlanTriggerCondition), hash['condition']
  ) : SKIP
  action = Actionobject.from_hash(hash['action']) if hash['action']

  # Create object from extracted values.
  PayAsYouGoPricePlanTrigger.new(pay_as_you_go,
                                 condition,
                                 action)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/verizon/models/pay_as_you_go_price_plan_trigger.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['pay_as_you_go'] = 'payAsYouGo'
  @_hash['condition'] = 'condition'
  @_hash['action'] = 'action'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/verizon/models/pay_as_you_go_price_plan_trigger.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/verizon/models/pay_as_you_go_price_plan_trigger.rb', line 34

def self.optionals
  %w[
    pay_as_you_go
    condition
    action
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



72
73
74
75
76
77
78
# File 'lib/verizon/models/pay_as_you_go_price_plan_trigger.rb', line 72

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



88
89
90
91
92
# File 'lib/verizon/models/pay_as_you_go_price_plan_trigger.rb', line 88

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} pay_as_you_go: #{@pay_as_you_go.inspect}, condition: #{@condition.inspect},"\
  " action: #{@action.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



81
82
83
84
85
# File 'lib/verizon/models/pay_as_you_go_price_plan_trigger.rb', line 81

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} pay_as_you_go: #{@pay_as_you_go}, condition: #{@condition}, action:"\
  " #{@action}>"
end