Class: Verizon::PeriodicReporting

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/periodic_reporting.rb

Overview

The units and values of the time interval for the sensor to send a report

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(unit = SKIP, hours = SKIP, minutes = SKIP) ⇒ PeriodicReporting

Returns a new instance of PeriodicReporting.



47
48
49
50
51
# File 'lib/verizon/models/periodic_reporting.rb', line 47

def initialize(unit = SKIP, hours = SKIP, minutes = SKIP)
  @unit = unit unless unit == SKIP
  @hours = hours unless hours == SKIP
  @minutes = minutes unless minutes == SKIP
end

Instance Attribute Details

#hoursInteger

whole numbers from 0 to 24

Returns:

  • (Integer)


18
19
20
# File 'lib/verizon/models/periodic_reporting.rb', line 18

def hours
  @hours
end

#minutesInteger

whole numbers from 0 to 59

Returns:

  • (Integer)


22
23
24
# File 'lib/verizon/models/periodic_reporting.rb', line 22

def minutes
  @minutes
end

#unitUnitEnum

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/verizon/models/periodic_reporting.rb', line 14

def unit
  @unit
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/verizon/models/periodic_reporting.rb', line 54

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  unit = hash.key?('unit') ? hash['unit'] : SKIP
  hours = hash.key?('hours') ? hash['hours'] : SKIP
  minutes = hash.key?('minutes') ? hash['minutes'] : SKIP

  # Create object from extracted values.
  PeriodicReporting.new(unit,
                        hours,
                        minutes)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/verizon/models/periodic_reporting.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['unit'] = 'unit'
  @_hash['hours'] = 'hours'
  @_hash['minutes'] = 'minutes'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/verizon/models/periodic_reporting.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/verizon/models/periodic_reporting.rb', line 34

def self.optionals
  %w[
    unit
    hours
    minutes
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



70
71
72
73
74
75
76
# File 'lib/verizon/models/periodic_reporting.rb', line 70

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



85
86
87
88
89
# File 'lib/verizon/models/periodic_reporting.rb', line 85

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} unit: #{@unit.inspect}, hours: #{@hours.inspect}, minutes:"\
  " #{@minutes.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



79
80
81
82
# File 'lib/verizon/models/periodic_reporting.rb', line 79

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} unit: #{@unit}, hours: #{@hours}, minutes: #{@minutes}>"
end