Class: Verizon::PromoAlert

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/promo_alert.rb

Overview

PromoAlert Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(filter_criteria = SKIP, condition = SKIP, enable_promo_exp = SKIP) ⇒ PromoAlert

Returns a new instance of PromoAlert.



47
48
49
50
51
52
# File 'lib/verizon/models/promo_alert.rb', line 47

def initialize(filter_criteria = SKIP, condition = SKIP,
               enable_promo_exp = SKIP)
  @filter_criteria = filter_criteria unless filter_criteria == SKIP
  @condition = condition unless condition == SKIP
  @enable_promo_exp = enable_promo_exp unless enable_promo_exp == SKIP
end

Instance Attribute Details

#conditionArray[Keyschunk2]

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/verizon/models/promo_alert.rb', line 18

def condition
  @condition
end

#enable_promo_expTrueClass | FalseClass

TODO: Write general description for this method

Returns:

  • (TrueClass | FalseClass)


22
23
24
# File 'lib/verizon/models/promo_alert.rb', line 22

def enable_promo_exp
  @enable_promo_exp
end

#filter_criteriaArray[ReadySimServicePlan]

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/verizon/models/promo_alert.rb', line 14

def filter_criteria
  @filter_criteria
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/verizon/models/promo_alert.rb', line 55

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  filter_criteria = nil
  unless hash['filterCriteria'].nil?
    filter_criteria = []
    hash['filterCriteria'].each do |structure|
      filter_criteria << (ReadySimServicePlan.from_hash(structure) if structure)
    end
  end

  filter_criteria = SKIP unless hash.key?('filterCriteria')
  # Parameter is an array, so we need to iterate through it
  condition = nil
  unless hash['condition'].nil?
    condition = []
    hash['condition'].each do |structure|
      condition << (Keyschunk2.from_hash(structure) if structure)
    end
  end

  condition = SKIP unless hash.key?('condition')
  enable_promo_exp =
    hash.key?('enablePromoExp') ? hash['enablePromoExp'] : SKIP

  # Create object from extracted values.
  PromoAlert.new(filter_criteria,
                 condition,
                 enable_promo_exp)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/verizon/models/promo_alert.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['filter_criteria'] = 'filterCriteria'
  @_hash['condition'] = 'condition'
  @_hash['enable_promo_exp'] = 'enablePromoExp'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/verizon/models/promo_alert.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/verizon/models/promo_alert.rb', line 34

def self.optionals
  %w[
    filter_criteria
    condition
    enable_promo_exp
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (PromoAlert | Hash)

    value against the validation is performed.



90
91
92
93
94
95
96
# File 'lib/verizon/models/promo_alert.rb', line 90

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



106
107
108
109
110
# File 'lib/verizon/models/promo_alert.rb', line 106

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} filter_criteria: #{@filter_criteria.inspect}, condition:"\
  " #{@condition.inspect}, enable_promo_exp: #{@enable_promo_exp.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



99
100
101
102
103
# File 'lib/verizon/models/promo_alert.rb', line 99

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} filter_criteria: #{@filter_criteria}, condition: #{@condition},"\
  " enable_promo_exp: #{@enable_promo_exp}>"
end