Class: Verizon::Rateplan

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/rateplan.rb

Overview

Rateplan Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(rate_plan_group = SKIP) ⇒ Rateplan

Returns a new instance of Rateplan.



35
36
37
# File 'lib/verizon/models/rateplan.rb', line 35

def initialize(rate_plan_group = SKIP)
  @rate_plan_group = rate_plan_group unless rate_plan_group == SKIP
end

Instance Attribute Details

#rate_plan_groupArray[RatePlanGroup]

An array of rate plan group names

Returns:



14
15
16
# File 'lib/verizon/models/rateplan.rb', line 14

def rate_plan_group
  @rate_plan_group
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



40
41
42
43
44
45
46
47
48
49
50
# File 'lib/verizon/models/rateplan.rb', line 40

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  rate_plan_group = hash.key?('ratePlanGroup') ? APIHelper.deserialize_union_type(
    UnionTypeLookUp.get(:RateplanRatePlanGroup), hash['ratePlanGroup']
  ) : SKIP

  # Create object from extracted values.
  Rateplan.new(rate_plan_group)
end

.namesObject

A mapping from model property names to API property names.



17
18
19
20
21
# File 'lib/verizon/models/rateplan.rb', line 17

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['rate_plan_group'] = 'ratePlanGroup'
  @_hash
end

.nullablesObject

An array for nullable fields



31
32
33
# File 'lib/verizon/models/rateplan.rb', line 31

def self.nullables
  []
end

.optionalsObject

An array for optional fields



24
25
26
27
28
# File 'lib/verizon/models/rateplan.rb', line 24

def self.optionals
  %w[
    rate_plan_group
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (Rateplan | Hash)

    value against the validation is performed.



54
55
56
57
58
59
60
# File 'lib/verizon/models/rateplan.rb', line 54

def self.validate(value)
  return true if value.instance_of? self

  return false unless value.instance_of? Hash

  true
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



69
70
71
72
# File 'lib/verizon/models/rateplan.rb', line 69

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} rate_plan_group: #{@rate_plan_group.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



63
64
65
66
# File 'lib/verizon/models/rateplan.rb', line 63

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} rate_plan_group: #{@rate_plan_group}>"
end