Class: Verizon::RateplantypeObject
- Defined in:
- lib/verizon/models/rateplantype_object.rb
Overview
RateplantypeObject Model.
Instance Attribute Summary collapse
-
#rate_plan ⇒ Array[Rateplantype2]
An array of rateplan names.
-
#rate_plan_group_description ⇒ String
TODO: Write general description for this method.
-
#rate_plan_type ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(rate_plan_group_description = SKIP, rate_plan_type = SKIP, rate_plan = SKIP) ⇒ RateplantypeObject
constructor
A new instance of RateplantypeObject.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(rate_plan_group_description = SKIP, rate_plan_type = SKIP, rate_plan = SKIP) ⇒ RateplantypeObject
Returns a new instance of RateplantypeObject.
47 48 49 50 51 52 53 54 55 |
# File 'lib/verizon/models/rateplantype_object.rb', line 47 def initialize(rate_plan_group_description = SKIP, rate_plan_type = SKIP, rate_plan = SKIP) unless rate_plan_group_description == SKIP @rate_plan_group_description = rate_plan_group_description end @rate_plan_type = rate_plan_type unless rate_plan_type == SKIP @rate_plan = rate_plan unless rate_plan == SKIP end |
Instance Attribute Details
#rate_plan ⇒ Array[Rateplantype2]
An array of rateplan names
22 23 24 |
# File 'lib/verizon/models/rateplantype_object.rb', line 22 def rate_plan @rate_plan end |
#rate_plan_group_description ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/verizon/models/rateplantype_object.rb', line 14 def rate_plan_group_description @rate_plan_group_description end |
#rate_plan_type ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/verizon/models/rateplantype_object.rb', line 18 def rate_plan_type @rate_plan_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/verizon/models/rateplantype_object.rb', line 58 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. rate_plan_group_description = hash.key?('ratePlanGroupDescription') ? hash['ratePlanGroupDescription'] : SKIP rate_plan_type = hash.key?('ratePlanType') ? hash['ratePlanType'] : SKIP # Parameter is an array, so we need to iterate through it rate_plan = nil unless hash['ratePlan'].nil? rate_plan = [] hash['ratePlan'].each do |structure| rate_plan << (Rateplantype2.from_hash(structure) if structure) end end rate_plan = SKIP unless hash.key?('ratePlan') # Create object from extracted values. RateplantypeObject.new(rate_plan_group_description, rate_plan_type, rate_plan) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/verizon/models/rateplantype_object.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['rate_plan_group_description'] = 'ratePlanGroupDescription' @_hash['rate_plan_type'] = 'ratePlanType' @_hash['rate_plan'] = 'ratePlan' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/verizon/models/rateplantype_object.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/verizon/models/rateplantype_object.rb', line 34 def self.optionals %w[ rate_plan_group_description rate_plan_type rate_plan ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
84 85 86 87 88 89 90 |
# File 'lib/verizon/models/rateplantype_object.rb', line 84 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
100 101 102 103 104 |
# File 'lib/verizon/models/rateplantype_object.rb', line 100 def inspect class_name = self.class.name.split('::').last "<#{class_name} rate_plan_group_description: #{@rate_plan_group_description.inspect},"\ " rate_plan_type: #{@rate_plan_type.inspect}, rate_plan: #{@rate_plan.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
93 94 95 96 97 |
# File 'lib/verizon/models/rateplantype_object.rb', line 93 def to_s class_name = self.class.name.split('::').last "<#{class_name} rate_plan_group_description: #{@rate_plan_group_description},"\ " rate_plan_type: #{@rate_plan_type}, rate_plan: #{@rate_plan}>" end |