Class: Verizon::ResourceIdentifier

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/resource_identifier.rb

Overview

The ID of the target to delete, in the format “dd1682d3-2d80-cefc-f3ee-25154800beff”.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(id = SKIP, imei = SKIP) ⇒ ResourceIdentifier

Returns a new instance of ResourceIdentifier.



42
43
44
45
# File 'lib/verizon/models/resource_identifier.rb', line 42

def initialize(id = SKIP, imei = SKIP)
  @id = id unless id == SKIP
  @imei = imei unless imei == SKIP
end

Instance Attribute Details

#idString

Target ID.

Returns:

  • (String)


15
16
17
# File 'lib/verizon/models/resource_identifier.rb', line 15

def id
  @id
end

#imeiString

Device IMEI.

Returns:

  • (String)


19
20
21
# File 'lib/verizon/models/resource_identifier.rb', line 19

def imei
  @imei
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



48
49
50
51
52
53
54
55
56
57
58
# File 'lib/verizon/models/resource_identifier.rb', line 48

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  id = hash.key?('id') ? hash['id'] : SKIP
  imei = hash.key?('imei') ? hash['imei'] : SKIP

  # Create object from extracted values.
  ResourceIdentifier.new(id,
                         imei)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/verizon/models/resource_identifier.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['id'] = 'id'
  @_hash['imei'] = 'imei'
  @_hash
end

.nullablesObject

An array for nullable fields



38
39
40
# File 'lib/verizon/models/resource_identifier.rb', line 38

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
33
34
35
# File 'lib/verizon/models/resource_identifier.rb', line 30

def self.optionals
  %w[
    id
    imei
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



67
68
69
70
# File 'lib/verizon/models/resource_identifier.rb', line 67

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id.inspect}, imei: #{@imei.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



61
62
63
64
# File 'lib/verizon/models/resource_identifier.rb', line 61

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id}, imei: #{@imei}>"
end