Class: Verizon::RetrieveRatePlanListController
- Inherits:
-
BaseController
- Object
- BaseController
- Verizon::RetrieveRatePlanListController
- Defined in:
- lib/verizon/controllers/retrieve_rate_plan_list_controller.rb
Overview
RetrieveRatePlanListController
Constant Summary
Constants inherited from BaseController
Instance Attribute Summary
Attributes inherited from BaseController
Instance Method Summary collapse
-
#get_rate_plan_list(ecpd_id) ⇒ ApiResponse
Retrieves the rate plans and rate plan details for a profile ID.
Methods inherited from BaseController
#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent
Constructor Details
This class inherits a constructor from Verizon::BaseController
Instance Method Details
#get_rate_plan_list(ecpd_id) ⇒ ApiResponse
Retrieves the rate plans and rate plan details for a profile ID. Profile Database ID. This is the same as the accountName value
13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 |
# File 'lib/verizon/controllers/retrieve_rate_plan_list_controller.rb', line 13 def get_rate_plan_list(ecpd_id) @api_call .request(new_request_builder(HttpMethodEnum::GET, '/v2/triggers/rateplanlist/{ecpdId}', Server::THINGSPACE) .template_param(new_parameter(ecpd_id, key: 'ecpdId') .should_encode(true)) .header_param(new_parameter('application/json', key: 'accept')) .auth(Or.new('thingspace_oauth1', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(Rateplan.method(:from_hash)) .is_api_response(true) .local_error('default', 'Error response', RuleRestErrorResponseException)) .execute end |