Class: Verizon::RetrieveResponseItem
- Defined in:
- lib/verizon/models/retrieve_response_item.rb
Overview
RetrieveResponseItem Model.
Instance Attribute Summary collapse
-
#failure ⇒ String
Present if retrieval failed.
-
#imei ⇒ String
TODO: Write general description for this method.
-
#username ⇒ String
Present if credentials exist.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(imei = SKIP, username = SKIP, failure = SKIP) ⇒ RetrieveResponseItem
constructor
A new instance of RetrieveResponseItem.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(imei = SKIP, username = SKIP, failure = SKIP) ⇒ RetrieveResponseItem
Returns a new instance of RetrieveResponseItem.
47 48 49 50 51 |
# File 'lib/verizon/models/retrieve_response_item.rb', line 47 def initialize(imei = SKIP, username = SKIP, failure = SKIP) @imei = imei unless imei == SKIP @username = username unless username == SKIP @failure = failure unless failure == SKIP end |
Instance Attribute Details
#failure ⇒ String
Present if retrieval failed
22 23 24 |
# File 'lib/verizon/models/retrieve_response_item.rb', line 22 def failure @failure end |
#imei ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/verizon/models/retrieve_response_item.rb', line 14 def imei @imei end |
#username ⇒ String
Present if credentials exist
18 19 20 |
# File 'lib/verizon/models/retrieve_response_item.rb', line 18 def username @username end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/verizon/models/retrieve_response_item.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. imei = hash.key?('imei') ? hash['imei'] : SKIP username = hash.key?('username') ? hash['username'] : SKIP failure = hash.key?('failure') ? hash['failure'] : SKIP # Create object from extracted values. RetrieveResponseItem.new(imei, username, failure) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/verizon/models/retrieve_response_item.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['imei'] = 'imei' @_hash['username'] = 'username' @_hash['failure'] = 'failure' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/verizon/models/retrieve_response_item.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/verizon/models/retrieve_response_item.rb', line 34 def self.optionals %w[ imei username failure ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
75 76 77 78 79 |
# File 'lib/verizon/models/retrieve_response_item.rb', line 75 def inspect class_name = self.class.name.split('::').last "<#{class_name} imei: #{@imei.inspect}, username: #{@username.inspect}, failure:"\ " #{@failure.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 |
# File 'lib/verizon/models/retrieve_response_item.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} imei: #{@imei}, username: #{@username}, failure: #{@failure}>" end |