Class: Verizon::SMSMessagesQueryResult

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/sms_messages_query_result.rb

Overview

Response to SMS messages sent by all M2M devices associated with a billing account.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(has_more_data = SKIP, messages = SKIP) ⇒ SMSMessagesQueryResult

Returns a new instance of SMSMessagesQueryResult.



44
45
46
47
# File 'lib/verizon/models/sms_messages_query_result.rb', line 44

def initialize(has_more_data = SKIP, messages = SKIP)
  @has_more_data = has_more_data unless has_more_data == SKIP
  @messages = messages unless messages == SKIP
end

Instance Attribute Details

#has_more_dataTrueClass | FalseClass

False for a status 200 response.True for a status 202 response, indicating that there is more data to be retrieved.

Returns:

  • (TrueClass | FalseClass)


16
17
18
# File 'lib/verizon/models/sms_messages_query_result.rb', line 16

def has_more_data
  @has_more_data
end

#messagesArray[SMSMessage]

An array of up to 100 SMS messages that were sent by devices in the account.

Returns:



21
22
23
# File 'lib/verizon/models/sms_messages_query_result.rb', line 21

def messages
  @messages
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/verizon/models/sms_messages_query_result.rb', line 50

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  has_more_data = hash.key?('hasMoreData') ? hash['hasMoreData'] : SKIP
  # Parameter is an array, so we need to iterate through it
  messages = nil
  unless hash['messages'].nil?
    messages = []
    hash['messages'].each do |structure|
      messages << (SMSMessage.from_hash(structure) if structure)
    end
  end

  messages = SKIP unless hash.key?('messages')

  # Create object from extracted values.
  SMSMessagesQueryResult.new(has_more_data,
                             messages)
end

.namesObject

A mapping from model property names to API property names.



24
25
26
27
28
29
# File 'lib/verizon/models/sms_messages_query_result.rb', line 24

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['has_more_data'] = 'hasMoreData'
  @_hash['messages'] = 'messages'
  @_hash
end

.nullablesObject

An array for nullable fields



40
41
42
# File 'lib/verizon/models/sms_messages_query_result.rb', line 40

def self.nullables
  []
end

.optionalsObject

An array for optional fields



32
33
34
35
36
37
# File 'lib/verizon/models/sms_messages_query_result.rb', line 32

def self.optionals
  %w[
    has_more_data
    messages
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



78
79
80
81
# File 'lib/verizon/models/sms_messages_query_result.rb', line 78

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} has_more_data: #{@has_more_data.inspect}, messages: #{@messages.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



72
73
74
75
# File 'lib/verizon/models/sms_messages_query_result.rb', line 72

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} has_more_data: #{@has_more_data}, messages: #{@messages}>"
end