Class: Verizon::SensorInsightsDeviceProfileController

Inherits:
BaseController
  • Object
show all
Defined in:
lib/verizon/controllers/sensor_insights_device_profile_controller.rb

Overview

SensorInsightsDeviceProfileController

Constant Summary

Constants inherited from BaseController

BaseController::GLOBAL_ERRORS

Instance Attribute Summary

Attributes inherited from BaseController

#config, #http_call_back

Instance Method Summary collapse

Methods inherited from BaseController

#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent

Constructor Details

This class inherits a constructor from Verizon::BaseController

Instance Method Details

#create_a_profile(body) ⇒ ApiResponse

Create a device profile description here

Parameters:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
# File 'lib/verizon/controllers/sensor_insights_device_profile_controller.rb', line 13

def create_a_profile(body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/dm/v1/deviceConfigurationProfiles',
                                 Server::THINGSPACE)
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(DtoProfileResponse.method(:from_hash))
                .is_api_response(true)
                .is_response_array(true)
                .local_error('400',
                             'Bad Request',
                             M400ManagementErrorException)
                .local_error('401',
                             'UnAuthorized',
                             ManagementErrorException)
                .local_error('403',
                             'Forbidden',
                             M403ManagementErrorException)
                .local_error('500',
                             'Internal server error.',
                             M500ManagementErrorException))
    .execute
end

#delete_a_profile(deleterequest) ⇒ ApiResponse

Delete a device profile payload for the delete request

Parameters:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/verizon/controllers/sensor_insights_device_profile_controller.rb', line 47

def delete_a_profile(deleterequest)
  @api_call
    .request(new_request_builder(HttpMethodEnum::DELETE,
                                 '/dm/v1/deviceConfigurationProfiles',
                                 Server::THINGSPACE)
               .header_param(new_parameter(deleterequest, key: 'deleterequest'))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(DtoProfileResponse.method(:from_hash))
                .is_api_response(true)
                .is_response_array(true)
                .local_error('400',
                             'Bad Request',
                             M400ManagementErrorException)
                .local_error('401',
                             'UnAuthorized',
                             ManagementErrorException)
                .local_error('403',
                             'Forbidden',
                             M403ManagementErrorException)
                .local_error('500',
                             'Internal server error.',
                             M500ManagementErrorException))
    .execute
end

#query_a_profile(body) ⇒ ApiResponse

Query a device profile for an individual device

Parameters:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/verizon/controllers/sensor_insights_device_profile_controller.rb', line 112

def query_a_profile(body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/dm/v1/deviceConfigurationProfiles/actions/query',
                                 Server::THINGSPACE)
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(DtoProfileResponse.method(:from_hash))
                .is_api_response(true)
                .is_response_array(true)
                .local_error('400',
                             'Bad Request',
                             M400ManagementErrorException)
                .local_error('401',
                             'UnAuthorized',
                             ManagementErrorException)
                .local_error('403',
                             'Forbidden',
                             M403ManagementErrorException)
                .local_error('500',
                             'Internal server error.',
                             M500ManagementErrorException))
    .execute
end

#update_a_profile(body) ⇒ ApiResponse

Partially update a device profile description here

Parameters:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/verizon/controllers/sensor_insights_device_profile_controller.rb', line 79

def update_a_profile(body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::PATCH,
                                 '/dm/v1/deviceConfigurationProfiles',
                                 Server::THINGSPACE)
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(DtoProfileResponse.method(:from_hash))
                .is_api_response(true)
                .is_response_array(true)
                .local_error('400',
                             'Bad Request',
                             M400ManagementErrorException)
                .local_error('401',
                             'UnAuthorized',
                             ManagementErrorException)
                .local_error('403',
                             'Forbidden',
                             M403ManagementErrorException)
                .local_error('500',
                             'Internal server error.',
                             M500ManagementErrorException))
    .execute
end