Class: Verizon::SensorInsightsHealthScoreController

Inherits:
BaseController show all
Defined in:
lib/verizon/controllers/sensor_insights_health_score_controller.rb

Overview

SensorInsightsHealthScoreController

Constant Summary

Constants inherited from BaseController

BaseController::GLOBAL_ERRORS

Instance Attribute Summary

Attributes inherited from BaseController

#config, #http_call_back

Instance Method Summary collapse

Methods inherited from BaseController

#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent

Constructor Details

This class inherits a constructor from Verizon::BaseController

Instance Method Details

#sensor_insights_get_network_health_score_responseApiResponse

TODO: type endpoint description here

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/verizon/controllers/sensor_insights_health_score_controller.rb', line 51

def sensor_insights_get_network_health_score_response
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/dm/v1/healthscore/network',
                                 Server::THINGSPACE)
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(DtoGetNetworkHealthScoreResponse.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'Bad Request',
                             M400ManagementErrorException)
                .local_error('401',
                             'UnAuthorized',
                             ManagementErrorException)
                .local_error('403',
                             'Forbidden',
                             M403ManagementErrorException)
                .local_error('406',
                             'Not Acceptable',
                             ManagementErrorException)
                .local_error('415',
                             'Unsupported media type',
                             ManagementErrorException)
                .local_error('429',
                             'Too many requests',
                             ManagementErrorException)
                .local_error('500',
                             'Internal server error.',
                             M500ManagementErrorException)
                .local_error('default',
                             'Unexpected error',
                             ManagementErrorException))
    .execute
end

#sensor_insights_health_score_summaryApiResponse

TODO: type endpoint description here

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
# File 'lib/verizon/controllers/sensor_insights_health_score_controller.rb', line 11

def sensor_insights_health_score_summary
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/dm/v1/healthscore/summary',
                                 Server::THINGSPACE)
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(And.new('thingspace_oauth', 'VZ-M2M-Token')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(DtoHealthScoreSummary.method(:from_hash))
                .is_api_response(true)
                .local_error('400',
                             'Bad Request',
                             M400ManagementErrorException)
                .local_error('401',
                             'UnAuthorized',
                             ManagementErrorException)
                .local_error('403',
                             'Forbidden',
                             M403ManagementErrorException)
                .local_error('406',
                             'Not Acceptable',
                             ManagementErrorException)
                .local_error('415',
                             'Unsupported media type',
                             ManagementErrorException)
                .local_error('429',
                             'Too many requests',
                             ManagementErrorException)
                .local_error('500',
                             'Internal server error.',
                             M500ManagementErrorException)
                .local_error('default',
                             'Unexpected error',
                             ManagementErrorException))
    .execute
end