Class: Verizon::StatusList
- Defined in:
- lib/verizon/models/status_list.rb
Overview
StatusList Model.
Instance Attribute Summary collapse
-
#id ⇒ String
Account name.
-
#reason ⇒ String
detailed reason.
-
#status ⇒ String
Success or Fail.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(id = SKIP, status = SKIP, reason = SKIP) ⇒ StatusList
constructor
A new instance of StatusList.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(id = SKIP, status = SKIP, reason = SKIP) ⇒ StatusList
Returns a new instance of StatusList.
47 48 49 50 51 |
# File 'lib/verizon/models/status_list.rb', line 47 def initialize(id = SKIP, status = SKIP, reason = SKIP) @id = id unless id == SKIP @status = status unless status == SKIP @reason = reason unless reason == SKIP end |
Instance Attribute Details
#id ⇒ String
Account name
14 15 16 |
# File 'lib/verizon/models/status_list.rb', line 14 def id @id end |
#reason ⇒ String
detailed reason
22 23 24 |
# File 'lib/verizon/models/status_list.rb', line 22 def reason @reason end |
#status ⇒ String
Success or Fail
18 19 20 |
# File 'lib/verizon/models/status_list.rb', line 18 def status @status end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/verizon/models/status_list.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. id = hash.key?('id') ? hash['id'] : SKIP status = hash.key?('status') ? hash['status'] : SKIP reason = hash.key?('reason') ? hash['reason'] : SKIP # Create object from extracted values. StatusList.new(id, status, reason) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/verizon/models/status_list.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['id'] = 'id' @_hash['status'] = 'status' @_hash['reason'] = 'reason' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/verizon/models/status_list.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/verizon/models/status_list.rb', line 34 def self.optionals %w[ id status reason ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
75 76 77 78 79 |
# File 'lib/verizon/models/status_list.rb', line 75 def inspect class_name = self.class.name.split('::').last "<#{class_name} id: #{@id.inspect}, status: #{@status.inspect}, reason:"\ " #{@reason.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 |
# File 'lib/verizon/models/status_list.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} id: #{@id}, status: #{@status}, reason: #{@reason}>" end |