Class: Verizon::TargetAuthentication
- Defined in:
- lib/verizon/models/target_authentication.rb
Overview
OAuth 2 token and refresh token for TS to stream events to Target.
Instance Attribute Summary collapse
-
#body ⇒ TargetAuthenticationBody
TODO: Write general description for this method.
-
#version ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(body = SKIP, version = SKIP) ⇒ TargetAuthentication
constructor
A new instance of TargetAuthentication.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(body = SKIP, version = SKIP) ⇒ TargetAuthentication
Returns a new instance of TargetAuthentication.
41 42 43 44 |
# File 'lib/verizon/models/target_authentication.rb', line 41 def initialize(body = SKIP, version = SKIP) @body = body unless body == SKIP @version = version unless version == SKIP end |
Instance Attribute Details
#body ⇒ TargetAuthenticationBody
TODO: Write general description for this method
14 15 16 |
# File 'lib/verizon/models/target_authentication.rb', line 14 def body @body end |
#version ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/verizon/models/target_authentication.rb', line 18 def version @version end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/verizon/models/target_authentication.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. body = TargetAuthenticationBody.from_hash(hash['body']) if hash['body'] version = hash.key?('version') ? hash['version'] : SKIP # Create object from extracted values. TargetAuthentication.new(body, version) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/verizon/models/target_authentication.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['body'] = 'body' @_hash['version'] = 'version' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/verizon/models/target_authentication.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/verizon/models/target_authentication.rb', line 29 def self.optionals %w[ body version ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 |
# File 'lib/verizon/models/target_authentication.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} body: #{@body.inspect}, version: #{@version.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/verizon/models/target_authentication.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} body: #{@body}, version: #{@version}>" end |