Class: Verizon::TextPhraseOrITIS

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/verizon/models/text_phrase_or_itis.rb

Overview

TextPhraseOrITIS Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(item = nil) ⇒ TextPhraseOrITIS

Returns a new instance of TextPhraseOrITIS.



33
34
35
# File 'lib/verizon/models/text_phrase_or_itis.rb', line 33

def initialize(item = nil)
  @item = item
end

Instance Attribute Details

#itemItem

TODO: Write general description for this method

Returns:



14
15
16
# File 'lib/verizon/models/text_phrase_or_itis.rb', line 14

def item
  @item
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



38
39
40
41
42
43
44
45
46
# File 'lib/verizon/models/text_phrase_or_itis.rb', line 38

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  item = Item.from_hash(hash['item']) if hash['item']

  # Create object from extracted values.
  TextPhraseOrITIS.new(item)
end

.namesObject

A mapping from model property names to API property names.



17
18
19
20
21
# File 'lib/verizon/models/text_phrase_or_itis.rb', line 17

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['item'] = 'item'
  @_hash
end

.nullablesObject

An array for nullable fields



29
30
31
# File 'lib/verizon/models/text_phrase_or_itis.rb', line 29

def self.nullables
  []
end

.optionalsObject

An array for optional fields



24
25
26
# File 'lib/verizon/models/text_phrase_or_itis.rb', line 24

def self.optionals
  []
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:



50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/verizon/models/text_phrase_or_itis.rb', line 50

def self.validate(value)
  if value.instance_of? self
    return APIHelper.valid_type?(value.item,
                                 ->(val) { Item.validate(val) },
                                 is_model_hash: true)
  end

  return false unless value.instance_of? Hash

  APIHelper.valid_type?(value['item'],
                        ->(val) { Item.validate(val) },
                        is_model_hash: true)
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



71
72
73
74
# File 'lib/verizon/models/text_phrase_or_itis.rb', line 71

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} item: #{@item.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



65
66
67
68
# File 'lib/verizon/models/text_phrase_or_itis.rb', line 65

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} item: #{@item}>"
end