Class: Verizon::TransactionID
- Defined in:
- lib/verizon/models/transaction_id.rb
Overview
The transaction ID of the request that you want to cancel, from the POST /devicelocations synchronus response.
Instance Attribute Summary collapse
-
#txid ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(txid = SKIP) ⇒ TransactionID
constructor
A new instance of TransactionID.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(txid = SKIP) ⇒ TransactionID
Returns a new instance of TransactionID.
36 37 38 |
# File 'lib/verizon/models/transaction_id.rb', line 36 def initialize(txid = SKIP) @txid = txid unless txid == SKIP end |
Instance Attribute Details
#txid ⇒ String
TODO: Write general description for this method
15 16 17 |
# File 'lib/verizon/models/transaction_id.rb', line 15 def txid @txid end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
41 42 43 44 45 46 47 48 49 |
# File 'lib/verizon/models/transaction_id.rb', line 41 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. txid = hash.key?('txid') ? hash['txid'] : SKIP # Create object from extracted values. TransactionID.new(txid) end |
.names ⇒ Object
A mapping from model property names to API property names.
18 19 20 21 22 |
# File 'lib/verizon/models/transaction_id.rb', line 18 def self.names @_hash = {} if @_hash.nil? @_hash['txid'] = 'txid' @_hash end |
.nullables ⇒ Object
An array for nullable fields
32 33 34 |
# File 'lib/verizon/models/transaction_id.rb', line 32 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
25 26 27 28 29 |
# File 'lib/verizon/models/transaction_id.rb', line 25 def self.optionals %w[ txid ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
58 59 60 61 |
# File 'lib/verizon/models/transaction_id.rb', line 58 def inspect class_name = self.class.name.split('::').last "<#{class_name} txid: #{@txid.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
52 53 54 55 |
# File 'lib/verizon/models/transaction_id.rb', line 52 def to_s class_name = self.class.name.split('::').last "<#{class_name} txid: #{@txid}>" end |