Class: Verizon::Tscore
- Defined in:
- lib/verizon/models/tscore.rb
Overview
Tscore Model.
Instance Attribute Summary collapse
-
#profileid ⇒ String
the UUID of the profile.
-
#profileversionid ⇒ String
the UUID of the profile version.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(profileid = SKIP, profileversionid = SKIP) ⇒ Tscore
constructor
A new instance of Tscore.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(profileid = SKIP, profileversionid = SKIP) ⇒ Tscore
Returns a new instance of Tscore.
41 42 43 44 |
# File 'lib/verizon/models/tscore.rb', line 41 def initialize(profileid = SKIP, profileversionid = SKIP) @profileid = profileid unless profileid == SKIP @profileversionid = profileversionid unless profileversionid == SKIP end |
Instance Attribute Details
#profileid ⇒ String
the UUID of the profile
14 15 16 |
# File 'lib/verizon/models/tscore.rb', line 14 def profileid @profileid end |
#profileversionid ⇒ String
the UUID of the profile version
18 19 20 |
# File 'lib/verizon/models/tscore.rb', line 18 def profileversionid @profileversionid end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/verizon/models/tscore.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. profileid = hash.key?('profileid') ? hash['profileid'] : SKIP profileversionid = hash.key?('profileversionid') ? hash['profileversionid'] : SKIP # Create object from extracted values. Tscore.new(profileid, profileversionid) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/verizon/models/tscore.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['profileid'] = 'profileid' @_hash['profileversionid'] = 'profileversionid' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/verizon/models/tscore.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/verizon/models/tscore.rb', line 29 def self.optionals %w[ profileid profileversionid ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
62 63 64 65 66 67 68 |
# File 'lib/verizon/models/tscore.rb', line 62 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
77 78 79 80 81 |
# File 'lib/verizon/models/tscore.rb', line 77 def inspect class_name = self.class.name.split('::').last "<#{class_name} profileid: #{@profileid.inspect}, profileversionid:"\ " #{@profileversionid.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
71 72 73 74 |
# File 'lib/verizon/models/tscore.rb', line 71 def to_s class_name = self.class.name.split('::').last "<#{class_name} profileid: #{@profileid}, profileversionid: #{@profileversionid}>" end |