Class: Verizon::V2LicenseIMEI
- Defined in:
- lib/verizon/models/v2_license_imei.rb
Overview
IMEIs of the devices to assign or remove licenses.
Instance Attribute Summary collapse
-
#account_name ⇒ String
Account name.
-
#device_list ⇒ Array[String]
Device IMEI list.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(device_list = nil, account_name = SKIP) ⇒ V2LicenseIMEI
constructor
A new instance of V2LicenseIMEI.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(device_list = nil, account_name = SKIP) ⇒ V2LicenseIMEI
Returns a new instance of V2LicenseIMEI.
40 41 42 43 |
# File 'lib/verizon/models/v2_license_imei.rb', line 40 def initialize(device_list = nil, account_name = SKIP) @account_name = account_name unless account_name == SKIP @device_list = device_list end |
Instance Attribute Details
#account_name ⇒ String
Account name.
14 15 16 |
# File 'lib/verizon/models/v2_license_imei.rb', line 14 def account_name @account_name end |
#device_list ⇒ Array[String]
Device IMEI list.
18 19 20 |
# File 'lib/verizon/models/v2_license_imei.rb', line 18 def device_list @device_list end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/verizon/models/v2_license_imei.rb', line 46 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. device_list = hash.key?('deviceList') ? hash['deviceList'] : nil account_name = hash.key?('accountName') ? hash['accountName'] : SKIP # Create object from extracted values. V2LicenseIMEI.new(device_list, account_name) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/verizon/models/v2_license_imei.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['account_name'] = 'accountName' @_hash['device_list'] = 'deviceList' @_hash end |
.nullables ⇒ Object
An array for nullable fields
36 37 38 |
# File 'lib/verizon/models/v2_license_imei.rb', line 36 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 |
# File 'lib/verizon/models/v2_license_imei.rb', line 29 def self.optionals %w[ account_name ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
65 66 67 68 69 |
# File 'lib/verizon/models/v2_license_imei.rb', line 65 def inspect class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name.inspect}, device_list:"\ " #{@device_list.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
59 60 61 62 |
# File 'lib/verizon/models/v2_license_imei.rb', line 59 def to_s class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name}, device_list: #{@device_list}>" end |