Class: Verizon::V2TimeWindow
- Defined in:
- lib/verizon/models/v2_time_window.rb
Overview
Allowed start and end time windows.
Instance Attribute Summary collapse
-
#end_time ⇒ Integer
End hour in range [1..24], current hour < endTime.
-
#start_time ⇒ Integer
Start hour in range [0..23], current hour >= startTime.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(start_time = nil, end_time = nil) ⇒ V2TimeWindow
constructor
A new instance of V2TimeWindow.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(start_time = nil, end_time = nil) ⇒ V2TimeWindow
Returns a new instance of V2TimeWindow.
38 39 40 41 |
# File 'lib/verizon/models/v2_time_window.rb', line 38 def initialize(start_time = nil, end_time = nil) @start_time = start_time @end_time = end_time end |
Instance Attribute Details
#end_time ⇒ Integer
End hour in range [1..24], current hour < endTime.
18 19 20 |
# File 'lib/verizon/models/v2_time_window.rb', line 18 def end_time @end_time end |
#start_time ⇒ Integer
Start hour in range [0..23], current hour >= startTime.
14 15 16 |
# File 'lib/verizon/models/v2_time_window.rb', line 14 def start_time @start_time end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/verizon/models/v2_time_window.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. start_time = hash.key?('startTime') ? hash['startTime'] : nil end_time = hash.key?('endTime') ? hash['endTime'] : nil # Create object from extracted values. V2TimeWindow.new(start_time, end_time) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/verizon/models/v2_time_window.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['start_time'] = 'startTime' @_hash['end_time'] = 'endTime' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/verizon/models/v2_time_window.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/verizon/models/v2_time_window.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
63 64 65 66 |
# File 'lib/verizon/models/v2_time_window.rb', line 63 def inspect class_name = self.class.name.split('::').last "<#{class_name} start_time: #{@start_time.inspect}, end_time: #{@end_time.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
57 58 59 60 |
# File 'lib/verizon/models/v2_time_window.rb', line 57 def to_s class_name = self.class.name.split('::').last "<#{class_name} start_time: #{@start_time}, end_time: #{@end_time}>" end |