Class: Verizon::V3LicenseIMEI
- Defined in:
- lib/verizon/models/v3_license_imei.rb
Overview
List of devices.
Instance Attribute Summary collapse
-
#device_list ⇒ Array[String]
Device IMEI list.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(device_list = nil) ⇒ V3LicenseIMEI
constructor
A new instance of V3LicenseIMEI.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(device_list = nil) ⇒ V3LicenseIMEI
Returns a new instance of V3LicenseIMEI.
33 34 35 |
# File 'lib/verizon/models/v3_license_imei.rb', line 33 def initialize(device_list = nil) @device_list = device_list end |
Instance Attribute Details
#device_list ⇒ Array[String]
Device IMEI list.
14 15 16 |
# File 'lib/verizon/models/v3_license_imei.rb', line 14 def device_list @device_list end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
38 39 40 41 42 43 44 45 46 |
# File 'lib/verizon/models/v3_license_imei.rb', line 38 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. device_list = hash.key?('deviceList') ? hash['deviceList'] : nil # Create object from extracted values. V3LicenseIMEI.new(device_list) end |
.names ⇒ Object
A mapping from model property names to API property names.
17 18 19 20 21 |
# File 'lib/verizon/models/v3_license_imei.rb', line 17 def self.names @_hash = {} if @_hash.nil? @_hash['device_list'] = 'deviceList' @_hash end |
.nullables ⇒ Object
An array for nullable fields
29 30 31 |
# File 'lib/verizon/models/v3_license_imei.rb', line 29 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
24 25 26 |
# File 'lib/verizon/models/v3_license_imei.rb', line 24 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
55 56 57 58 |
# File 'lib/verizon/models/v3_license_imei.rb', line 55 def inspect class_name = self.class.name.split('::').last "<#{class_name} device_list: #{@device_list.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
49 50 51 52 |
# File 'lib/verizon/models/v3_license_imei.rb', line 49 def to_s class_name = self.class.name.split('::').last "<#{class_name} device_list: #{@device_list}>" end |