Class: Verizon::AggregateUsageItem
- Defined in:
- lib/verizon/models/aggregate_usage_item.rb
Overview
Contains usage information per device.
Instance Attribute Summary collapse
-
#bytes_transferred ⇒ Integer
The amount of data transferred by the device reporting usage, measured in Bytes.
-
#imei ⇒ String
The International Mobile Equipment Identifier of the device.
-
#number_of_sessions ⇒ Integer
Number of sessions established by the device reporting usage.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(imei = SKIP, number_of_sessions = SKIP, bytes_transferred = SKIP) ⇒ AggregateUsageItem
constructor
A new instance of AggregateUsageItem.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(imei = SKIP, number_of_sessions = SKIP, bytes_transferred = SKIP) ⇒ AggregateUsageItem
Returns a new instance of AggregateUsageItem.
48 49 50 51 52 53 |
# File 'lib/verizon/models/aggregate_usage_item.rb', line 48 def initialize(imei = SKIP, number_of_sessions = SKIP, bytes_transferred = SKIP) @imei = imei unless imei == SKIP @number_of_sessions = number_of_sessions unless number_of_sessions == SKIP @bytes_transferred = bytes_transferred unless bytes_transferred == SKIP end |
Instance Attribute Details
#bytes_transferred ⇒ Integer
The amount of data transferred by the device reporting usage, measured in Bytes.
23 24 25 |
# File 'lib/verizon/models/aggregate_usage_item.rb', line 23 def bytes_transferred @bytes_transferred end |
#imei ⇒ String
The International Mobile Equipment Identifier of the device.
14 15 16 |
# File 'lib/verizon/models/aggregate_usage_item.rb', line 14 def imei @imei end |
#number_of_sessions ⇒ Integer
Number of sessions established by the device reporting usage.
18 19 20 |
# File 'lib/verizon/models/aggregate_usage_item.rb', line 18 def number_of_sessions @number_of_sessions end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/verizon/models/aggregate_usage_item.rb', line 56 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. imei = hash.key?('imei') ? hash['imei'] : SKIP number_of_sessions = hash.key?('numberOfSessions') ? hash['numberOfSessions'] : SKIP bytes_transferred = hash.key?('bytesTransferred') ? hash['bytesTransferred'] : SKIP # Create object from extracted values. AggregateUsageItem.new(imei, number_of_sessions, bytes_transferred) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 32 |
# File 'lib/verizon/models/aggregate_usage_item.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['imei'] = 'imei' @_hash['number_of_sessions'] = 'numberOfSessions' @_hash['bytes_transferred'] = 'bytesTransferred' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/verizon/models/aggregate_usage_item.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 38 39 40 41 |
# File 'lib/verizon/models/aggregate_usage_item.rb', line 35 def self.optionals %w[ imei number_of_sessions bytes_transferred ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
80 81 82 83 84 |
# File 'lib/verizon/models/aggregate_usage_item.rb', line 80 def inspect class_name = self.class.name.split('::').last "<#{class_name} imei: #{@imei.inspect}, number_of_sessions: #{@number_of_sessions.inspect},"\ " bytes_transferred: #{@bytes_transferred.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
73 74 75 76 77 |
# File 'lib/verizon/models/aggregate_usage_item.rb', line 73 def to_s class_name = self.class.name.split('::').last "<#{class_name} imei: #{@imei}, number_of_sessions: #{@number_of_sessions},"\ " bytes_transferred: #{@bytes_transferred}>" end |