Class: Verizon::BullseyeServiceRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::BullseyeServiceRequest
- Defined in:
- lib/verizon/models/bullseye_service_request.rb
Overview
Account number and list of devices.
Instance Attribute Summary collapse
-
#account_number ⇒ String
The numeric ID of the account and must include leading zeroes.
-
#device_list ⇒ Array[DeviceServiceRequest]
A list of devices.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(device_list = nil, account_number = nil) ⇒ BullseyeServiceRequest
constructor
A new instance of BullseyeServiceRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(device_list = nil, account_number = nil) ⇒ BullseyeServiceRequest
Returns a new instance of BullseyeServiceRequest.
39 40 41 42 |
# File 'lib/verizon/models/bullseye_service_request.rb', line 39 def initialize(device_list = nil, account_number = nil) @device_list = device_list @account_number = account_number end |
Instance Attribute Details
#account_number ⇒ String
The numeric ID of the account and must include leading zeroes. This value is indentical to ‘accountName`.
19 20 21 |
# File 'lib/verizon/models/bullseye_service_request.rb', line 19 def account_number @account_number end |
#device_list ⇒ Array[DeviceServiceRequest]
A list of devices.
14 15 16 |
# File 'lib/verizon/models/bullseye_service_request.rb', line 14 def device_list @device_list end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/verizon/models/bullseye_service_request.rb', line 45 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it device_list = nil unless hash['deviceList'].nil? device_list = [] hash['deviceList'].each do |structure| device_list << (DeviceServiceRequest.from_hash(structure) if structure) end end device_list = nil unless hash.key?('deviceList') account_number = hash.key?('accountNumber') ? hash['accountNumber'] : nil # Create object from extracted values. BullseyeServiceRequest.new(device_list, account_number) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/verizon/models/bullseye_service_request.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['device_list'] = 'deviceList' @_hash['account_number'] = 'accountNumber' @_hash end |
.nullables ⇒ Object
An array for nullable fields
35 36 37 |
# File 'lib/verizon/models/bullseye_service_request.rb', line 35 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 |
# File 'lib/verizon/models/bullseye_service_request.rb', line 30 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
73 74 75 76 77 |
# File 'lib/verizon/models/bullseye_service_request.rb', line 73 def inspect class_name = self.class.name.split('::').last "<#{class_name} device_list: #{@device_list.inspect}, account_number:"\ " #{@account_number.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
67 68 69 70 |
# File 'lib/verizon/models/bullseye_service_request.rb', line 67 def to_s class_name = self.class.name.split('::').last "<#{class_name} device_list: #{@device_list}, account_number: #{@account_number}>" end |