Class: Verizon::DtoConfigurationProfilePath
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Verizon::DtoConfigurationProfilePath
- Defined in:
- lib/verizon/models/dto_configuration_profile_path.rb
Overview
DtoConfigurationProfilePath Model.
Instance Attribute Summary collapse
-
#account_name ⇒ String
The numeric account name, which must include leading zeros.
-
#profile ⇒ DtoProfile
The numeric account name, which must include leading zeros.
-
#resourceidentifier ⇒ DtoResourceidentifier
The numeric account name, which must include leading zeros.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(account_name = SKIP, resourceidentifier = SKIP, profile = SKIP) ⇒ DtoConfigurationProfilePath
constructor
A new instance of DtoConfigurationProfilePath.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(account_name = SKIP, resourceidentifier = SKIP, profile = SKIP) ⇒ DtoConfigurationProfilePath
Returns a new instance of DtoConfigurationProfilePath.
47 48 49 50 51 52 |
# File 'lib/verizon/models/dto_configuration_profile_path.rb', line 47 def initialize(account_name = SKIP, resourceidentifier = SKIP, profile = SKIP) @account_name = account_name unless account_name == SKIP @resourceidentifier = resourceidentifier unless resourceidentifier == SKIP @profile = profile unless profile == SKIP end |
Instance Attribute Details
#account_name ⇒ String
The numeric account name, which must include leading zeros
14 15 16 |
# File 'lib/verizon/models/dto_configuration_profile_path.rb', line 14 def account_name @account_name end |
#profile ⇒ DtoProfile
The numeric account name, which must include leading zeros
22 23 24 |
# File 'lib/verizon/models/dto_configuration_profile_path.rb', line 22 def profile @profile end |
#resourceidentifier ⇒ DtoResourceidentifier
The numeric account name, which must include leading zeros
18 19 20 |
# File 'lib/verizon/models/dto_configuration_profile_path.rb', line 18 def resourceidentifier @resourceidentifier end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/verizon/models/dto_configuration_profile_path.rb', line 55 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. account_name = hash.key?('accountName') ? hash['accountName'] : SKIP resourceidentifier = DtoResourceidentifier.from_hash(hash['resourceidentifier']) if hash['resourceidentifier'] profile = DtoProfile.from_hash(hash['profile']) if hash['profile'] # Create object from extracted values. DtoConfigurationProfilePath.new(account_name, resourceidentifier, profile) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/verizon/models/dto_configuration_profile_path.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['account_name'] = 'accountName' @_hash['resourceidentifier'] = 'resourceidentifier' @_hash['profile'] = 'profile' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/verizon/models/dto_configuration_profile_path.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/verizon/models/dto_configuration_profile_path.rb', line 34 def self.optionals %w[ account_name resourceidentifier profile ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
78 79 80 81 82 |
# File 'lib/verizon/models/dto_configuration_profile_path.rb', line 78 def inspect class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name.inspect}, resourceidentifier:"\ " #{@resourceidentifier.inspect}, profile: #{@profile.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
71 72 73 74 75 |
# File 'lib/verizon/models/dto_configuration_profile_path.rb', line 71 def to_s class_name = self.class.name.split('::').last "<#{class_name} account_name: #{@account_name}, resourceidentifier: #{@resourceidentifier},"\ " profile: #{@profile}>" end |