Class: Verizon::EtsiAlert
- Defined in:
- lib/verizon/models/etsi_alert.rb
Overview
EtsiAlert Model.
Instance Attribute Summary collapse
-
#denm ⇒ DenmPayload
The payload of the DENM PDU.
-
#header ⇒ Header
The header of the DENM PDU.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(header = nil, denm = nil) ⇒ EtsiAlert
constructor
A new instance of EtsiAlert.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(header = nil, denm = nil) ⇒ EtsiAlert
Returns a new instance of EtsiAlert.
38 39 40 41 |
# File 'lib/verizon/models/etsi_alert.rb', line 38 def initialize(header = nil, denm = nil) @header = header @denm = denm end |
Instance Attribute Details
#denm ⇒ DenmPayload
The payload of the DENM PDU.
18 19 20 |
# File 'lib/verizon/models/etsi_alert.rb', line 18 def denm @denm end |
#header ⇒ Header
The header of the DENM PDU.
14 15 16 |
# File 'lib/verizon/models/etsi_alert.rb', line 14 def header @header end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/verizon/models/etsi_alert.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. header = Header.from_hash(hash['header']) if hash['header'] denm = DenmPayload.from_hash(hash['denm']) if hash['denm'] # Create object from extracted values. EtsiAlert.new(header, denm) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/verizon/models/etsi_alert.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['header'] = 'header' @_hash['denm'] = 'denm' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/verizon/models/etsi_alert.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/verizon/models/etsi_alert.rb', line 29 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/verizon/models/etsi_alert.rb', line 58 def self.validate(value) if value.instance_of? self return ( APIHelper.valid_type?(value.header, ->(val) { Header.validate(val) }, is_model_hash: true) and APIHelper.valid_type?(value.denm, ->(val) { DenmPayload.validate(val) }, is_model_hash: true) ) end return false unless value.instance_of? Hash ( APIHelper.valid_type?(value['header'], ->(val) { Header.validate(val) }, is_model_hash: true) and APIHelper.valid_type?(value['denm'], ->(val) { DenmPayload.validate(val) }, is_model_hash: true) ) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
89 90 91 92 |
# File 'lib/verizon/models/etsi_alert.rb', line 89 def inspect class_name = self.class.name.split('::').last "<#{class_name} header: #{@header.inspect}, denm: #{@denm.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
83 84 85 86 |
# File 'lib/verizon/models/etsi_alert.rb', line 83 def to_s class_name = self.class.name.split('::').last "<#{class_name} header: #{@header}, denm: #{@denm}>" end |