Class: Verizon::EventType
- Defined in:
- lib/verizon/models/event_type.rb
Overview
The type of event including direct and sub cause.
Instance Attribute Summary collapse
-
#cc_and_scc ⇒ Object
The main cause of a detected event.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(cc_and_scc = SKIP) ⇒ EventType
constructor
A new instance of EventType.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(cc_and_scc = SKIP) ⇒ EventType
Returns a new instance of EventType.
36 37 38 |
# File 'lib/verizon/models/event_type.rb', line 36 def initialize(cc_and_scc = SKIP) @cc_and_scc = cc_and_scc unless cc_and_scc == SKIP end |
Instance Attribute Details
#cc_and_scc ⇒ Object
The main cause of a detected event. Each entry is of a different type and represents the sub cause code.
15 16 17 |
# File 'lib/verizon/models/event_type.rb', line 15 def cc_and_scc @cc_and_scc end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/verizon/models/event_type.rb', line 41 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. cc_and_scc = hash.key?('ccAndScc') ? APIHelper.deserialize_union_type( UnionTypeLookUp.get(:CauseCodeChoice6), hash['ccAndScc'] ) : SKIP # Create object from extracted values. EventType.new(cc_and_scc) end |
.names ⇒ Object
A mapping from model property names to API property names.
18 19 20 21 22 |
# File 'lib/verizon/models/event_type.rb', line 18 def self.names @_hash = {} if @_hash.nil? @_hash['cc_and_scc'] = 'ccAndScc' @_hash end |
.nullables ⇒ Object
An array for nullable fields
32 33 34 |
# File 'lib/verizon/models/event_type.rb', line 32 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
25 26 27 28 29 |
# File 'lib/verizon/models/event_type.rb', line 25 def self.optionals %w[ cc_and_scc ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
55 56 57 58 59 60 61 |
# File 'lib/verizon/models/event_type.rb', line 55 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
70 71 72 73 |
# File 'lib/verizon/models/event_type.rb', line 70 def inspect class_name = self.class.name.split('::').last "<#{class_name} cc_and_scc: #{@cc_and_scc.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
64 65 66 67 |
# File 'lib/verizon/models/event_type.rb', line 64 def to_s class_name = self.class.name.split('::').last "<#{class_name} cc_and_scc: #{@cc_and_scc}>" end |