Class: Verizon::FallBack
- Defined in:
- lib/verizon/models/fall_back.rb
Overview
FallBack Model.
Instance Attribute Summary collapse
-
#account_name ⇒ String
The numeric name of the account, in the format “0000123456-00001”.
-
#devices ⇒ Array[DeviceIdarray]
An array containing the ‘deviceId` array.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(devices = SKIP, account_name = SKIP) ⇒ FallBack
constructor
A new instance of FallBack.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(devices = SKIP, account_name = SKIP) ⇒ FallBack
Returns a new instance of FallBack.
42 43 44 45 |
# File 'lib/verizon/models/fall_back.rb', line 42 def initialize(devices = SKIP, account_name = SKIP) @devices = devices unless devices == SKIP @account_name = account_name unless account_name == SKIP end |
Instance Attribute Details
#account_name ⇒ String
The numeric name of the account, in the format “0000123456-00001”. Leading zeros must be included.
19 20 21 |
# File 'lib/verizon/models/fall_back.rb', line 19 def account_name @account_name end |
#devices ⇒ Array[DeviceIdarray]
An array containing the ‘deviceId` array.
14 15 16 |
# File 'lib/verizon/models/fall_back.rb', line 14 def devices @devices end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
48 49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/verizon/models/fall_back.rb', line 48 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. devices = hash.key?('devices') ? APIHelper.deserialize_union_type( UnionTypeLookUp.get(:FallBackDevices), hash['devices'] ) : SKIP account_name = hash.key?('accountName') ? hash['accountName'] : SKIP # Create object from extracted values. FallBack.new(devices, account_name) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/verizon/models/fall_back.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['devices'] = 'devices' @_hash['account_name'] = 'accountName' @_hash end |
.nullables ⇒ Object
An array for nullable fields
38 39 40 |
# File 'lib/verizon/models/fall_back.rb', line 38 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 33 34 35 |
# File 'lib/verizon/models/fall_back.rb', line 30 def self.optionals %w[ devices account_name ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
64 65 66 67 68 69 70 |
# File 'lib/verizon/models/fall_back.rb', line 64 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
79 80 81 82 |
# File 'lib/verizon/models/fall_back.rb', line 79 def inspect class_name = self.class.name.split('::').last "<#{class_name} devices: #{@devices.inspect}, account_name: #{@account_name.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
73 74 75 76 |
# File 'lib/verizon/models/fall_back.rb', line 73 def to_s class_name = self.class.name.split('::').last "<#{class_name} devices: #{@devices}, account_name: #{@account_name}>" end |