Class: Verizon::Locations1
- Defined in:
- lib/verizon/models/locations1.rb
Overview
Locations1 Model.
Instance Attribute Summary collapse
-
#address_list ⇒ Array[AddressItem]
TODO: Write general description for this method.
-
#coordinates_list ⇒ Array[Coordinates]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(coordinates_list = SKIP, address_list = SKIP) ⇒ Locations1
constructor
A new instance of Locations1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(coordinates_list = SKIP, address_list = SKIP) ⇒ Locations1
Returns a new instance of Locations1.
41 42 43 44 |
# File 'lib/verizon/models/locations1.rb', line 41 def initialize(coordinates_list = SKIP, address_list = SKIP) @coordinates_list = coordinates_list unless coordinates_list == SKIP @address_list = address_list unless address_list == SKIP end |
Instance Attribute Details
#address_list ⇒ Array[AddressItem]
TODO: Write general description for this method
18 19 20 |
# File 'lib/verizon/models/locations1.rb', line 18 def address_list @address_list end |
#coordinates_list ⇒ Array[Coordinates]
TODO: Write general description for this method
14 15 16 |
# File 'lib/verizon/models/locations1.rb', line 14 def coordinates_list @coordinates_list end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/verizon/models/locations1.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it coordinates_list = nil unless hash['coordinatesList'].nil? coordinates_list = [] hash['coordinatesList'].each do |structure| coordinates_list << (Coordinates.from_hash(structure) if structure) end end coordinates_list = SKIP unless hash.key?('coordinatesList') # Parameter is an array, so we need to iterate through it address_list = nil unless hash['addressList'].nil? address_list = [] hash['addressList'].each do |structure| address_list << (AddressItem.from_hash(structure) if structure) end end address_list = SKIP unless hash.key?('addressList') # Create object from extracted values. Locations1.new(coordinates_list, address_list) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/verizon/models/locations1.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['coordinates_list'] = 'coordinatesList' @_hash['address_list'] = 'addressList' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/verizon/models/locations1.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/verizon/models/locations1.rb', line 29 def self.optionals %w[ coordinates_list address_list ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
84 85 86 87 88 |
# File 'lib/verizon/models/locations1.rb', line 84 def inspect class_name = self.class.name.split('::').last "<#{class_name} coordinates_list: #{@coordinates_list.inspect}, address_list:"\ " #{@address_list.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
78 79 80 81 |
# File 'lib/verizon/models/locations1.rb', line 78 def to_s class_name = self.class.name.split('::').last "<#{class_name} coordinates_list: #{@coordinates_list}, address_list: #{@address_list}>" end |