Class: Verizon::MsgId
- Defined in:
- lib/verizon/models/msg_id.rb
Overview
MsgId Model.
Instance Attribute Summary collapse
-
#further_info_id ⇒ String
Links to ATIS message.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(further_info_id = nil) ⇒ MsgId
constructor
A new instance of MsgId.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(further_info_id = nil) ⇒ MsgId
Returns a new instance of MsgId.
36 37 38 |
# File 'lib/verizon/models/msg_id.rb', line 36 def initialize(further_info_id = nil) @further_info_id = further_info_id end |
Instance Attribute Details
#further_info_id ⇒ String
Links to ATIS message. A link to any other incident information data that may be available in the normal ATIS incident description or other messages. The value is described as a 4-character hexadecimal string.
17 18 19 |
# File 'lib/verizon/models/msg_id.rb', line 17 def further_info_id @further_info_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
41 42 43 44 45 46 47 48 49 |
# File 'lib/verizon/models/msg_id.rb', line 41 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. further_info_id = hash.key?('furtherInfoID') ? hash['furtherInfoID'] : nil # Create object from extracted values. MsgId.new(further_info_id) end |
.names ⇒ Object
A mapping from model property names to API property names.
20 21 22 23 24 |
# File 'lib/verizon/models/msg_id.rb', line 20 def self.names @_hash = {} if @_hash.nil? @_hash['further_info_id'] = 'furtherInfoID' @_hash end |
.nullables ⇒ Object
An array for nullable fields
32 33 34 |
# File 'lib/verizon/models/msg_id.rb', line 32 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
27 28 29 |
# File 'lib/verizon/models/msg_id.rb', line 27 def self.optionals [] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/verizon/models/msg_id.rb', line 53 def self.validate(value) if value.instance_of? self return APIHelper.valid_type?(value.further_info_id, ->(val) { val.instance_of? String }) end return false unless value.instance_of? Hash APIHelper.valid_type?(value['furtherInfoID'], ->(val) { val.instance_of? String }) end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
72 73 74 75 |
# File 'lib/verizon/models/msg_id.rb', line 72 def inspect class_name = self.class.name.split('::').last "<#{class_name} further_info_id: #{@further_info_id.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
66 67 68 69 |
# File 'lib/verizon/models/msg_id.rb', line 66 def to_s class_name = self.class.name.split('::').last "<#{class_name} further_info_id: #{@further_info_id}>" end |