Class: Verizon::PeriodicReporting
- Defined in:
- lib/verizon/models/periodic_reporting.rb
Overview
The units and values of the time interval for the sensor to send a report
Instance Attribute Summary collapse
-
#hours ⇒ Integer
whole numbers from 0 to 24.
-
#minutes ⇒ Integer
whole numbers from 0 to 59.
-
#unit ⇒ UnitEnum
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
-
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
Instance Method Summary collapse
-
#initialize(unit = SKIP, hours = SKIP, minutes = SKIP) ⇒ PeriodicReporting
constructor
A new instance of PeriodicReporting.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(unit = SKIP, hours = SKIP, minutes = SKIP) ⇒ PeriodicReporting
Returns a new instance of PeriodicReporting.
47 48 49 50 51 |
# File 'lib/verizon/models/periodic_reporting.rb', line 47 def initialize(unit = SKIP, hours = SKIP, minutes = SKIP) @unit = unit unless unit == SKIP @hours = hours unless hours == SKIP @minutes = minutes unless minutes == SKIP end |
Instance Attribute Details
#hours ⇒ Integer
whole numbers from 0 to 24
18 19 20 |
# File 'lib/verizon/models/periodic_reporting.rb', line 18 def hours @hours end |
#minutes ⇒ Integer
whole numbers from 0 to 59
22 23 24 |
# File 'lib/verizon/models/periodic_reporting.rb', line 22 def minutes @minutes end |
#unit ⇒ UnitEnum
TODO: Write general description for this method
14 15 16 |
# File 'lib/verizon/models/periodic_reporting.rb', line 14 def unit @unit end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/verizon/models/periodic_reporting.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. unit = hash.key?('unit') ? hash['unit'] : SKIP hours = hash.key?('hours') ? hash['hours'] : SKIP minutes = hash.key?('minutes') ? hash['minutes'] : SKIP # Create object from extracted values. PeriodicReporting.new(unit, hours, minutes) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/verizon/models/periodic_reporting.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['unit'] = 'unit' @_hash['hours'] = 'hours' @_hash['minutes'] = 'minutes' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/verizon/models/periodic_reporting.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/verizon/models/periodic_reporting.rb', line 34 def self.optionals %w[ unit hours minutes ] end |
.validate(value) ⇒ Object
Validates an instance of the object from a given value.
70 71 72 73 74 75 76 |
# File 'lib/verizon/models/periodic_reporting.rb', line 70 def self.validate(value) return true if value.instance_of? self return false unless value.instance_of? Hash true end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
85 86 87 88 89 |
# File 'lib/verizon/models/periodic_reporting.rb', line 85 def inspect class_name = self.class.name.split('::').last "<#{class_name} unit: #{@unit.inspect}, hours: #{@hours.inspect}, minutes:"\ " #{@minutes.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
79 80 81 82 |
# File 'lib/verizon/models/periodic_reporting.rb', line 79 def to_s class_name = self.class.name.split('::').last "<#{class_name} unit: #{@unit}, hours: #{@hours}, minutes: #{@minutes}>" end |