Class: Verizon::SensorInsightsSmartAlertMetricsController
- Inherits:
-
BaseController
- Object
- BaseController
- Verizon::SensorInsightsSmartAlertMetricsController
- Defined in:
- lib/verizon/controllers/sensor_insights_smart_alert_metrics_controller.rb
Overview
SensorInsightsSmartAlertMetricsController
Constant Summary
Constants inherited from BaseController
Instance Attribute Summary
Attributes inherited from BaseController
Instance Method Summary collapse
-
#sensorinsightsmetricsquery(body) ⇒ ApiResponse
Get Device Alerts for the most recent daily period, up to 30 days.
Methods inherited from BaseController
#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent
Constructor Details
This class inherits a constructor from Verizon::BaseController
Instance Method Details
#sensorinsightsmetricsquery(body) ⇒ ApiResponse
Get Device Alerts for the most recent daily period, up to 30 days. up to 30 days.
13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 |
# File 'lib/verizon/controllers/sensor_insights_smart_alert_metrics_controller.rb', line 13 def sensorinsightsmetricsquery(body) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/dm/v1/smartAlerts/actions/metrics', Server::THINGSPACE) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(And.new('thingspace_oauth', 'VZ-M2M-Token'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(DtoQueryMetricsResponse.method(:from_hash)) .is_api_response(true) .local_error('400', 'Bad Request', M400ManagementErrorException) .local_error('401', 'UnAuthorized', ManagementErrorException) .local_error('403', 'Forbidden', M403ManagementErrorException) .local_error('500', 'Internal server error.', M500ManagementErrorException)) .execute end |